#!/bin/sh
cd `dirname "$0"`
case $1 in
  p1) timeout -s 9 2 ../source/tcas.exe  958 1 1 2597  574 4253 0  399  400 0 0 1     > ../outputs/t1
    if diff ../outputs/t1 ../originals/t1 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2) timeout -s 9 2 ../source/tcas.exe  627 0 0  621  216  382 1  400  641 1 1 0     > ../outputs/t2
    if diff ../outputs/t2 ../originals/t2 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3) timeout -s 9 2 ../source/tcas.exe  549 1 1 4398  133 1445 1  641  639 0 0 1     > ../outputs/t3
    if diff ../outputs/t3 ../originals/t3 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4) timeout -s 9 2 ../source/tcas.exe  576 0 1 3469  183  381 2  641  501 1 0 1     > ../outputs/t4
    if diff ../outputs/t4 ../originals/t4 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5) timeout -s 9 2 ../source/tcas.exe  992 1 0 3342   23 4657 1  640  741 0 0 0     > ../outputs/t5
    if diff ../outputs/t5 ../originals/t5 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p6) timeout -s 9 2 ../source/tcas.exe  548 0 1   34  542 3514 2  499  401 1 1 1     > ../outputs/t6
    if diff ../outputs/t6 ../originals/t6 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p7) timeout -s 9 2 ../source/tcas.exe  710 0 0  127  403 4616 3  500  400 0 0 0     > ../outputs/t7
    if diff ../outputs/t7 ../originals/t7 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p8) timeout -s 9 2 ../source/tcas.exe  638 0 1  698  499 2465 3  500  501 0 0 0     > ../outputs/t8
    if diff ../outputs/t8 ../originals/t8 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p9) timeout -s 9 2 ../source/tcas.exe  893 1 0  205  283 5056 3  400  641 1 1 1     > ../outputs/t9
    if diff ../outputs/t9 ../originals/t9 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p10) timeout -s 9 2 ../source/tcas.exe  976 1 1 5378  390 1000 2  641  741 1 0 0     > ../outputs/t10
    if diff ../outputs/t10 ../originals/t10 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p11) timeout -s 9 2 ../source/tcas.exe  763 0 0  136  576 2305 0  401  741 0 0 0     > ../outputs/t11
    if diff ../outputs/t11 ../originals/t11 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p12) timeout -s 9 2 ../source/tcas.exe  570 0 1 1945  376 2064 0  739  740 1 1 1     > ../outputs/t12
    if diff ../outputs/t12 ../originals/t12 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p13) timeout -s 9 2 ../source/tcas.exe  967 1 0  659  204 3825 3  500  399 0 0 0     > ../outputs/t13
    if diff ../outputs/t13 ../originals/t13 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p14) timeout -s 9 2 ../source/tcas.exe  892 0 1 2009   40 1011 1  641  740 1 1 0     > ../outputs/t14
    if diff ../outputs/t14 ../originals/t14 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p15) timeout -s 9 2 ../source/tcas.exe  911 1 1 4194  242 4667 1  401  399 1 1 1     > ../outputs/t15
    if diff ../outputs/t15 ../originals/t15 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p16) timeout -s 9 2 ../source/tcas.exe  929 0 1 1072  134 1036 1  741  639 1 1 0     > ../outputs/t16
    if diff ../outputs/t16 ../originals/t16 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p17) timeout -s 9 2 ../source/tcas.exe  588 1 0 4341  336 2774 2  740  400 1 0 1     > ../outputs/t17
    if diff ../outputs/t17 ../originals/t17 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p18) timeout -s 9 2 ../source/tcas.exe  963 0 0 5985  377  994 3  400  499 0 1 1     > ../outputs/t18
    if diff ../outputs/t18 ../originals/t18 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p19) timeout -s 9 2 ../source/tcas.exe  699 1 1  619  432  912 2  740  639 0 1 0     > ../outputs/t19
    if diff ../outputs/t19 ../originals/t19 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p20) timeout -s 9 2 ../source/tcas.exe  818 0 1 1876  318  793 1  499  501 1 0 0     > ../outputs/t20
    if diff ../outputs/t20 ../originals/t20 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p21) timeout -s 9 2 ../source/tcas.exe  926 1 0 1694  263  651 2  501  499 1 0 0     > ../outputs/t21
    if diff ../outputs/t21 ../originals/t21 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p22) timeout -s 9 2 ../source/tcas.exe  579 0 1  882  101 5381 0  639  499 0 1 0     > ../outputs/t22
    if diff ../outputs/t22 ../originals/t22 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p23) timeout -s 9 2 ../source/tcas.exe  878 0 0 1063   86 4714 1  499  400 0 0 0     > ../outputs/t23
    if diff ../outputs/t23 ../originals/t23 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p24) timeout -s 9 2 ../source/tcas.exe  822 0 1 1469  234 4419 1  399  399 1 1 1     > ../outputs/t24
    if diff ../outputs/t24 ../originals/t24 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p25) timeout -s 9 2 ../source/tcas.exe  653 1 0  432   67  203 0  401  401 1 0 0     > ../outputs/t25
    if diff ../outputs/t25 ../originals/t25 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p26) timeout -s 9 2 ../source/tcas.exe  601 1 1  777  424  309 1  641  401 0 1 1     > ../outputs/t26
    if diff ../outputs/t26 ../originals/t26 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p27) timeout -s 9 2 ../source/tcas.exe  764 0 1 2969  491 2466 0  639  501 0 1 1     > ../outputs/t27
    if diff ../outputs/t27 ../originals/t27 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p28) timeout -s 9 2 ../source/tcas.exe  594 1 1 2484  121 1193 2  500  740 0 0 1     > ../outputs/t28
    if diff ../outputs/t28 ../originals/t28 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p29) timeout -s 9 2 ../source/tcas.exe  992 1 0 1793  517  254 0  739  500 1 1 1     > ../outputs/t29
    if diff ../outputs/t29 ../originals/t29 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p30) timeout -s 9 2 ../source/tcas.exe  832 1 1 4454  148 4683 3  501  640 0 1 1     > ../outputs/t30
    if diff ../outputs/t30 ../originals/t30 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p31) timeout -s 9 2 ../source/tcas.exe  882 0 1  674  444  191 3  741  740 1 0 0     > ../outputs/t31
    if diff ../outputs/t31 ../originals/t31 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p32) timeout -s 9 2 ../source/tcas.exe  753 1 0 3203  448 1667 0  501  641 0 0 0     > ../outputs/t32
    if diff ../outputs/t32 ../originals/t32 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p33) timeout -s 9 2 ../source/tcas.exe  953 1 1  682   24 2477 2  739  399 1 1 0     > ../outputs/t33
    if diff ../outputs/t33 ../originals/t33 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p34) timeout -s 9 2 ../source/tcas.exe  588 1 0 3362   93 1315 3  741  639 1 0 1     > ../outputs/t34
    if diff ../outputs/t34 ../originals/t34 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p35) timeout -s 9 2 ../source/tcas.exe  965 0 0 2078   76  303 1  401  640 0 1 1     > ../outputs/t35
    if diff ../outputs/t35 ../originals/t35 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p36) timeout -s 9 2 ../source/tcas.exe  612 0 0 5073  510 1151 1  501  500 1 0 0     > ../outputs/t36
    if diff ../outputs/t36 ../originals/t36 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p37) timeout -s 9 2 ../source/tcas.exe  783 1 0 4006  586 1219 0  501  740 0 1 1     > ../outputs/t37
    if diff ../outputs/t37 ../originals/t37 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p38) timeout -s 9 2 ../source/tcas.exe  903 0 1 4075  608 5049 1  399  741 0 1 1     > ../outputs/t38
    if diff ../outputs/t38 ../originals/t38 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p39) timeout -s 9 2 ../source/tcas.exe  888 0 0 2521  241  647 1  741  639 1 0 0     > ../outputs/t39
    if diff ../outputs/t39 ../originals/t39 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p40) timeout -s 9 2 ../source/tcas.exe  971 0 1  183  524  747 2  400  401 1 1 1     > ../outputs/t40
    if diff ../outputs/t40 ../originals/t40 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p41) timeout -s 9 2 ../source/tcas.exe  668 0 0 4507  418 4267 2  740  640 0 1 1     > ../outputs/t41
    if diff ../outputs/t41 ../originals/t41 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p42) timeout -s 9 2 ../source/tcas.exe  731 0 0 2686  128  674 2  499  740 0 0 0     > ../outputs/t42
    if diff ../outputs/t42 ../originals/t42 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p43) timeout -s 9 2 ../source/tcas.exe  935 0 0  121  179 2414 0  501  639 1 0 1     > ../outputs/t43
    if diff ../outputs/t43 ../originals/t43 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p44) timeout -s 9 2 ../source/tcas.exe  952 1 1  802   26 3803 1  400  740 1 1 0     > ../outputs/t44
    if diff ../outputs/t44 ../originals/t44 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p45) timeout -s 9 2 ../source/tcas.exe  673 1 0 2913   18 2294 3  400  641 0 1 0     > ../outputs/t45
    if diff ../outputs/t45 ../originals/t45 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p46) timeout -s 9 2 ../source/tcas.exe  832 0 1  934    9 1145 2  399  401 0 1 1     > ../outputs/t46
    if diff ../outputs/t46 ../originals/t46 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p47) timeout -s 9 2 ../source/tcas.exe  547 1 1 1723  236 2963 0  739  501 1 1 1     > ../outputs/t47
    if diff ../outputs/t47 ../originals/t47 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p48) timeout -s 9 2 ../source/tcas.exe  799 0 1 5588  485  211 0  399  499 0 0 1     > ../outputs/t48
    if diff ../outputs/t48 ../originals/t48 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p49) timeout -s 9 2 ../source/tcas.exe  711 0 0  201  181 2943 1  739  741 0 0 0     > ../outputs/t49
    if diff ../outputs/t49 ../originals/t49 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p50) timeout -s 9 2 ../source/tcas.exe  987 0 0  813  318  888 3  641  400 1 0 0     > ../outputs/t50
    if diff ../outputs/t50 ../originals/t50 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p51) timeout -s 9 2 ../source/tcas.exe  821 0 1  138   79  356 2  399  640 0 1 1     > ../outputs/t51
    if diff ../outputs/t51 ../originals/t51 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p52) timeout -s 9 2 ../source/tcas.exe  528 1 0 5170   22  500 1  740  639 1 1 1     > ../outputs/t52
    if diff ../outputs/t52 ../originals/t52 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p53) timeout -s 9 2 ../source/tcas.exe  896 1 1 5784  557  585 2  739  641 1 0 0     > ../outputs/t53
    if diff ../outputs/t53 ../originals/t53 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p54) timeout -s 9 2 ../source/tcas.exe  546 0 1 1900  507 4846 1  501  641 0 1 1     > ../outputs/t54
    if diff ../outputs/t54 ../originals/t54 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p55) timeout -s 9 2 ../source/tcas.exe  822 0 0  447  353 1740 2  399  639 0 0 1     > ../outputs/t55
    if diff ../outputs/t55 ../originals/t55 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p56) timeout -s 9 2 ../source/tcas.exe  796 0 1  108   59  134 3  640  740 1 1 0     > ../outputs/t56
    if diff ../outputs/t56 ../originals/t56 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p57) timeout -s 9 2 ../source/tcas.exe  775 1 1 2961  373 5279 3  640  499 0 1 0     > ../outputs/t57
    if diff ../outputs/t57 ../originals/t57 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p58) timeout -s 9 2 ../source/tcas.exe  763 1 1 2635  387 4709 3  641  741 0 0 1     > ../outputs/t58
    if diff ../outputs/t58 ../originals/t58 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p59) timeout -s 9 2 ../source/tcas.exe  568 1 1 3423   52 3011 3  499  640 0 1 1     > ../outputs/t59
    if diff ../outputs/t59 ../originals/t59 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p60) timeout -s 9 2 ../source/tcas.exe  972 0 1 4644  495 4090 1  640  500 0 0 1     > ../outputs/t60
    if diff ../outputs/t60 ../originals/t60 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p61) timeout -s 9 2 ../source/tcas.exe  562 0 0 1642   19  895 2  400  739 0 0 1     > ../outputs/t61
    if diff ../outputs/t61 ../originals/t61 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p62) timeout -s 9 2 ../source/tcas.exe  804 0 1 3945   71  376 2  501  739 0 0 0     > ../outputs/t62
    if diff ../outputs/t62 ../originals/t62 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p63) timeout -s 9 2 ../source/tcas.exe  610 0 1  282  158   14 3  500  499 1 1 0     > ../outputs/t63
    if diff ../outputs/t63 ../originals/t63 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p64) timeout -s 9 2 ../source/tcas.exe  743 1 0  773  436  860 2  501  740 1 0 1     > ../outputs/t64
    if diff ../outputs/t64 ../originals/t64 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p65) timeout -s 9 2 ../source/tcas.exe  947 1 0 1660  606 2279 3  739  500 1 0 0     > ../outputs/t65
    if diff ../outputs/t65 ../originals/t65 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p66) timeout -s 9 2 ../source/tcas.exe  919 0 1  904  185 2680 0  641  401 0 0 0     > ../outputs/t66
    if diff ../outputs/t66 ../originals/t66 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p67) timeout -s 9 2 ../source/tcas.exe  529 0 1 2376  616 4702 3  501  739 0 0 0     > ../outputs/t67
    if diff ../outputs/t67 ../originals/t67 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p68) timeout -s 9 2 ../source/tcas.exe  632 0 1 1479  544 2213 1  499  641 1 0 0     > ../outputs/t68
    if diff ../outputs/t68 ../originals/t68 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p69) timeout -s 9 2 ../source/tcas.exe  871 0 1 4564  133  362 1  499  400 0 0 0     > ../outputs/t69
    if diff ../outputs/t69 ../originals/t69 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p70) timeout -s 9 2 ../source/tcas.exe  562 1 1 2836  195 5909 2  499  741 0 1 1     > ../outputs/t70
    if diff ../outputs/t70 ../originals/t70 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p71) timeout -s 9 2 ../source/tcas.exe  610 0 1  135  539 5537 1  739  639 1 0 0     > ../outputs/t71
    if diff ../outputs/t71 ../originals/t71 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p72) timeout -s 9 2 ../source/tcas.exe  867 1 1 1874  201 4704 0  499  499 1 0 1     > ../outputs/t72
    if diff ../outputs/t72 ../originals/t72 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p73) timeout -s 9 2 ../source/tcas.exe  845 1 0  647  226 4212 2  501  499 0 0 1     > ../outputs/t73
    if diff ../outputs/t73 ../originals/t73 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p74) timeout -s 9 2 ../source/tcas.exe  822 1 0 5034  541 2582 2  740  740 0 1 0     > ../outputs/t74
    if diff ../outputs/t74 ../originals/t74 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p75) timeout -s 9 2 ../source/tcas.exe  769 0 1  903   91  233 3  399  740 1 1 0     > ../outputs/t75
    if diff ../outputs/t75 ../originals/t75 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p76) timeout -s 9 2 ../source/tcas.exe  667 0 0 4200  562  645 3  640  739 1 0 1     > ../outputs/t76
    if diff ../outputs/t76 ../originals/t76 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p77) timeout -s 9 2 ../source/tcas.exe  597 0 0 5459  555 2985 3  741  401 1 1 0     > ../outputs/t77
    if diff ../outputs/t77 ../originals/t77 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p78) timeout -s 9 2 ../source/tcas.exe  959 1 1 1600  566 3684 1  641  740 0 0 1     > ../outputs/t78
    if diff ../outputs/t78 ../originals/t78 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p79) timeout -s 9 2 ../source/tcas.exe  557 0 1 1365  369  241 0  500  401 0 0 0     > ../outputs/t79
    if diff ../outputs/t79 ../originals/t79 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p80) timeout -s 9 2 ../source/tcas.exe  877 0 1 3749  566 3439 1  641  739 0 1 0     > ../outputs/t80
    if diff ../outputs/t80 ../originals/t80 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p81) timeout -s 9 2 ../source/tcas.exe  637 1 1  486  588 3732 2  399  641 1 0 1     > ../outputs/t81
    if diff ../outputs/t81 ../originals/t81 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p82) timeout -s 9 2 ../source/tcas.exe  950 1 1 1309    2 5510 3  740  639 1 0 0     > ../outputs/t82
    if diff ../outputs/t82 ../originals/t82 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p83) timeout -s 9 2 ../source/tcas.exe  925 0 1  508  500 1124 3  740  740 1 0 1     > ../outputs/t83
    if diff ../outputs/t83 ../originals/t83 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p84) timeout -s 9 2 ../source/tcas.exe  691 0 0 1625  534 5258 0  400  639 1 0 0     > ../outputs/t84
    if diff ../outputs/t84 ../originals/t84 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p85) timeout -s 9 2 ../source/tcas.exe  833 1 1  927  145 2642 2  641  501 1 0 1     > ../outputs/t85
    if diff ../outputs/t85 ../originals/t85 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p86) timeout -s 9 2 ../source/tcas.exe  804 0 1 1933  194 1176 0  640  639 1 0 0     > ../outputs/t86
    if diff ../outputs/t86 ../originals/t86 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p87) timeout -s 9 2 ../source/tcas.exe  937 0 1 2358  298  524 1  740  741 1 1 1     > ../outputs/t87
    if diff ../outputs/t87 ../originals/t87 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p88) timeout -s 9 2 ../source/tcas.exe  542 0 0   96  231 2100 2  400  741 1 0 0     > ../outputs/t88
    if diff ../outputs/t88 ../originals/t88 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p89) timeout -s 9 2 ../source/tcas.exe  975 0 0 1371  238 1272 1  400  640 1 1 1     > ../outputs/t89
    if diff ../outputs/t89 ../originals/t89 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p90) timeout -s 9 2 ../source/tcas.exe  690 0 0  173  231  681 1  499  741 1 1 1     > ../outputs/t90
    if diff ../outputs/t90 ../originals/t90 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p91) timeout -s 9 2 ../source/tcas.exe  866 1 1 5987   18 2595 1  639  639 0 0 0     > ../outputs/t91
    if diff ../outputs/t91 ../originals/t91 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p92) timeout -s 9 2 ../source/tcas.exe  915 0 0 1855   99 3443 2  401  740 0 0 1     > ../outputs/t92
    if diff ../outputs/t92 ../originals/t92 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p93) timeout -s 9 2 ../source/tcas.exe  630 1 0 3335  578 2359 3  401  740 1 0 1     > ../outputs/t93
    if diff ../outputs/t93 ../originals/t93 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p94) timeout -s 9 2 ../source/tcas.exe  843 1 1 1806  481 1209 3  640  500 1 1 1     > ../outputs/t94
    if diff ../outputs/t94 ../originals/t94 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p95) timeout -s 9 2 ../source/tcas.exe  564 1 0  389  179  377 3  741  501 0 1 0     > ../outputs/t95
    if diff ../outputs/t95 ../originals/t95 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p96) timeout -s 9 2 ../source/tcas.exe  685 1 1 4828  116  410 2  501  500 1 1 0     > ../outputs/t96
    if diff ../outputs/t96 ../originals/t96 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p97) timeout -s 9 2 ../source/tcas.exe  716 0 0 1318   76   54 2  400  640 1 1 1     > ../outputs/t97
    if diff ../outputs/t97 ../originals/t97 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p98) timeout -s 9 2 ../source/tcas.exe  624 1 0 3575  185 2668 2  501  639 0 1 1     > ../outputs/t98
    if diff ../outputs/t98 ../originals/t98 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p99) timeout -s 9 2 ../source/tcas.exe  922 0 0 5533  587 5628 1  640  499 0 0 0     > ../outputs/t99
    if diff ../outputs/t99 ../originals/t99 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p100) timeout -s 9 2 ../source/tcas.exe  651 1 0  270  517 5308 0  739  740 0 1 1     > ../outputs/t100
    if diff ../outputs/t100 ../originals/t100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p101) timeout -s 9 2 ../source/tcas.exe  931 0 0  472  619  702 3  639  740 0 0 1     > ../outputs/t101
    if diff ../outputs/t101 ../originals/t101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p102) timeout -s 9 2 ../source/tcas.exe  827 0 1 1691  437  776 1  641  399 1 0 1     > ../outputs/t102
    if diff ../outputs/t102 ../originals/t102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p103) timeout -s 9 2 ../source/tcas.exe  636 0 0 4210  340 4046 0  741  401 0 1 1     > ../outputs/t103
    if diff ../outputs/t103 ../originals/t103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p104) timeout -s 9 2 ../source/tcas.exe  838 1 0 5179  451 3128 2  399  740 1 0 0     > ../outputs/t104
    if diff ../outputs/t104 ../originals/t104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p105) timeout -s 9 2 ../source/tcas.exe  807 1 1 3747  344 2226 1  641  401 0 0 1     > ../outputs/t105
    if diff ../outputs/t105 ../originals/t105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p106) timeout -s 9 2 ../source/tcas.exe  953 1 1 5194  356 2325 3  501  401 1 1 0     > ../outputs/t106
    if diff ../outputs/t106 ../originals/t106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p107) timeout -s 9 2 ../source/tcas.exe  779 1 1 5328  619 4294 0  501  399 0 1 1     > ../outputs/t107
    if diff ../outputs/t107 ../originals/t107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p108) timeout -s 9 2 ../source/tcas.exe  932 0 1 2219  415  189 0  641  500 1 1 0     > ../outputs/t108
    if diff ../outputs/t108 ../originals/t108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p109) timeout -s 9 2 ../source/tcas.exe  969 1 0  691  510  603 1  740  399 1 1 1     > ../outputs/t109
    if diff ../outputs/t109 ../originals/t109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p110) timeout -s 9 2 ../source/tcas.exe  530 0 0  515   36  368 2  740  400 1 1 1     > ../outputs/t110
    if diff ../outputs/t110 ../originals/t110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p111) timeout -s 9 2 ../source/tcas.exe  940 1 1  203  198  885 0  499  500 0 0 0     > ../outputs/t111
    if diff ../outputs/t111 ../originals/t111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p112) timeout -s 9 2 ../source/tcas.exe  877 0 0  996  157 2459 1  501  740 1 1 0     > ../outputs/t112
    if diff ../outputs/t112 ../originals/t112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p113) timeout -s 9 2 ../source/tcas.exe  779 1 0 4175   94 5280 1  739  499 0 1 1     > ../outputs/t113
    if diff ../outputs/t113 ../originals/t113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p114) timeout -s 9 2 ../source/tcas.exe  753 1 0 5017   27 1162 3  740  640 1 0 0     > ../outputs/t114
    if diff ../outputs/t114 ../originals/t114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p115) timeout -s 9 2 ../source/tcas.exe  890 0 1 4178  598 5835 2  741  401 1 0 1     > ../outputs/t115
    if diff ../outputs/t115 ../originals/t115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p116) timeout -s 9 2 ../source/tcas.exe  969 1 1  375  228  986 0  499  499 1 1 1     > ../outputs/t116
    if diff ../outputs/t116 ../originals/t116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p117) timeout -s 9 2 ../source/tcas.exe  705 0 0 3770  607  499 1  401  399 0 0 0     > ../outputs/t117
    if diff ../outputs/t117 ../originals/t117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p118) timeout -s 9 2 ../source/tcas.exe  886 1 1 1380  305 2806 0  641  739 0 0 0     > ../outputs/t118
    if diff ../outputs/t118 ../originals/t118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p119) timeout -s 9 2 ../source/tcas.exe  833 0 0  981  545  739 0  499  399 1 0 0     > ../outputs/t119
    if diff ../outputs/t119 ../originals/t119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p120) timeout -s 9 2 ../source/tcas.exe  656 0 0  892  409 4552 1  399  639 0 1 1     > ../outputs/t120
    if diff ../outputs/t120 ../originals/t120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p121) timeout -s 9 2 ../source/tcas.exe  913 0 0   58   84 1982 1  739  500 1 1 1     > ../outputs/t121
    if diff ../outputs/t121 ../originals/t121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p122) timeout -s 9 2 ../source/tcas.exe  675 1 0  300  395 2397 2  501  639 0 1 1     > ../outputs/t122
    if diff ../outputs/t122 ../originals/t122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p123) timeout -s 9 2 ../source/tcas.exe  625 1 1 3344  560 3343 1  501  499 1 1 0     > ../outputs/t123
    if diff ../outputs/t123 ../originals/t123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p124) timeout -s 9 2 ../source/tcas.exe  750 0 0 5769   41  906 1  401  741 0 1 1     > ../outputs/t124
    if diff ../outputs/t124 ../originals/t124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p125) timeout -s 9 2 ../source/tcas.exe  817 1 0  973  245 3280 3  740  640 1 0 1     > ../outputs/t125
    if diff ../outputs/t125 ../originals/t125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p126) timeout -s 9 2 ../source/tcas.exe  651 0 1  982  211  394 3  500  741 0 0 0     > ../outputs/t126
    if diff ../outputs/t126 ../originals/t126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p127) timeout -s 9 2 ../source/tcas.exe  646 0 1 1598  269 5991 0  400  739 0 0 0     > ../outputs/t127
    if diff ../outputs/t127 ../originals/t127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p128) timeout -s 9 2 ../source/tcas.exe  670 1 1 1329  428 5569 1  399  740 1 1 1     > ../outputs/t128
    if diff ../outputs/t128 ../originals/t128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p129) timeout -s 9 2 ../source/tcas.exe  622 1 0 4421  180 1996 2  639  640 0 1 0     > ../outputs/t129
    if diff ../outputs/t129 ../originals/t129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p130) timeout -s 9 2 ../source/tcas.exe  548 1 1 4416  322 1952 0  739  500 0 0 0     > ../outputs/t130
    if diff ../outputs/t130 ../originals/t130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p131) timeout -s 9 2 ../source/tcas.exe  654 1 1 2133  113  442 3  641  741 0 0 0     > ../outputs/t131
    if diff ../outputs/t131 ../originals/t131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p132) timeout -s 9 2 ../source/tcas.exe  543 0 1 2857  188 2979 3  401  741 0 0 0     > ../outputs/t132
    if diff ../outputs/t132 ../originals/t132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p133) timeout -s 9 2 ../source/tcas.exe  845 1 0 2624  419 4353 1  400  641 1 1 1     > ../outputs/t133
    if diff ../outputs/t133 ../originals/t133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p134) timeout -s 9 2 ../source/tcas.exe  837 1 1 3649   52 3911 3  640  499 0 1 0     > ../outputs/t134
    if diff ../outputs/t134 ../originals/t134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p135) timeout -s 9 2 ../source/tcas.exe  812 1 0 2155  530 1846 2  640  739 0 1 1     > ../outputs/t135
    if diff ../outputs/t135 ../originals/t135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p136) timeout -s 9 2 ../source/tcas.exe  554 1 0 4534    6 1975 3  399  499 1 1 1     > ../outputs/t136
    if diff ../outputs/t136 ../originals/t136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p137) timeout -s 9 2 ../source/tcas.exe  888 1 0 3648  302  215 1  501  399 1 1 0     > ../outputs/t137
    if diff ../outputs/t137 ../originals/t137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p138) timeout -s 9 2 ../source/tcas.exe  702 1 1 3653  250  423 1  401  501 0 0 0     > ../outputs/t138
    if diff ../outputs/t138 ../originals/t138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p139) timeout -s 9 2 ../source/tcas.exe  774 1 1  551  433 2572 1  740  639 0 0 1     > ../outputs/t139
    if diff ../outputs/t139 ../originals/t139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p140) timeout -s 9 2 ../source/tcas.exe  594 1 1 5449  318 4116 1  400  501 1 1 1     > ../outputs/t140
    if diff ../outputs/t140 ../originals/t140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p141) timeout -s 9 2 ../source/tcas.exe  961 0 1  902  126 3531 1  740  500 1 0 0     > ../outputs/t141
    if diff ../outputs/t141 ../originals/t141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p142) timeout -s 9 2 ../source/tcas.exe  934 1 1 2743  366 5463 2  739  399 0 1 1     > ../outputs/t142
    if diff ../outputs/t142 ../originals/t142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p143) timeout -s 9 2 ../source/tcas.exe  533 0 0 5750  407 4328 2  641  400 1 1 1     > ../outputs/t143
    if diff ../outputs/t143 ../originals/t143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p144) timeout -s 9 2 ../source/tcas.exe  712 1 1 2545  341 4146 0  641  740 1 0 0     > ../outputs/t144
    if diff ../outputs/t144 ../originals/t144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p145) timeout -s 9 2 ../source/tcas.exe  780 0 0  702   12 4837 3  740  739 1 0 0     > ../outputs/t145
    if diff ../outputs/t145 ../originals/t145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p146) timeout -s 9 2 ../source/tcas.exe  861 1 1 2982  567 3850 3  400  401 1 0 1     > ../outputs/t146
    if diff ../outputs/t146 ../originals/t146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p147) timeout -s 9 2 ../source/tcas.exe  829 1 0 4012  389  818 1  401  400 0 1 1     > ../outputs/t147
    if diff ../outputs/t147 ../originals/t147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p148) timeout -s 9 2 ../source/tcas.exe  660 0 1 3874   28  726 1  400  401 1 1 0     > ../outputs/t148
    if diff ../outputs/t148 ../originals/t148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p149) timeout -s 9 2 ../source/tcas.exe  716 1 1 2749  240  993 3  401  739 0 1 0     > ../outputs/t149
    if diff ../outputs/t149 ../originals/t149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p150) timeout -s 9 2 ../source/tcas.exe  739 1 1  609   48 1187 1  741  639 1 1 1     > ../outputs/t150
    if diff ../outputs/t150 ../originals/t150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p151) timeout -s 9 2 ../source/tcas.exe  592 1 0 1045  226 4721 2  640  401 0 0 1     > ../outputs/t151
    if diff ../outputs/t151 ../originals/t151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p152) timeout -s 9 2 ../source/tcas.exe  833 0 0  678  405  963 2  400  739 1 0 1     > ../outputs/t152
    if diff ../outputs/t152 ../originals/t152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p153) timeout -s 9 2 ../source/tcas.exe  940 0 0  651  469 3461 2  639  400 0 1 0     > ../outputs/t153
    if diff ../outputs/t153 ../originals/t153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p154) timeout -s 9 2 ../source/tcas.exe  690 0 0  404  384  908 0  500  740 0 0 1     > ../outputs/t154
    if diff ../outputs/t154 ../originals/t154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p155) timeout -s 9 2 ../source/tcas.exe  757 1 1 3234  187 2853 3  401  500 0 1 1     > ../outputs/t155
    if diff ../outputs/t155 ../originals/t155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p156) timeout -s 9 2 ../source/tcas.exe  879 0 1  553  347 2553 1  639  400 0 0 1     > ../outputs/t156
    if diff ../outputs/t156 ../originals/t156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p157) timeout -s 9 2 ../source/tcas.exe  719 1 1 5010  438 4880 0  741  640 1 1 1     > ../outputs/t157
    if diff ../outputs/t157 ../originals/t157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p158) timeout -s 9 2 ../source/tcas.exe  690 1 1  380  577  239 0  641  640 0 1 1     > ../outputs/t158
    if diff ../outputs/t158 ../originals/t158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p159) timeout -s 9 2 ../source/tcas.exe  793 0 1  176   89 4431 0  740  399 1 0 0     > ../outputs/t159
    if diff ../outputs/t159 ../originals/t159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p160) timeout -s 9 2 ../source/tcas.exe  771 0 0 1054  289  282 3  400  641 0 0 1     > ../outputs/t160
    if diff ../outputs/t160 ../originals/t160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p161) timeout -s 9 2 ../source/tcas.exe  979 0 1  931  141   79 1  639  399 0 0 0     > ../outputs/t161
    if diff ../outputs/t161 ../originals/t161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p162) timeout -s 9 2 ../source/tcas.exe  858 0 1 3222  405  349 1  740  500 0 0 0     > ../outputs/t162
    if diff ../outputs/t162 ../originals/t162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p163) timeout -s 9 2 ../source/tcas.exe  918 1 0  818  542 1868 2  639  639 0 0 1     > ../outputs/t163
    if diff ../outputs/t163 ../originals/t163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p164) timeout -s 9 2 ../source/tcas.exe  741 1 1  966  413 2508 3  741  641 1 0 0     > ../outputs/t164
    if diff ../outputs/t164 ../originals/t164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p165) timeout -s 9 2 ../source/tcas.exe  990 1 1 3490  323  281 2  640  741 0 0 1     > ../outputs/t165
    if diff ../outputs/t165 ../originals/t165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p166) timeout -s 9 2 ../source/tcas.exe  536 0 1  927  423 2757 3  399  501 1 0 1     > ../outputs/t166
    if diff ../outputs/t166 ../originals/t166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p167) timeout -s 9 2 ../source/tcas.exe  927 1 0 4902  351 2093 0  739  740 1 0 0     > ../outputs/t167
    if diff ../outputs/t167 ../originals/t167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p168) timeout -s 9 2 ../source/tcas.exe  749 0 1 1037  384  703 3  400  740 1 1 1     > ../outputs/t168
    if diff ../outputs/t168 ../originals/t168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p169) timeout -s 9 2 ../source/tcas.exe  946 1 0 2345  180  170 2  399  400 0 1 0     > ../outputs/t169
    if diff ../outputs/t169 ../originals/t169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p170) timeout -s 9 2 ../source/tcas.exe  631 1 0 1569  330 1984 0  740  500 1 1 1     > ../outputs/t170
    if diff ../outputs/t170 ../originals/t170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p171) timeout -s 9 2 ../source/tcas.exe  550 1 1  489  113 1317 1  640  399 1 0 1     > ../outputs/t171
    if diff ../outputs/t171 ../originals/t171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p172) timeout -s 9 2 ../source/tcas.exe  641 0 1   41  422 4244 3  740  401 0 1 1     > ../outputs/t172
    if diff ../outputs/t172 ../originals/t172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p173) timeout -s 9 2 ../source/tcas.exe  700 0 1 1300  580 3798 2  639  741 1 1 0     > ../outputs/t173
    if diff ../outputs/t173 ../originals/t173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p174) timeout -s 9 2 ../source/tcas.exe  666 1 0  201  119 3080 2  399  640 1 0 0     > ../outputs/t174
    if diff ../outputs/t174 ../originals/t174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p175) timeout -s 9 2 ../source/tcas.exe  661 0 1 3235  287 2268 1  640  399 0 1 1     > ../outputs/t175
    if diff ../outputs/t175 ../originals/t175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p176) timeout -s 9 2 ../source/tcas.exe  826 0 0 3619  369 2109 1  741  639 0 1 1     > ../outputs/t176
    if diff ../outputs/t176 ../originals/t176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p177) timeout -s 9 2 ../source/tcas.exe  874 0 1  771    9 4043 1  500  639 1 1 1     > ../outputs/t177
    if diff ../outputs/t177 ../originals/t177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p178) timeout -s 9 2 ../source/tcas.exe  911 1 1 3373  346 1773 2  400  501 1 1 1     > ../outputs/t178
    if diff ../outputs/t178 ../originals/t178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p179) timeout -s 9 2 ../source/tcas.exe  749 0 1 2307  230 1594 1  741  740 1 0 1     > ../outputs/t179
    if diff ../outputs/t179 ../originals/t179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p180) timeout -s 9 2 ../source/tcas.exe  567 1 0 5621  399 3514 1  500  400 0 1 0     > ../outputs/t180
    if diff ../outputs/t180 ../originals/t180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p181) timeout -s 9 2 ../source/tcas.exe  635 1 0 5854  219  617 3  399  401 1 1 0     > ../outputs/t181
    if diff ../outputs/t181 ../originals/t181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p182) timeout -s 9 2 ../source/tcas.exe  897 1 1 1701  109 3438 1  641  401 0 1 0     > ../outputs/t182
    if diff ../outputs/t182 ../originals/t182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p183) timeout -s 9 2 ../source/tcas.exe  598 0 1 2589  130  629 3  399  500 0 0 1     > ../outputs/t183
    if diff ../outputs/t183 ../originals/t183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p184) timeout -s 9 2 ../source/tcas.exe  893 0 1 5001  301  711 2  400  739 1 0 0     > ../outputs/t184
    if diff ../outputs/t184 ../originals/t184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p185) timeout -s 9 2 ../source/tcas.exe  530 0 0 1564  583 4042 1  400  500 1 0 1     > ../outputs/t185
    if diff ../outputs/t185 ../originals/t185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p186) timeout -s 9 2 ../source/tcas.exe  854 0 0 5295  258  895 3  639  500 1 1 1     > ../outputs/t186
    if diff ../outputs/t186 ../originals/t186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p187) timeout -s 9 2 ../source/tcas.exe  550 1 0  968   10 5679 0  500  740 0 0 0     > ../outputs/t187
    if diff ../outputs/t187 ../originals/t187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p188) timeout -s 9 2 ../source/tcas.exe  828 1 0 4580  568 2638 0  740  639 0 1 0     > ../outputs/t188
    if diff ../outputs/t188 ../originals/t188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p189) timeout -s 9 2 ../source/tcas.exe  944 1 1 4283  251 3431 2  639  641 1 0 1     > ../outputs/t189
    if diff ../outputs/t189 ../originals/t189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p190) timeout -s 9 2 ../source/tcas.exe  768 0 0  889  193 4424 3  740  740 1 1 0     > ../outputs/t190
    if diff ../outputs/t190 ../originals/t190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p191) timeout -s 9 2 ../source/tcas.exe  857 0 1  574  409 3712 2  501  501 1 1 0     > ../outputs/t191
    if diff ../outputs/t191 ../originals/t191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p192) timeout -s 9 2 ../source/tcas.exe  659 1 0  781   18  271 3  399  499 1 0 1     > ../outputs/t192
    if diff ../outputs/t192 ../originals/t192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p193) timeout -s 9 2 ../source/tcas.exe  827 1 1 1935  339  968 0  399  740 0 1 1     > ../outputs/t193
    if diff ../outputs/t193 ../originals/t193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p194) timeout -s 9 2 ../source/tcas.exe  768 1 1 2197  496 5257 1  639  399 0 0 0     > ../outputs/t194
    if diff ../outputs/t194 ../originals/t194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p195) timeout -s 9 2 ../source/tcas.exe  684 1 1 5744  499  870 3  741  739 1 1 1     > ../outputs/t195
    if diff ../outputs/t195 ../originals/t195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p196) timeout -s 9 2 ../source/tcas.exe  722 1 0  201  343  665 1  639  499 1 1 0     > ../outputs/t196
    if diff ../outputs/t196 ../originals/t196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p197) timeout -s 9 2 ../source/tcas.exe  571 1 0  397  173 2247 2  641  499 1 0 1     > ../outputs/t197
    if diff ../outputs/t197 ../originals/t197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p198) timeout -s 9 2 ../source/tcas.exe  956 0 1 3698   70  717 3  399  499 1 0 1     > ../outputs/t198
    if diff ../outputs/t198 ../originals/t198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p199) timeout -s 9 2 ../source/tcas.exe  850 1 1 4146  473  899 1  740  500 1 0 0     > ../outputs/t199
    if diff ../outputs/t199 ../originals/t199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p200) timeout -s 9 2 ../source/tcas.exe  642 1 1 3494  125 2158 0  500  400 1 0 1     > ../outputs/t200
    if diff ../outputs/t200 ../originals/t200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p201) timeout -s 9 2 ../source/tcas.exe  628 1 0 2784    4 3034 3  399  399 1 0 0     > ../outputs/t201
    if diff ../outputs/t201 ../originals/t201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p202) timeout -s 9 2 ../source/tcas.exe  838 0 0 5849  266 1016 2  401  500 0 0 0     > ../outputs/t202
    if diff ../outputs/t202 ../originals/t202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p203) timeout -s 9 2 ../source/tcas.exe  824 1 1 1917   99  850 3  739  739 0 0 1     > ../outputs/t203
    if diff ../outputs/t203 ../originals/t203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p204) timeout -s 9 2 ../source/tcas.exe  686 0 0 1705  525 5369 1  641  401 0 1 0     > ../outputs/t204
    if diff ../outputs/t204 ../originals/t204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p205) timeout -s 9 2 ../source/tcas.exe  934 0 1  372  159 1322 1  401  639 1 1 0     > ../outputs/t205
    if diff ../outputs/t205 ../originals/t205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p206) timeout -s 9 2 ../source/tcas.exe  999 0 0 3577   27 4795 0  641  500 1 1 0     > ../outputs/t206
    if diff ../outputs/t206 ../originals/t206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p207) timeout -s 9 2 ../source/tcas.exe  738 0 1  573  548  268 3  499  741 1 1 0     > ../outputs/t207
    if diff ../outputs/t207 ../originals/t207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p208) timeout -s 9 2 ../source/tcas.exe  988 1 0 5692  580 4270 0  639  639 1 0 1     > ../outputs/t208
    if diff ../outputs/t208 ../originals/t208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p209) timeout -s 9 2 ../source/tcas.exe  762 0 0 1874  205 4933 3  399  641 1 0 1     > ../outputs/t209
    if diff ../outputs/t209 ../originals/t209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p210) timeout -s 9 2 ../source/tcas.exe  540 1 1  122  460 5776 2  640  740 1 0 1     > ../outputs/t210
    if diff ../outputs/t210 ../originals/t210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p211) timeout -s 9 2 ../source/tcas.exe  745 1 1 5728  191 2829 1  401  640 0 1 0     > ../outputs/t211
    if diff ../outputs/t211 ../originals/t211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p212) timeout -s 9 2 ../source/tcas.exe 1000 1 0  177  288 5884 3  401  640 0 0 1     > ../outputs/t212
    if diff ../outputs/t212 ../originals/t212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p213) timeout -s 9 2 ../source/tcas.exe  638 1 0 2578  156 3757 0  500  399 1 0 0     > ../outputs/t213
    if diff ../outputs/t213 ../originals/t213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p214) timeout -s 9 2 ../source/tcas.exe  919 0 1  131  300 3506 0  641  501 0 0 1     > ../outputs/t214
    if diff ../outputs/t214 ../originals/t214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p215) timeout -s 9 2 ../source/tcas.exe  874 0 0 5644  103 4207 3  399  740 1 0 0     > ../outputs/t215
    if diff ../outputs/t215 ../originals/t215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p216) timeout -s 9 2 ../source/tcas.exe  848 1 1 2141  138 2142 1  500  399 1 1 0     > ../outputs/t216
    if diff ../outputs/t216 ../originals/t216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p217) timeout -s 9 2 ../source/tcas.exe  910 1 0  427  162 2489 2  740  741 0 0 1     > ../outputs/t217
    if diff ../outputs/t217 ../originals/t217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p218) timeout -s 9 2 ../source/tcas.exe  838 1 0 2922  557  983 1  740  640 0 0 1     > ../outputs/t218
    if diff ../outputs/t218 ../originals/t218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p219) timeout -s 9 2 ../source/tcas.exe  913 0 1  452  437  263 1  741  741 1 1 1     > ../outputs/t219
    if diff ../outputs/t219 ../originals/t219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p220) timeout -s 9 2 ../source/tcas.exe  776 0 1  798  308 3693 0  400  741 0 0 0     > ../outputs/t220
    if diff ../outputs/t220 ../originals/t220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p221) timeout -s 9 2 ../source/tcas.exe  556 0 0 5915  151  482 2  400  739 1 0 0     > ../outputs/t221
    if diff ../outputs/t221 ../originals/t221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p222) timeout -s 9 2 ../source/tcas.exe  974 0 1  420  156 5924 0  741  400 0 0 1     > ../outputs/t222
    if diff ../outputs/t222 ../originals/t222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p223) timeout -s 9 2 ../source/tcas.exe  781 1 0  930  207 4163 1  639  399 0 0 0     > ../outputs/t223
    if diff ../outputs/t223 ../originals/t223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p224) timeout -s 9 2 ../source/tcas.exe  916 0 1 1828   43 3898 3  499  640 0 1 0     > ../outputs/t224
    if diff ../outputs/t224 ../originals/t224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p225) timeout -s 9 2 ../source/tcas.exe  813 0 0 1259   55  662 1  399  501 0 1 1     > ../outputs/t225
    if diff ../outputs/t225 ../originals/t225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p226) timeout -s 9 2 ../source/tcas.exe  822 0 0 1474   38 1377 3  641  640 1 0 0     > ../outputs/t226
    if diff ../outputs/t226 ../originals/t226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p227) timeout -s 9 2 ../source/tcas.exe  538 0 0  186  548 2387 0  739  639 0 0 0     > ../outputs/t227
    if diff ../outputs/t227 ../originals/t227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p228) timeout -s 9 2 ../source/tcas.exe  983 1 1 4732   69 1731 2  640  739 1 0 1     > ../outputs/t228
    if diff ../outputs/t228 ../originals/t228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p229) timeout -s 9 2 ../source/tcas.exe  685 1 0  117   74 5136 0  640  639 1 1 0     > ../outputs/t229
    if diff ../outputs/t229 ../originals/t229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p230) timeout -s 9 2 ../source/tcas.exe  660 1 1 4014  407  561 3  501  400 0 1 1     > ../outputs/t230
    if diff ../outputs/t230 ../originals/t230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p231) timeout -s 9 2 ../source/tcas.exe  535 0 0 1871   69 5220 2  500  641 0 1 1     > ../outputs/t231
    if diff ../outputs/t231 ../originals/t231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p232) timeout -s 9 2 ../source/tcas.exe  651 0 1  703  399   62 3  741  641 1 1 0     > ../outputs/t232
    if diff ../outputs/t232 ../originals/t232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p233) timeout -s 9 2 ../source/tcas.exe  868 0 0 2014  577 1420 1  740  401 1 0 0     > ../outputs/t233
    if diff ../outputs/t233 ../originals/t233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p234) timeout -s 9 2 ../source/tcas.exe  760 0 0  104  113 1610 3  741  401 1 0 1     > ../outputs/t234
    if diff ../outputs/t234 ../originals/t234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p235) timeout -s 9 2 ../source/tcas.exe  856 0 1 4927  182 3316 0  741  740 0 0 1     > ../outputs/t235
    if diff ../outputs/t235 ../originals/t235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p236) timeout -s 9 2 ../source/tcas.exe  874 0 0 3373  525 1643 2  399  641 1 1 0     > ../outputs/t236
    if diff ../outputs/t236 ../originals/t236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p237) timeout -s 9 2 ../source/tcas.exe  844 1 1 3839   76 2610 1  740  640 0 1 0     > ../outputs/t237
    if diff ../outputs/t237 ../originals/t237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p238) timeout -s 9 2 ../source/tcas.exe  782 1 1  263  499 1160 0  641  740 1 1 1     > ../outputs/t238
    if diff ../outputs/t238 ../originals/t238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p239) timeout -s 9 2 ../source/tcas.exe  679 0 0  279  453  454 1  641  499 0 0 1     > ../outputs/t239
    if diff ../outputs/t239 ../originals/t239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p240) timeout -s 9 2 ../source/tcas.exe  898 1 0 2193   11 2865 2  741  641 0 1 1     > ../outputs/t240
    if diff ../outputs/t240 ../originals/t240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p241) timeout -s 9 2 ../source/tcas.exe  878 1 0 2425  103  556 1  740  739 1 0 0     > ../outputs/t241
    if diff ../outputs/t241 ../originals/t241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p242) timeout -s 9 2 ../source/tcas.exe  743 1 0 1305  269  942 1  740  501 0 0 1     > ../outputs/t242
    if diff ../outputs/t242 ../originals/t242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p243) timeout -s 9 2 ../source/tcas.exe  953 0 1 2935  224 2070 3  499  641 0 1 0     > ../outputs/t243
    if diff ../outputs/t243 ../originals/t243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p244) timeout -s 9 2 ../source/tcas.exe  897 1 1 2226  306 3860 3  740  641 0 0 1     > ../outputs/t244
    if diff ../outputs/t244 ../originals/t244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p245) timeout -s 9 2 ../source/tcas.exe  733 0 1  367   18 1266 1  499  399 0 0 1     > ../outputs/t245
    if diff ../outputs/t245 ../originals/t245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p246) timeout -s 9 2 ../source/tcas.exe  643 1 1 5514  362 2288 1  400  741 1 1 0     > ../outputs/t246
    if diff ../outputs/t246 ../originals/t246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p247) timeout -s 9 2 ../source/tcas.exe  541 0 1 5231  502 1059 1  399  639 0 0 0     > ../outputs/t247
    if diff ../outputs/t247 ../originals/t247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p248) timeout -s 9 2 ../source/tcas.exe  598 0 0 3491  413 5933 3  741  401 0 0 0     > ../outputs/t248
    if diff ../outputs/t248 ../originals/t248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p249) timeout -s 9 2 ../source/tcas.exe  750 1 1  682  313 4253 2  499  740 0 0 1     > ../outputs/t249
    if diff ../outputs/t249 ../originals/t249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p250) timeout -s 9 2 ../source/tcas.exe  563 1 1 4688  587  773 3  640  639 0 0 0     > ../outputs/t250
    if diff ../outputs/t250 ../originals/t250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p251) timeout -s 9 2 ../source/tcas.exe  544 0 0 4467  603 5942 1  501  640 0 0 0     > ../outputs/t251
    if diff ../outputs/t251 ../originals/t251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p252) timeout -s 9 2 ../source/tcas.exe  661 1 1 1802  117 1355 3  400  499 0 1 0     > ../outputs/t252
    if diff ../outputs/t252 ../originals/t252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p253) timeout -s 9 2 ../source/tcas.exe  880 0 1  412  407  936 1  401  739 1 0 1     > ../outputs/t253
    if diff ../outputs/t253 ../originals/t253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p254) timeout -s 9 2 ../source/tcas.exe  832 0 0  375  147 2068 0  739  741 0 1 1     > ../outputs/t254
    if diff ../outputs/t254 ../originals/t254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p255) timeout -s 9 2 ../source/tcas.exe  751 1 1 1924  408 2617 0  639  640 1 1 1     > ../outputs/t255
    if diff ../outputs/t255 ../originals/t255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p256) timeout -s 9 2 ../source/tcas.exe  698 0 0  990  464 5856 3  640  501 1 0 0     > ../outputs/t256
    if diff ../outputs/t256 ../originals/t256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p257) timeout -s 9 2 ../source/tcas.exe  858 0 1 1894  242  772 3  400  639 0 1 0     > ../outputs/t257
    if diff ../outputs/t257 ../originals/t257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p258) timeout -s 9 2 ../source/tcas.exe  798 0 1 5229  263 1740 0  740  401 1 1 0     > ../outputs/t258
    if diff ../outputs/t258 ../originals/t258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p259) timeout -s 9 2 ../source/tcas.exe  710 1 1 5993  315  239 1  641  401 0 1 1     > ../outputs/t259
    if diff ../outputs/t259 ../originals/t259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p260) timeout -s 9 2 ../source/tcas.exe  743 1 1 3478  260 1672 1  400  499 1 0 0     > ../outputs/t260
    if diff ../outputs/t260 ../originals/t260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p261) timeout -s 9 2 ../source/tcas.exe  745 0 0 2069  495 3141 3  501  501 1 1 1     > ../outputs/t261
    if diff ../outputs/t261 ../originals/t261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p262) timeout -s 9 2 ../source/tcas.exe  865 0 1  796  147  444 0  499  400 1 1 1     > ../outputs/t262
    if diff ../outputs/t262 ../originals/t262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p263) timeout -s 9 2 ../source/tcas.exe  554 1 1 2815  476 1600 3  641  401 0 1 1     > ../outputs/t263
    if diff ../outputs/t263 ../originals/t263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p264) timeout -s 9 2 ../source/tcas.exe  536 0 0 3139  164 5669 1  399  501 0 0 1     > ../outputs/t264
    if diff ../outputs/t264 ../originals/t264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p265) timeout -s 9 2 ../source/tcas.exe  849 0 1 4435  344  969 3  399  401 0 1 0     > ../outputs/t265
    if diff ../outputs/t265 ../originals/t265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p266) timeout -s 9 2 ../source/tcas.exe  715 1 1 1085  409 1577 3  640  740 0 1 0     > ../outputs/t266
    if diff ../outputs/t266 ../originals/t266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p267) timeout -s 9 2 ../source/tcas.exe  726 1 0 1021  340 5644 2  641  399 0 0 0     > ../outputs/t267
    if diff ../outputs/t267 ../originals/t267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p268) timeout -s 9 2 ../source/tcas.exe  974 0 0 1091  325   69 3  501  741 1 0 0     > ../outputs/t268
    if diff ../outputs/t268 ../originals/t268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p269) timeout -s 9 2 ../source/tcas.exe  584 1 0  679   53  117 1  739  401 0 1 1     > ../outputs/t269
    if diff ../outputs/t269 ../originals/t269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p270) timeout -s 9 2 ../source/tcas.exe  998 1 0 2921  563  904 1  499  641 1 0 0     > ../outputs/t270
    if diff ../outputs/t270 ../originals/t270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p271) timeout -s 9 2 ../source/tcas.exe  786 1 0  383  548 5870 0  639  399 1 0 1     > ../outputs/t271
    if diff ../outputs/t271 ../originals/t271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p272) timeout -s 9 2 ../source/tcas.exe  809 0 0  108  413  343 3  401  399 1 0 1     > ../outputs/t272
    if diff ../outputs/t272 ../originals/t272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p273) timeout -s 9 2 ../source/tcas.exe  873 1 0 2763    4  208 3  741  401 0 0 1     > ../outputs/t273
    if diff ../outputs/t273 ../originals/t273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p274) timeout -s 9 2 ../source/tcas.exe  523 1 0 5002  473  909 3  499  501 0 0 0     > ../outputs/t274
    if diff ../outputs/t274 ../originals/t274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p275) timeout -s 9 2 ../source/tcas.exe  982 1 1  927  524 5556 2  500  501 1 1 1     > ../outputs/t275
    if diff ../outputs/t275 ../originals/t275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p276) timeout -s 9 2 ../source/tcas.exe  921 1 0 2049  162 1259 3  401  641 1 0 1     > ../outputs/t276
    if diff ../outputs/t276 ../originals/t276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p277) timeout -s 9 2 ../source/tcas.exe  679 1 1 3180  297 5750 3  739  400 0 0 0     > ../outputs/t277
    if diff ../outputs/t277 ../originals/t277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p278) timeout -s 9 2 ../source/tcas.exe  755 0 0 2949  565 2031 0  399  741 1 1 0     > ../outputs/t278
    if diff ../outputs/t278 ../originals/t278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p279) timeout -s 9 2 ../source/tcas.exe  643 0 1 1976  129  124 1  499  641 0 0 1     > ../outputs/t279
    if diff ../outputs/t279 ../originals/t279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p280) timeout -s 9 2 ../source/tcas.exe  815 0 0  836  295 1267 3  739  499 1 0 0     > ../outputs/t280
    if diff ../outputs/t280 ../originals/t280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p281) timeout -s 9 2 ../source/tcas.exe  677 1 0 4864  257 5470 1  501  399 0 1 0     > ../outputs/t281
    if diff ../outputs/t281 ../originals/t281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p282) timeout -s 9 2 ../source/tcas.exe  986 1 1 1534  145 2736 3  641  401 0 0 0     > ../outputs/t282
    if diff ../outputs/t282 ../originals/t282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p283) timeout -s 9 2 ../source/tcas.exe  841 1 1  670  226 4140 1  640  740 0 1 1     > ../outputs/t283
    if diff ../outputs/t283 ../originals/t283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p284) timeout -s 9 2 ../source/tcas.exe  960 0 1 5487  575 2958 0  400  500 1 0 1     > ../outputs/t284
    if diff ../outputs/t284 ../originals/t284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p285) timeout -s 9 2 ../source/tcas.exe  945 1 1 1426  406  555 2  401  739 1 1 0     > ../outputs/t285
    if diff ../outputs/t285 ../originals/t285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p286) timeout -s 9 2 ../source/tcas.exe  587 0 0 3575    5  815 0  639  739 1 1 0     > ../outputs/t286
    if diff ../outputs/t286 ../originals/t286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p287) timeout -s 9 2 ../source/tcas.exe  816 1 1 5118  231 4376 1  500  499 0 1 1     > ../outputs/t287
    if diff ../outputs/t287 ../originals/t287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p288) timeout -s 9 2 ../source/tcas.exe  772 1 1 2007  377  416 1  401  639 1 0 1     > ../outputs/t288
    if diff ../outputs/t288 ../originals/t288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p289) timeout -s 9 2 ../source/tcas.exe  802 0 1 3169  150 4244 2  739  400 0 0 1     > ../outputs/t289
    if diff ../outputs/t289 ../originals/t289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p290) timeout -s 9 2 ../source/tcas.exe  745 1 0   85  144 5206 3  401  499 1 0 0     > ../outputs/t290
    if diff ../outputs/t290 ../originals/t290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p291) timeout -s 9 2 ../source/tcas.exe  944 0 0 2065  348  818 2  640  739 0 1 0     > ../outputs/t291
    if diff ../outputs/t291 ../originals/t291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p292) timeout -s 9 2 ../source/tcas.exe  937 1 1 5273  326  878 1  640  641 1 1 1     > ../outputs/t292
    if diff ../outputs/t292 ../originals/t292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p293) timeout -s 9 2 ../source/tcas.exe  594 0 1  574  103  969 2  499  399 0 0 1     > ../outputs/t293
    if diff ../outputs/t293 ../originals/t293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p294) timeout -s 9 2 ../source/tcas.exe  725 1 1 2766  354 4811 3  641  501 1 1 0     > ../outputs/t294
    if diff ../outputs/t294 ../originals/t294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p295) timeout -s 9 2 ../source/tcas.exe  523 1 1  877  601 5608 1  639  400 0 0 0     > ../outputs/t295
    if diff ../outputs/t295 ../originals/t295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p296) timeout -s 9 2 ../source/tcas.exe  931 1 0 5113   72 3242 3  400  639 1 1 0     > ../outputs/t296
    if diff ../outputs/t296 ../originals/t296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p297) timeout -s 9 2 ../source/tcas.exe  716 1 0 5046  323 3839 1  639  500 0 1 0     > ../outputs/t297
    if diff ../outputs/t297 ../originals/t297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p298) timeout -s 9 2 ../source/tcas.exe  893 1 0 5078  256 3944 1  500  641 0 0 1     > ../outputs/t298
    if diff ../outputs/t298 ../originals/t298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p299) timeout -s 9 2 ../source/tcas.exe  819 0 0 3878  331 5704 3  740  499 1 1 0     > ../outputs/t299
    if diff ../outputs/t299 ../originals/t299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p300) timeout -s 9 2 ../source/tcas.exe  611 0 0 1509   98  667 3  739  399 1 1 1     > ../outputs/t300
    if diff ../outputs/t300 ../originals/t300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p301) timeout -s 9 2 ../source/tcas.exe  574 0 1 2060  111 2572 3  500  641 0 0 0     > ../outputs/t301
    if diff ../outputs/t301 ../originals/t301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p302) timeout -s 9 2 ../source/tcas.exe  989 1 0 1208   55 4201 2  499  400 1 1 1     > ../outputs/t302
    if diff ../outputs/t302 ../originals/t302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p303) timeout -s 9 2 ../source/tcas.exe  895 1 1  985  483 3388 2  501  400 1 0 0     > ../outputs/t303
    if diff ../outputs/t303 ../originals/t303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p304) timeout -s 9 2 ../source/tcas.exe  724 0 1 1495  597 5243 0  640  500 1 1 0     > ../outputs/t304
    if diff ../outputs/t304 ../originals/t304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p305) timeout -s 9 2 ../source/tcas.exe  932 1 1 3456  557  571 2  640  400 0 0 0     > ../outputs/t305
    if diff ../outputs/t305 ../originals/t305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p306) timeout -s 9 2 ../source/tcas.exe  521 1 0 1907  348 2633 0  499  501 0 1 0     > ../outputs/t306
    if diff ../outputs/t306 ../originals/t306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p307) timeout -s 9 2 ../source/tcas.exe  608 1 1  674  216  442 0  741  400 0 0 0     > ../outputs/t307
    if diff ../outputs/t307 ../originals/t307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p308) timeout -s 9 2 ../source/tcas.exe  589 0 1 3817  593  223 3  400  641 1 1 1     > ../outputs/t308
    if diff ../outputs/t308 ../originals/t308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p309) timeout -s 9 2 ../source/tcas.exe  841 0 1 3618  311 1559 1  400  739 1 0 1     > ../outputs/t309
    if diff ../outputs/t309 ../originals/t309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p310) timeout -s 9 2 ../source/tcas.exe  746 1 0  121  246  362 1  401  640 1 1 0     > ../outputs/t310
    if diff ../outputs/t310 ../originals/t310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p311) timeout -s 9 2 ../source/tcas.exe  628 1 0 5645  573 1477 2  501  399 1 1 0     > ../outputs/t311
    if diff ../outputs/t311 ../originals/t311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p312) timeout -s 9 2 ../source/tcas.exe  845 1 0  805  521  374 3  499  740 1 0 1     > ../outputs/t312
    if diff ../outputs/t312 ../originals/t312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p313) timeout -s 9 2 ../source/tcas.exe  690 0 1 4135  106 3520 1  499  639 1 0 1     > ../outputs/t313
    if diff ../outputs/t313 ../originals/t313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p314) timeout -s 9 2 ../source/tcas.exe  548 1 1 2625  249 1679 0  641  501 1 1 1     > ../outputs/t314
    if diff ../outputs/t314 ../originals/t314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p315) timeout -s 9 2 ../source/tcas.exe  763 0 0  907  444 1881 0  741  399 0 0 1     > ../outputs/t315
    if diff ../outputs/t315 ../originals/t315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p316) timeout -s 9 2 ../source/tcas.exe  750 1 1 1730  298   60 0  640  500 0 0 0     > ../outputs/t316
    if diff ../outputs/t316 ../originals/t316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p317) timeout -s 9 2 ../source/tcas.exe  653 1 0 1707  280 3904 3  501  740 0 0 1     > ../outputs/t317
    if diff ../outputs/t317 ../originals/t317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p318) timeout -s 9 2 ../source/tcas.exe  697 0 0  539  241 2597 3  640  741 0 1 0     > ../outputs/t318
    if diff ../outputs/t318 ../originals/t318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p319) timeout -s 9 2 ../source/tcas.exe  556 1 1  351    9  281 3  741  639 0 0 1     > ../outputs/t319
    if diff ../outputs/t319 ../originals/t319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p320) timeout -s 9 2 ../source/tcas.exe  789 0 0 3283  354 1116 2  640  400 0 0 0     > ../outputs/t320
    if diff ../outputs/t320 ../originals/t320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p321) timeout -s 9 2 ../source/tcas.exe  717 0 0 3436  374 1439 2  640  740 1 1 0     > ../outputs/t321
    if diff ../outputs/t321 ../originals/t321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p322) timeout -s 9 2 ../source/tcas.exe  596 0 0 5238  574  857 3  739  501 1 1 0     > ../outputs/t322
    if diff ../outputs/t322 ../originals/t322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p323) timeout -s 9 2 ../source/tcas.exe  767 0 1 2316  399 3575 0  499  501 0 1 1     > ../outputs/t323
    if diff ../outputs/t323 ../originals/t323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p324) timeout -s 9 2 ../source/tcas.exe  806 1 0 2197  495 5711 0  401  739 0 0 1     > ../outputs/t324
    if diff ../outputs/t324 ../originals/t324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p325) timeout -s 9 2 ../source/tcas.exe  593 0 1  765  481 3711 0  500  641 1 0 1     > ../outputs/t325
    if diff ../outputs/t325 ../originals/t325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p326) timeout -s 9 2 ../source/tcas.exe  955 0 1 1836  542 3698 3  500  401 1 0 0     > ../outputs/t326
    if diff ../outputs/t326 ../originals/t326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p327) timeout -s 9 2 ../source/tcas.exe  622 1 1 3661   13  223 1  499  739 0 1 0     > ../outputs/t327
    if diff ../outputs/t327 ../originals/t327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p328) timeout -s 9 2 ../source/tcas.exe  719 0 0 5273  196 3585 1  740  740 1 1 1     > ../outputs/t328
    if diff ../outputs/t328 ../originals/t328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p329) timeout -s 9 2 ../source/tcas.exe  772 0 1 3773   87 4375 1  639  400 1 0 1     > ../outputs/t329
    if diff ../outputs/t329 ../originals/t329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p330) timeout -s 9 2 ../source/tcas.exe  612 1 0 4829    4  200 1  399  500 1 1 1     > ../outputs/t330
    if diff ../outputs/t330 ../originals/t330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p331) timeout -s 9 2 ../source/tcas.exe  694 1 1 3238   81 1642 1  500  739 0 0 0     > ../outputs/t331
    if diff ../outputs/t331 ../originals/t331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p332) timeout -s 9 2 ../source/tcas.exe  564 0 0  417  556 3138 0  741  639 1 0 0     > ../outputs/t332
    if diff ../outputs/t332 ../originals/t332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p333) timeout -s 9 2 ../source/tcas.exe  994 0 0 3682  579   39 0  400  740 1 1 1     > ../outputs/t333
    if diff ../outputs/t333 ../originals/t333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p334) timeout -s 9 2 ../source/tcas.exe  689 1 0 5258  331 1464 2  640  501 0 1 1     > ../outputs/t334
    if diff ../outputs/t334 ../originals/t334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p335) timeout -s 9 2 ../source/tcas.exe  971 1 0  383  189 4986 3  739  501 0 0 0     > ../outputs/t335
    if diff ../outputs/t335 ../originals/t335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p336) timeout -s 9 2 ../source/tcas.exe  775 0 1  865  102 2303 3  401  401 1 1 1     > ../outputs/t336
    if diff ../outputs/t336 ../originals/t336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p337) timeout -s 9 2 ../source/tcas.exe  612 0 1 3691  242  485 1  401  500 1 0 0     > ../outputs/t337
    if diff ../outputs/t337 ../originals/t337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p338) timeout -s 9 2 ../source/tcas.exe  980 1 1  904  214 2419 1  400  641 1 0 1     > ../outputs/t338
    if diff ../outputs/t338 ../originals/t338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p339) timeout -s 9 2 ../source/tcas.exe  785 1 0 2740  421  162 3  741  741 1 0 0     > ../outputs/t339
    if diff ../outputs/t339 ../originals/t339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p340) timeout -s 9 2 ../source/tcas.exe  546 0 0 2569  544 2947 0  399  640 1 0 1     > ../outputs/t340
    if diff ../outputs/t340 ../originals/t340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p341) timeout -s 9 2 ../source/tcas.exe  886 0 0 2059  459  274 1  401  641 1 1 1     > ../outputs/t341
    if diff ../outputs/t341 ../originals/t341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p342) timeout -s 9 2 ../source/tcas.exe  889 0 0 3799  100 4302 1  499  640 1 0 1     > ../outputs/t342
    if diff ../outputs/t342 ../originals/t342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p343) timeout -s 9 2 ../source/tcas.exe  698 1 1 4165  477 5526 2  641  500 1 1 0     > ../outputs/t343
    if diff ../outputs/t343 ../originals/t343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p344) timeout -s 9 2 ../source/tcas.exe  644 0 1 2518  298  896 2  401  500 1 0 1     > ../outputs/t344
    if diff ../outputs/t344 ../originals/t344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p345) timeout -s 9 2 ../source/tcas.exe  843 0 1 1935    2 4489 0  499  401 0 0 0     > ../outputs/t345
    if diff ../outputs/t345 ../originals/t345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p346) timeout -s 9 2 ../source/tcas.exe  577 1 1 2046  389  495 0  740  501 0 1 1     > ../outputs/t346
    if diff ../outputs/t346 ../originals/t346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p347) timeout -s 9 2 ../source/tcas.exe  856 1 1 2716  320 1742 2  641  401 1 1 0     > ../outputs/t347
    if diff ../outputs/t347 ../originals/t347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p348) timeout -s 9 2 ../source/tcas.exe  900 1 0 3346  507  663 2  640  639 0 0 1     > ../outputs/t348
    if diff ../outputs/t348 ../originals/t348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p349) timeout -s 9 2 ../source/tcas.exe  995 0 1 3499   70 1262 1  640  399 0 0 0     > ../outputs/t349
    if diff ../outputs/t349 ../originals/t349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p350) timeout -s 9 2 ../source/tcas.exe  656 0 1 4956  595 2307 2  501  741 0 0 1     > ../outputs/t350
    if diff ../outputs/t350 ../originals/t350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p351) timeout -s 9 2 ../source/tcas.exe  878 0 1 4939  250 1842 2  640  400 1 0 0     > ../outputs/t351
    if diff ../outputs/t351 ../originals/t351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p352) timeout -s 9 2 ../source/tcas.exe  591 1 1 1124  287 2790 2  640  501 1 1 1     > ../outputs/t352
    if diff ../outputs/t352 ../originals/t352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p353) timeout -s 9 2 ../source/tcas.exe  785 0 1 2802  447 2187 1  400  740 1 1 1     > ../outputs/t353
    if diff ../outputs/t353 ../originals/t353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p354) timeout -s 9 2 ../source/tcas.exe  904 1 1 2361  527  419 2  401  400 1 1 1     > ../outputs/t354
    if diff ../outputs/t354 ../originals/t354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p355) timeout -s 9 2 ../source/tcas.exe  619 1 0  197  287 4568 2  500  499 0 0 1     > ../outputs/t355
    if diff ../outputs/t355 ../originals/t355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p356) timeout -s 9 2 ../source/tcas.exe  928 1 1  380  232 5117 1  740  499 0 0 0     > ../outputs/t356
    if diff ../outputs/t356 ../originals/t356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p357) timeout -s 9 2 ../source/tcas.exe  860 1 1  602  331 5657 3  639  740 1 1 0     > ../outputs/t357
    if diff ../outputs/t357 ../originals/t357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p358) timeout -s 9 2 ../source/tcas.exe  661 0 0  767   26 5316 3  640  399 0 1 1     > ../outputs/t358
    if diff ../outputs/t358 ../originals/t358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p359) timeout -s 9 2 ../source/tcas.exe  534 1 0 5360  149 1528 3  740  499 1 1 0     > ../outputs/t359
    if diff ../outputs/t359 ../originals/t359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p360) timeout -s 9 2 ../source/tcas.exe  774 1 1 1231  234   61 2  400  500 1 1 1     > ../outputs/t360
    if diff ../outputs/t360 ../originals/t360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p361) timeout -s 9 2 ../source/tcas.exe  804 0 1 3514  152 1152 1  740  501 1 1 1     > ../outputs/t361
    if diff ../outputs/t361 ../originals/t361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p362) timeout -s 9 2 ../source/tcas.exe  887 0 0 1725  477 2346 2  741  739 1 0 0     > ../outputs/t362
    if diff ../outputs/t362 ../originals/t362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p363) timeout -s 9 2 ../source/tcas.exe  808 1 1  946  546  661 1  400  640 0 1 0     > ../outputs/t363
    if diff ../outputs/t363 ../originals/t363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p364) timeout -s 9 2 ../source/tcas.exe  800 1 0 2067  586  284 3  740  499 0 0 1     > ../outputs/t364
    if diff ../outputs/t364 ../originals/t364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p365) timeout -s 9 2 ../source/tcas.exe  811 0 0 2117  222 3074 3  501  399 1 0 1     > ../outputs/t365
    if diff ../outputs/t365 ../originals/t365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p366) timeout -s 9 2 ../source/tcas.exe  661 0 0  963  177 5207 3  499  400 1 0 0     > ../outputs/t366
    if diff ../outputs/t366 ../originals/t366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p367) timeout -s 9 2 ../source/tcas.exe  995 0 0 2133  218  905 1  501  501 0 0 1     > ../outputs/t367
    if diff ../outputs/t367 ../originals/t367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p368) timeout -s 9 2 ../source/tcas.exe  788 0 0  113  177 2105 2  501  741 0 1 1     > ../outputs/t368
    if diff ../outputs/t368 ../originals/t368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p369) timeout -s 9 2 ../source/tcas.exe  906 0 0 4284  439  111 2  740  740 0 1 1     > ../outputs/t369
    if diff ../outputs/t369 ../originals/t369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p370) timeout -s 9 2 ../source/tcas.exe  537 0 1 1397  427 1241 1  739  740 0 1 0     > ../outputs/t370
    if diff ../outputs/t370 ../originals/t370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p371) timeout -s 9 2 ../source/tcas.exe  876 1 1  508  401  271 0  401  400 1 0 0     > ../outputs/t371
    if diff ../outputs/t371 ../originals/t371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p372) timeout -s 9 2 ../source/tcas.exe  548 1 0 2001  399  523 0  741  739 0 0 0     > ../outputs/t372
    if diff ../outputs/t372 ../originals/t372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p373) timeout -s 9 2 ../source/tcas.exe  801 0 1 5536  450  504 2  741  740 0 0 1     > ../outputs/t373
    if diff ../outputs/t373 ../originals/t373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p374) timeout -s 9 2 ../source/tcas.exe  921 0 1 2166  315 3826 0  739  500 1 1 1     > ../outputs/t374
    if diff ../outputs/t374 ../originals/t374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p375) timeout -s 9 2 ../source/tcas.exe  958 0 0 1971  138 4932 2  400  640 0 0 1     > ../outputs/t375
    if diff ../outputs/t375 ../originals/t375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p376) timeout -s 9 2 ../source/tcas.exe  661 1 1   23  469 2852 1  400  500 1 1 1     > ../outputs/t376
    if diff ../outputs/t376 ../originals/t376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p377) timeout -s 9 2 ../source/tcas.exe  878 0 1 5906  588 3803 2  499  399 0 0 1     > ../outputs/t377
    if diff ../outputs/t377 ../originals/t377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p378) timeout -s 9 2 ../source/tcas.exe  664 1 0 3757   24 2579 1  499  739 0 1 1     > ../outputs/t378
    if diff ../outputs/t378 ../originals/t378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p379) timeout -s 9 2 ../source/tcas.exe  564 1 0  463  166  199 2  500  640 1 1 0     > ../outputs/t379
    if diff ../outputs/t379 ../originals/t379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p380) timeout -s 9 2 ../source/tcas.exe  787 0 1 3296  306  326 3  741  639 1 1 0     > ../outputs/t380
    if diff ../outputs/t380 ../originals/t380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p381) timeout -s 9 2 ../source/tcas.exe  843 0 1  154  327 2365 0  640  499 0 0 0     > ../outputs/t381
    if diff ../outputs/t381 ../originals/t381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p382) timeout -s 9 2 ../source/tcas.exe  669 1 0  287  436 2803 3  740  400 1 1 1     > ../outputs/t382
    if diff ../outputs/t382 ../originals/t382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p383) timeout -s 9 2 ../source/tcas.exe  734 0 0 2049  280 5472 0  399  499 0 0 0     > ../outputs/t383
    if diff ../outputs/t383 ../originals/t383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p384) timeout -s 9 2 ../source/tcas.exe  578 1 0 1170  526 4785 1  399  741 1 0 1     > ../outputs/t384
    if diff ../outputs/t384 ../originals/t384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p385) timeout -s 9 2 ../source/tcas.exe  541 1 0 3553  365  687 0  400  741 1 1 0     > ../outputs/t385
    if diff ../outputs/t385 ../originals/t385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p386) timeout -s 9 2 ../source/tcas.exe  530 0 1  129  519 1555 1  501  640 0 1 0     > ../outputs/t386
    if diff ../outputs/t386 ../originals/t386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p387) timeout -s 9 2 ../source/tcas.exe  847 0 1 2379  193 4481 0  641  741 0 0 0     > ../outputs/t387
    if diff ../outputs/t387 ../originals/t387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p388) timeout -s 9 2 ../source/tcas.exe  867 1 1 1211  581  153 2  640  641 1 1 1     > ../outputs/t388
    if diff ../outputs/t388 ../originals/t388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p389) timeout -s 9 2 ../source/tcas.exe  607 1 1 4250   14 4883 2  399  641 1 0 0     > ../outputs/t389
    if diff ../outputs/t389 ../originals/t389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p390) timeout -s 9 2 ../source/tcas.exe  558 0 1   84  275 4457 1  501  401 1 0 1     > ../outputs/t390
    if diff ../outputs/t390 ../originals/t390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p391) timeout -s 9 2 ../source/tcas.exe  526 0 1  751  595 2071 3  400  641 1 0 0     > ../outputs/t391
    if diff ../outputs/t391 ../originals/t391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p392) timeout -s 9 2 ../source/tcas.exe  745 0 1  730  516  245 1  641  399 1 1 0     > ../outputs/t392
    if diff ../outputs/t392 ../originals/t392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p393) timeout -s 9 2 ../source/tcas.exe  812 1 0 4165   80  690 0  741  401 0 1 1     > ../outputs/t393
    if diff ../outputs/t393 ../originals/t393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p394) timeout -s 9 2 ../source/tcas.exe  785 0 1 4931  240  554 2  499  400 0 1 1     > ../outputs/t394
    if diff ../outputs/t394 ../originals/t394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p395) timeout -s 9 2 ../source/tcas.exe  540 1 0  672  233    7 0  641  399 1 0 0     > ../outputs/t395
    if diff ../outputs/t395 ../originals/t395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p396) timeout -s 9 2 ../source/tcas.exe  756 0 1  562  415 3339 2  640  640 0 0 0     > ../outputs/t396
    if diff ../outputs/t396 ../originals/t396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p397) timeout -s 9 2 ../source/tcas.exe  695 0 1   55  100 2038 1  499  401 0 0 0     > ../outputs/t397
    if diff ../outputs/t397 ../originals/t397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p398) timeout -s 9 2 ../source/tcas.exe  559 1 1 1883  613 4507 2  640  500 1 1 1     > ../outputs/t398
    if diff ../outputs/t398 ../originals/t398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p399) timeout -s 9 2 ../source/tcas.exe  676 1 0  566  287 5295 2  399  500 1 1 1     > ../outputs/t399
    if diff ../outputs/t399 ../originals/t399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p400) timeout -s 9 2 ../source/tcas.exe  571 0 0 3403  576  850 1  741  500 1 0 0     > ../outputs/t400
    if diff ../outputs/t400 ../originals/t400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p401) timeout -s 9 2 ../source/tcas.exe  831 0 1  468  108 3882 1  500  399 0 1 0     > ../outputs/t401
    if diff ../outputs/t401 ../originals/t401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p402) timeout -s 9 2 ../source/tcas.exe  794 1 1  562  577 2901 2  499  401 0 0 1     > ../outputs/t402
    if diff ../outputs/t402 ../originals/t402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p403) timeout -s 9 2 ../source/tcas.exe  680 0 0  505   44  186 1  739  741 0 1 0     > ../outputs/t403
    if diff ../outputs/t403 ../originals/t403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p404) timeout -s 9 2 ../source/tcas.exe  924 0 0 1568   86  533 0  739  499 1 1 0     > ../outputs/t404
    if diff ../outputs/t404 ../originals/t404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p405) timeout -s 9 2 ../source/tcas.exe  833 1 0 4117  424 2255 1  501  401 1 0 0     > ../outputs/t405
    if diff ../outputs/t405 ../originals/t405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p406) timeout -s 9 2 ../source/tcas.exe  759 0 0 1552  265 4793 0  641  640 1 0 0     > ../outputs/t406
    if diff ../outputs/t406 ../originals/t406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p407) timeout -s 9 2 ../source/tcas.exe  973 0 0 1209  444 4409 2  399  641 1 0 0     > ../outputs/t407
    if diff ../outputs/t407 ../originals/t407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p408) timeout -s 9 2 ../source/tcas.exe  739 1 1 5287  252  632 1  740  639 1 0 1     > ../outputs/t408
    if diff ../outputs/t408 ../originals/t408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p409) timeout -s 9 2 ../source/tcas.exe  912 0 0 2658  192 3449 3  399  401 0 1 0     > ../outputs/t409
    if diff ../outputs/t409 ../originals/t409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p410) timeout -s 9 2 ../source/tcas.exe  750 0 0 5376  523 2611 2  500  639 0 0 0     > ../outputs/t410
    if diff ../outputs/t410 ../originals/t410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p411) timeout -s 9 2 ../source/tcas.exe  953 0 1 1508  132  672 3  499  499 0 1 0     > ../outputs/t411
    if diff ../outputs/t411 ../originals/t411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p412) timeout -s 9 2 ../source/tcas.exe  782 1 1  513  224 5295 0  641  639 0 1 0     > ../outputs/t412
    if diff ../outputs/t412 ../originals/t412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p413) timeout -s 9 2 ../source/tcas.exe  722 1 1 1415  245  316 0  401  739 0 0 1     > ../outputs/t413
    if diff ../outputs/t413 ../originals/t413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p414) timeout -s 9 2 ../source/tcas.exe  836 1 0 4086  407  308 2  499  400 0 1 0     > ../outputs/t414
    if diff ../outputs/t414 ../originals/t414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p415) timeout -s 9 2 ../source/tcas.exe  994 0 1 3194  242  687 1  501  741 0 0 1     > ../outputs/t415
    if diff ../outputs/t415 ../originals/t415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p416) timeout -s 9 2 ../source/tcas.exe  644 1 1 1986  596 2448 0  741  400 1 0 0     > ../outputs/t416
    if diff ../outputs/t416 ../originals/t416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p417) timeout -s 9 2 ../source/tcas.exe  935 1 1  792  272 3451 3  401  740 1 1 1     > ../outputs/t417
    if diff ../outputs/t417 ../originals/t417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p418) timeout -s 9 2 ../source/tcas.exe  690 1 1 4560  148   43 2  741  500 0 1 0     > ../outputs/t418
    if diff ../outputs/t418 ../originals/t418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p419) timeout -s 9 2 ../source/tcas.exe  596 1 0 4634  393  376 1  640  501 0 1 0     > ../outputs/t419
    if diff ../outputs/t419 ../originals/t419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p420) timeout -s 9 2 ../source/tcas.exe  538 0 1  404  384 4237 2  640  499 0 0 1     > ../outputs/t420
    if diff ../outputs/t420 ../originals/t420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p421) timeout -s 9 2 ../source/tcas.exe  799 0 1  386  380  351 1  639  639 1 0 1     > ../outputs/t421
    if diff ../outputs/t421 ../originals/t421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p422) timeout -s 9 2 ../source/tcas.exe  640 0 1 2175  485 1271 3  639  499 1 0 0     > ../outputs/t422
    if diff ../outputs/t422 ../originals/t422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p423) timeout -s 9 2 ../source/tcas.exe  884 0 1  754  323 2052 3  399  640 1 0 0     > ../outputs/t423
    if diff ../outputs/t423 ../originals/t423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p424) timeout -s 9 2 ../source/tcas.exe  635 1 0 1142  511 4704 1  740  500 0 0 1     > ../outputs/t424
    if diff ../outputs/t424 ../originals/t424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p425) timeout -s 9 2 ../source/tcas.exe  781 1 0 1855  408 3758 3  741  741 1 1 0     > ../outputs/t425
    if diff ../outputs/t425 ../originals/t425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p426) timeout -s 9 2 ../source/tcas.exe  757 1 1  319   51  300 1  401  741 0 1 0     > ../outputs/t426
    if diff ../outputs/t426 ../originals/t426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p427) timeout -s 9 2 ../source/tcas.exe  526 1 1 5505  562 2174 2  639  399 1 0 0     > ../outputs/t427
    if diff ../outputs/t427 ../originals/t427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p428) timeout -s 9 2 ../source/tcas.exe  867 0 0 4266  161 5389 1  640  741 0 0 0     > ../outputs/t428
    if diff ../outputs/t428 ../originals/t428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p429) timeout -s 9 2 ../source/tcas.exe  693 1 1 4557  254  482 3  740  739 0 0 1     > ../outputs/t429
    if diff ../outputs/t429 ../originals/t429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p430) timeout -s 9 2 ../source/tcas.exe  671 0 1 5327  132  902 2  400  500 1 0 1     > ../outputs/t430
    if diff ../outputs/t430 ../originals/t430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p431) timeout -s 9 2 ../source/tcas.exe  818 0 1  100  562 4914 0  739  401 0 1 0     > ../outputs/t431
    if diff ../outputs/t431 ../originals/t431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p432) timeout -s 9 2 ../source/tcas.exe  780 1 0 5331   10 1209 3  399  640 1 0 1     > ../outputs/t432
    if diff ../outputs/t432 ../originals/t432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p433) timeout -s 9 2 ../source/tcas.exe  706 1 0 4170  207  133 3  499  400 0 0 1     > ../outputs/t433
    if diff ../outputs/t433 ../originals/t433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p434) timeout -s 9 2 ../source/tcas.exe  714 1 1 1027  537  387 3  739  400 1 1 1     > ../outputs/t434
    if diff ../outputs/t434 ../originals/t434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p435) timeout -s 9 2 ../source/tcas.exe  946 0 0  693  550 4173 2  399  400 1 0 1     > ../outputs/t435
    if diff ../outputs/t435 ../originals/t435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p436) timeout -s 9 2 ../source/tcas.exe  630 1 0 2188  209 2525 0  639  739 0 0 1     > ../outputs/t436
    if diff ../outputs/t436 ../originals/t436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p437) timeout -s 9 2 ../source/tcas.exe  914 1 1 4924  384 5869 3  740  741 0 0 1     > ../outputs/t437
    if diff ../outputs/t437 ../originals/t437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p438) timeout -s 9 2 ../source/tcas.exe  721 1 0 4129  379 2370 3  500  741 1 1 1     > ../outputs/t438
    if diff ../outputs/t438 ../originals/t438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p439) timeout -s 9 2 ../source/tcas.exe  831 1 0 4955    8 4715 0  500  399 0 0 0     > ../outputs/t439
    if diff ../outputs/t439 ../originals/t439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p440) timeout -s 9 2 ../source/tcas.exe  905 1 0 1171  158  385 0  739  499 1 0 0     > ../outputs/t440
    if diff ../outputs/t440 ../originals/t440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p441) timeout -s 9 2 ../source/tcas.exe  899 0 1 4998    2 4230 0  500  501 0 0 0     > ../outputs/t441
    if diff ../outputs/t441 ../originals/t441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p442) timeout -s 9 2 ../source/tcas.exe  924 0 1 1780  437  998 2  501  639 0 1 1     > ../outputs/t442
    if diff ../outputs/t442 ../originals/t442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p443) timeout -s 9 2 ../source/tcas.exe  574 1 0  317  311 2079 1  400  400 1 1 0     > ../outputs/t443
    if diff ../outputs/t443 ../originals/t443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p444) timeout -s 9 2 ../source/tcas.exe  623 0 1 4856  546  420 3  500  501 0 1 1     > ../outputs/t444
    if diff ../outputs/t444 ../originals/t444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p445) timeout -s 9 2 ../source/tcas.exe  699 0 0 4483  280  358 1  499  639 1 1 1     > ../outputs/t445
    if diff ../outputs/t445 ../originals/t445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p446) timeout -s 9 2 ../source/tcas.exe  942 1 1 2938  179  534 0  740  641 0 1 0     > ../outputs/t446
    if diff ../outputs/t446 ../originals/t446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p447) timeout -s 9 2 ../source/tcas.exe  571 0 1  379  114 2328 2  400  401 1 1 1     > ../outputs/t447
    if diff ../outputs/t447 ../originals/t447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p448) timeout -s 9 2 ../source/tcas.exe  965 0 0 5560  431 1871 0  741  399 1 0 1     > ../outputs/t448
    if diff ../outputs/t448 ../originals/t448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p449) timeout -s 9 2 ../source/tcas.exe  974 0 1 1279  110 1990 3  400  501 1 1 0     > ../outputs/t449
    if diff ../outputs/t449 ../originals/t449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p450) timeout -s 9 2 ../source/tcas.exe  559 1 1 2851  413 4323 2  501  740 0 0 0     > ../outputs/t450
    if diff ../outputs/t450 ../originals/t450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p451) timeout -s 9 2 ../source/tcas.exe  655 1 1 4095  265 3490 2  739  499 1 1 0     > ../outputs/t451
    if diff ../outputs/t451 ../originals/t451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p452) timeout -s 9 2 ../source/tcas.exe  860 1 1 2944  139 5412 0  399  641 1 0 1     > ../outputs/t452
    if diff ../outputs/t452 ../originals/t452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p453) timeout -s 9 2 ../source/tcas.exe  924 1 0 1981  336 3860 2  500  501 1 1 0     > ../outputs/t453
    if diff ../outputs/t453 ../originals/t453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p454) timeout -s 9 2 ../source/tcas.exe  848 1 0 2408  180  525 0  740  401 0 1 0     > ../outputs/t454
    if diff ../outputs/t454 ../originals/t454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p455) timeout -s 9 2 ../source/tcas.exe  921 0 1 1788  125  516 3  399  739 1 0 1     > ../outputs/t455
    if diff ../outputs/t455 ../originals/t455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p456) timeout -s 9 2 ../source/tcas.exe  852 1 1 1399  347 1245 1  400  641 0 0 0     > ../outputs/t456
    if diff ../outputs/t456 ../originals/t456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p457) timeout -s 9 2 ../source/tcas.exe  897 0 0 2622  326 3725 2  401  400 0 0 0     > ../outputs/t457
    if diff ../outputs/t457 ../originals/t457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p458) timeout -s 9 2 ../source/tcas.exe  933 0 1  567  407 1839 0  641  640 0 0 1     > ../outputs/t458
    if diff ../outputs/t458 ../originals/t458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p459) timeout -s 9 2 ../source/tcas.exe  776 1 0  954   72 2987 3  399  741 0 1 1     > ../outputs/t459
    if diff ../outputs/t459 ../originals/t459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p460) timeout -s 9 2 ../source/tcas.exe  748 1 0  508   81 1372 0  740  739 0 1 1     > ../outputs/t460
    if diff ../outputs/t460 ../originals/t460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p461) timeout -s 9 2 ../source/tcas.exe  624 0 1 3277  264 5028 3  640  400 1 1 1     > ../outputs/t461
    if diff ../outputs/t461 ../originals/t461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p462) timeout -s 9 2 ../source/tcas.exe  570 1 1 5125   85 4371 0  400  499 1 1 0     > ../outputs/t462
    if diff ../outputs/t462 ../originals/t462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p463) timeout -s 9 2 ../source/tcas.exe  546 0 1 4364   90 4988 3  739  640 0 1 0     > ../outputs/t463
    if diff ../outputs/t463 ../originals/t463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p464) timeout -s 9 2 ../source/tcas.exe  732 0 0 2558  599 3531 0  399  739 1 0 0     > ../outputs/t464
    if diff ../outputs/t464 ../originals/t464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p465) timeout -s 9 2 ../source/tcas.exe  795 0 0 3378   59  440 0  399  740 0 1 1     > ../outputs/t465
    if diff ../outputs/t465 ../originals/t465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p466) timeout -s 9 2 ../source/tcas.exe  574 0 0  321  131 1814 0  639  641 1 1 0     > ../outputs/t466
    if diff ../outputs/t466 ../originals/t466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p467) timeout -s 9 2 ../source/tcas.exe  997 1 0 4466  100 4610 1  639  400 1 0 1     > ../outputs/t467
    if diff ../outputs/t467 ../originals/t467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p468) timeout -s 9 2 ../source/tcas.exe  740 1 1  972  312 3512 3  501  740 0 0 0     > ../outputs/t468
    if diff ../outputs/t468 ../originals/t468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p469) timeout -s 9 2 ../source/tcas.exe  869 0 0 5624   18  702 2  500  641 1 0 1     > ../outputs/t469
    if diff ../outputs/t469 ../originals/t469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p470) timeout -s 9 2 ../source/tcas.exe  955 0 1 1567  366  363 0  401  639 1 1 0     > ../outputs/t470
    if diff ../outputs/t470 ../originals/t470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p471) timeout -s 9 2 ../source/tcas.exe  735 1 0 2792  119  224 3  739  739 0 0 0     > ../outputs/t471
    if diff ../outputs/t471 ../originals/t471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p472) timeout -s 9 2 ../source/tcas.exe  912 1 0 4251  133  545 1  739  399 1 1 0     > ../outputs/t472
    if diff ../outputs/t472 ../originals/t472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p473) timeout -s 9 2 ../source/tcas.exe  607 1 0 5014  531  310 1  739  501 0 0 1     > ../outputs/t473
    if diff ../outputs/t473 ../originals/t473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p474) timeout -s 9 2 ../source/tcas.exe  733 1 0 1785  585  343 3  741  499 0 1 1     > ../outputs/t474
    if diff ../outputs/t474 ../originals/t474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p475) timeout -s 9 2 ../source/tcas.exe  811 1 1 4100  193 5500 3  641  500 0 1 0     > ../outputs/t475
    if diff ../outputs/t475 ../originals/t475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p476) timeout -s 9 2 ../source/tcas.exe  715 0 0 1768  391 1782 2  740  399 0 0 0     > ../outputs/t476
    if diff ../outputs/t476 ../originals/t476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p477) timeout -s 9 2 ../source/tcas.exe  797 0 0 4454  508  288 2  741  401 1 0 1     > ../outputs/t477
    if diff ../outputs/t477 ../originals/t477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p478) timeout -s 9 2 ../source/tcas.exe  578 0 0 4590  303  220 0  499  501 1 0 1     > ../outputs/t478
    if diff ../outputs/t478 ../originals/t478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p479) timeout -s 9 2 ../source/tcas.exe  621 0 1  675  520 3199 3  641  400 0 0 0     > ../outputs/t479
    if diff ../outputs/t479 ../originals/t479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p480) timeout -s 9 2 ../source/tcas.exe  841 0 1  427    9 4967 2  740  501 1 1 0     > ../outputs/t480
    if diff ../outputs/t480 ../originals/t480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p481) timeout -s 9 2 ../source/tcas.exe  524 0 0 2495  396  506 3  740  640 0 1 0     > ../outputs/t481
    if diff ../outputs/t481 ../originals/t481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p482) timeout -s 9 2 ../source/tcas.exe  848 0 0 2494  271 2583 1  501  641 1 0 1     > ../outputs/t482
    if diff ../outputs/t482 ../originals/t482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p483) timeout -s 9 2 ../source/tcas.exe  966 0 0 5272  252  451 3  499  740 0 1 0     > ../outputs/t483
    if diff ../outputs/t483 ../originals/t483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p484) timeout -s 9 2 ../source/tcas.exe  820 0 0 1557  524 1163 0  499  499 0 0 0     > ../outputs/t484
    if diff ../outputs/t484 ../originals/t484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p485) timeout -s 9 2 ../source/tcas.exe  679 1 1  541  338 5123 0  641  641 1 0 1     > ../outputs/t485
    if diff ../outputs/t485 ../originals/t485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p486) timeout -s 9 2 ../source/tcas.exe  565 0 0 4233   97 5531 1  739  641 0 0 0     > ../outputs/t486
    if diff ../outputs/t486 ../originals/t486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p487) timeout -s 9 2 ../source/tcas.exe  793 0 0 5989  606 3063 3  500  641 0 0 1     > ../outputs/t487
    if diff ../outputs/t487 ../originals/t487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p488) timeout -s 9 2 ../source/tcas.exe  609 0 0  259    8 3583 0  641  741 0 1 1     > ../outputs/t488
    if diff ../outputs/t488 ../originals/t488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p489) timeout -s 9 2 ../source/tcas.exe  962 0 0 3810  528 1326 2  641  400 0 0 1     > ../outputs/t489
    if diff ../outputs/t489 ../originals/t489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p490) timeout -s 9 2 ../source/tcas.exe  587 1 0 4426  303 1022 0  499  741 1 0 0     > ../outputs/t490
    if diff ../outputs/t490 ../originals/t490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p491) timeout -s 9 2 ../source/tcas.exe  607 0 0 3707  320 5543 0  639  639 1 1 1     > ../outputs/t491
    if diff ../outputs/t491 ../originals/t491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p492) timeout -s 9 2 ../source/tcas.exe  584 1 1 1289  401 4395 1  501  639 0 1 1     > ../outputs/t492
    if diff ../outputs/t492 ../originals/t492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p493) timeout -s 9 2 ../source/tcas.exe  564 1 1 4996  391 1494 3  640  500 0 1 1     > ../outputs/t493
    if diff ../outputs/t493 ../originals/t493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p494) timeout -s 9 2 ../source/tcas.exe  952 0 1 2813  121 3907 0  501  401 1 0 0     > ../outputs/t494
    if diff ../outputs/t494 ../originals/t494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p495) timeout -s 9 2 ../source/tcas.exe  817 0 1 4129   65 3077 0  739  401 1 0 1     > ../outputs/t495
    if diff ../outputs/t495 ../originals/t495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p496) timeout -s 9 2 ../source/tcas.exe  726 0 0 3176  519 2689 1  400  641 1 1 1     > ../outputs/t496
    if diff ../outputs/t496 ../originals/t496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p497) timeout -s 9 2 ../source/tcas.exe  895 0 1 5104  338  372 3  500  639 0 0 0     > ../outputs/t497
    if diff ../outputs/t497 ../originals/t497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p498) timeout -s 9 2 ../source/tcas.exe  928 1 1 3716  536 1907 2  501  639 1 0 0     > ../outputs/t498
    if diff ../outputs/t498 ../originals/t498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p499) timeout -s 9 2 ../source/tcas.exe  608 1 1 3093  528 5892 1  400  400 0 1 0     > ../outputs/t499
    if diff ../outputs/t499 ../originals/t499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p500) timeout -s 9 2 ../source/tcas.exe  627 1 0  151  446 1983 3  401  500 0 1 1     > ../outputs/t500
    if diff ../outputs/t500 ../originals/t500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p501) timeout -s 9 2 ../source/tcas.exe 597 -1 0 -1 577 0 0 605 931 0 2 0     > ../outputs/t501
    if diff ../outputs/t501 ../originals/t501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p502) timeout -s 9 2 ../source/tcas.exe 653 1 -1 740 -1 702 -1 0 -1 2 1 1     > ../outputs/t502
    if diff ../outputs/t502 ../originals/t502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p503) timeout -s 9 2 ../source/tcas.exe 0 0 0 0 609 -1 1 582 89 4 0 -1     > ../outputs/t503
    if diff ../outputs/t503 ../originals/t503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p504) timeout -s 9 2 ../source/tcas.exe -1 1 0 9343 0 127 3 -100 0 1 2 0     > ../outputs/t504
    if diff ../outputs/t504 ../originals/t504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p505) timeout -s 9 2 ../source/tcas.exe 640 0 0 569 400 586 1 1012 1037 0 1 1     > ../outputs/t505
    if diff ../outputs/t505 ../originals/t505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p506) timeout -s 9 2 ../source/tcas.exe 1174 1 0 586 373 559 2 259 351 0 2 0     > ../outputs/t506
    if diff ../outputs/t506 ../originals/t506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p507) timeout -s 9 2 ../source/tcas.exe 684 1 1 522 426 478 0 848 496 0 2 1     > ../outputs/t507
    if diff ../outputs/t507 ../originals/t507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p508) timeout -s 9 2 ../source/tcas.exe 1016 1 1 628 0 614 0 0 746 0 2 1     > ../outputs/t508
    if diff ../outputs/t508 ../originals/t508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p509) timeout -s 9 2 ../source/tcas.exe 913 0 1 722 520 657 2 714 822 0 2 0     > ../outputs/t509
    if diff ../outputs/t509 ../originals/t509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p510) timeout -s 9 2 ../source/tcas.exe 4 1 1 0 409 648 2 601 657 0 2 1     > ../outputs/t510
    if diff ../outputs/t510 ../originals/t510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p511) timeout -s 9 2 ../source/tcas.exe 595 0 1 647 357 695 1 536 593 0 1 0     > ../outputs/t511
    if diff ../outputs/t511 ../originals/t511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p512) timeout -s 9 2 ../source/tcas.exe 925 1 1 557 349 608 3 994 880 0 2 1     > ../outputs/t512
    if diff ../outputs/t512 ../originals/t512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p513) timeout -s 9 2 ../source/tcas.exe 1108 1 1 583 449 601 1 712 725 0 2 1     > ../outputs/t513
    if diff ../outputs/t513 ../originals/t513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p514) timeout -s 9 2 ../source/tcas.exe 681 1 0 614 482 0 0 707 757 0 2 0     > ../outputs/t514
    if diff ../outputs/t514 ../originals/t514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p515) timeout -s 9 2 ../source/tcas.exe 1081 1 0 675 428 638 0 917 920 0 2 1     > ../outputs/t515
    if diff ../outputs/t515 ../originals/t515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p516) timeout -s 9 2 ../source/tcas.exe 652 1 1 638 609 620 1 726 0 0 2 0     > ../outputs/t516
    if diff ../outputs/t516 ../originals/t516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p517) timeout -s 9 2 ../source/tcas.exe 1093 1 1 0 580 750 1 678 447 0 2 0     > ../outputs/t517
    if diff ../outputs/t517 ../originals/t517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p518) timeout -s 9 2 ../source/tcas.exe 859 1 0 632 355 662 2 379 97 0 2 0     > ../outputs/t518
    if diff ../outputs/t518 ../originals/t518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p519) timeout -s 9 2 ../source/tcas.exe 709 1 1 4523 547 657 3 743 743 0 2 1     > ../outputs/t519
    if diff ../outputs/t519 ../originals/t519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p520) timeout -s 9 2 ../source/tcas.exe 694 1 0 631 485 642 9 442 418 0 2 1     > ../outputs/t520
    if diff ../outputs/t520 ../originals/t520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p521) timeout -s 9 2 ../source/tcas.exe 647 1 1 570 505 615 1 341 392 0 2 1     > ../outputs/t521
    if diff ../outputs/t521 ../originals/t521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p522) timeout -s 9 2 ../source/tcas.exe 810 1 0 686 458 122 3 1017 980 0 1 1     > ../outputs/t522
    if diff ../outputs/t522 ../originals/t522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p523) timeout -s 9 2 ../source/tcas.exe 766 1 1 0 380 744 0 370 369 0 2 1     > ../outputs/t523
    if diff ../outputs/t523 ../originals/t523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p524) timeout -s 9 2 ../source/tcas.exe 860 1 1 618 329 574 4 893 914 0 2 0     > ../outputs/t524
    if diff ../outputs/t524 ../originals/t524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p525) timeout -s 9 2 ../source/tcas.exe 654 1 1 912 496 465 0 587 495 0 2 1     > ../outputs/t525
    if diff ../outputs/t525 ../originals/t525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p526) timeout -s 9 2 ../source/tcas.exe 760 1 1 753 595 619 0 679 630 0 2 0     > ../outputs/t526
    if diff ../outputs/t526 ../originals/t526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p527) timeout -s 9 2 ../source/tcas.exe 1149 1 0 562 485 272 1 670 633 2 2 1     > ../outputs/t527
    if diff ../outputs/t527 ../originals/t527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p528) timeout -s 9 2 ../source/tcas.exe 987 1 0 550 587 819 2 929 955 0 1 0     > ../outputs/t528
    if diff ../outputs/t528 ../originals/t528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p529) timeout -s 9 2 ../source/tcas.exe 907 1 0 560 342 601 3 961 399 2 2 1     > ../outputs/t529
    if diff ../outputs/t529 ../originals/t529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p530) timeout -s 9 2 ../source/tcas.exe 1207 1 1 591 996 658 1 556 0 0 1 1     > ../outputs/t530
    if diff ../outputs/t530 ../originals/t530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p531) timeout -s 9 2 ../source/tcas.exe -1 1 0 631 370 661 2 820 825 1 2 1     > ../outputs/t531
    if diff ../outputs/t531 ../originals/t531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p532) timeout -s 9 2 ../source/tcas.exe 775 1 1 0 506 596 0 906 685 0 2 1     > ../outputs/t532
    if diff ../outputs/t532 ../originals/t532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p533) timeout -s 9 2 ../source/tcas.exe 1018 1 1 3177 325 624 3 1026 1017 0 2 0     > ../outputs/t533
    if diff ../outputs/t533 ../originals/t533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p534) timeout -s 9 2 ../source/tcas.exe 868 1 1 731 361 699 1 672 690 0 2 0     > ../outputs/t534
    if diff ../outputs/t534 ../originals/t534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p535) timeout -s 9 2 ../source/tcas.exe 895 1 1 -1 403 718 2 694 708 0 2 1     > ../outputs/t535
    if diff ../outputs/t535 ../originals/t535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p536) timeout -s 9 2 ../source/tcas.exe 837 1 1 711 452 726 2 593 506 2 2 1     > ../outputs/t536
    if diff ../outputs/t536 ../originals/t536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p537) timeout -s 9 2 ../source/tcas.exe 887 1 1 591 589 -100 2 424 457 0 2 0     > ../outputs/t537
    if diff ../outputs/t537 ../originals/t537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p538) timeout -s 9 2 ../source/tcas.exe 1027 1 1 -100 369 599 1 737 708 0 2 0     > ../outputs/t538
    if diff ../outputs/t538 ../originals/t538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p539) timeout -s 9 2 ../source/tcas.exe 589 1 0 657 557 644 3 0 999 0 2 1     > ../outputs/t539
    if diff ../outputs/t539 ../originals/t539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p540) timeout -s 9 2 ../source/tcas.exe 1144 1 1 590 490 646 3 457 0 0 2 1     > ../outputs/t540
    if diff ../outputs/t540 ../originals/t540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p541) timeout -s 9 2 ../source/tcas.exe 646 1 1 630 310 615 2 318 314 0 1 1     > ../outputs/t541
    if diff ../outputs/t541 ../originals/t541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p542) timeout -s 9 2 ../source/tcas.exe 1168 1 1 0 590 673 0 387 377 0 2 1     > ../outputs/t542
    if diff ../outputs/t542 ../originals/t542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p543) timeout -s 9 2 ../source/tcas.exe 248 1 0 0 584 616 3 566 523 0 2 0     > ../outputs/t543
    if diff ../outputs/t543 ../originals/t543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p544) timeout -s 9 2 ../source/tcas.exe 837 1 0 691 396 0 0 949 942 0 1 0     > ../outputs/t544
    if diff ../outputs/t544 ../originals/t544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p545) timeout -s 9 2 ../source/tcas.exe 854 1 1 703 502 730 1 0 617 0 2 1     > ../outputs/t545
    if diff ../outputs/t545 ../originals/t545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p546) timeout -s 9 2 ../source/tcas.exe 1172 1 1 0 590 732 3 745 765 0 2 0     > ../outputs/t546
    if diff ../outputs/t546 ../originals/t546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p547) timeout -s 9 2 ../source/tcas.exe 746 1 0 0 391 601 3 837 957 0 2 0     > ../outputs/t547
    if diff ../outputs/t547 ../originals/t547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p548) timeout -s 9 2 ../source/tcas.exe 897 1 1 3257 470 707 2 744 693 0 1 0     > ../outputs/t548
    if diff ../outputs/t548 ../originals/t548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p549) timeout -s 9 2 ../source/tcas.exe 589 0 1 584 798 567 2 957 925 0 2 0     > ../outputs/t549
    if diff ../outputs/t549 ../originals/t549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p550) timeout -s 9 2 ../source/tcas.exe 697 0 0 726 322 725 3 638 650 0 2 1     > ../outputs/t550
    if diff ../outputs/t550 ../originals/t550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p551) timeout -s 9 2 ../source/tcas.exe 787 1 1 0 293 597 0 726 686 1 2 1     > ../outputs/t551
    if diff ../outputs/t551 ../originals/t551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p552) timeout -s 9 2 ../source/tcas.exe 866 0 1 657 464 43 2 403 424 0 2 1     > ../outputs/t552
    if diff ../outputs/t552 ../originals/t552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p553) timeout -s 9 2 ../source/tcas.exe 854 1 0 687 426 684 1 623 744 3 2 1     > ../outputs/t553
    if diff ../outputs/t553 ../originals/t553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p554) timeout -s 9 2 ../source/tcas.exe 1016 1 0 658 359 644 1 391 442 1 2 1     > ../outputs/t554
    if diff ../outputs/t554 ../originals/t554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p555) timeout -s 9 2 ../source/tcas.exe 905 0 1 699 436 742 1 372 331 0 2 0     > ../outputs/t555
    if diff ../outputs/t555 ../originals/t555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p556) timeout -s 9 2 ../source/tcas.exe 892 0 1 762 445 157 2 442 440 0 2 1     > ../outputs/t556
    if diff ../outputs/t556 ../originals/t556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p557) timeout -s 9 2 ../source/tcas.exe 1005 1 1 601 394 601 1 717 0 0 2 0     > ../outputs/t557
    if diff ../outputs/t557 ../originals/t557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p558) timeout -s 9 2 ../source/tcas.exe 934 1 0 5216 458 972 1 539 464 0 2 1     > ../outputs/t558
    if diff ../outputs/t558 ../originals/t558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p559) timeout -s 9 2 ../source/tcas.exe 1184 1 1 4983 523 689 0 653 938 0 1 1     > ../outputs/t559
    if diff ../outputs/t559 ../originals/t559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p560) timeout -s 9 2 ../source/tcas.exe 1146 1 0 656 392 691 0 860 0 1 2 1     > ../outputs/t560
    if diff ../outputs/t560 ../originals/t560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p561) timeout -s 9 2 ../source/tcas.exe 666 1 1 577 342 558 2 193 1016 0 2 0     > ../outputs/t561
    if diff ../outputs/t561 ../originals/t561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p562) timeout -s 9 2 ../source/tcas.exe 1059 0 0 640 380 580 0 748 692 2 2 0     > ../outputs/t562
    if diff ../outputs/t562 ../originals/t562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p563) timeout -s 9 2 ../source/tcas.exe 934 1 0 603 333 552 0 410 439 0 2 1     > ../outputs/t563
    if diff ../outputs/t563 ../originals/t563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p564) timeout -s 9 2 ../source/tcas.exe 947 1 1 677 237 681 2 594 352 0 2 0     > ../outputs/t564
    if diff ../outputs/t564 ../originals/t564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p565) timeout -s 9 2 ../source/tcas.exe 655 1 1 628 348 861 2 455 0 0 2 0     > ../outputs/t565
    if diff ../outputs/t565 ../originals/t565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p566) timeout -s 9 2 ../source/tcas.exe 1137 1 1 687 292 572 2 0 372 0 1 1     > ../outputs/t566
    if diff ../outputs/t566 ../originals/t566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p567) timeout -s 9 2 ../source/tcas.exe 812 1 0 663 336 587 0 518 20 0 2 0     > ../outputs/t567
    if diff ../outputs/t567 ../originals/t567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p568) timeout -s 9 2 ../source/tcas.exe 1022 1 1 554 320 598 2 914 494 2 1 0     > ../outputs/t568
    if diff ../outputs/t568 ../originals/t568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p569) timeout -s 9 2 ../source/tcas.exe 761 1 0 608 527 596 0 663 632 0 2 1     > ../outputs/t569
    if diff ../outputs/t569 ../originals/t569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p570) timeout -s 9 2 ../source/tcas.exe 0 0 1 60 432 738 3 863 852 0 2 1     > ../outputs/t570
    if diff ../outputs/t570 ../originals/t570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p571) timeout -s 9 2 ../source/tcas.exe 808 1 0 581 492 448 2 452 0 0 2 1     > ../outputs/t571
    if diff ../outputs/t571 ../originals/t571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p572) timeout -s 9 2 ../source/tcas.exe 845 1 1 667 661 683 1 446 404 2 2 0     > ../outputs/t572
    if diff ../outputs/t572 ../originals/t572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p573) timeout -s 9 2 ../source/tcas.exe 815 1 0 625 419 657 0 0 887 0 1 0     > ../outputs/t573
    if diff ../outputs/t573 ../originals/t573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p574) timeout -s 9 2 ../source/tcas.exe 756 1 1 586 341 824 3 417 361 0 2 1     > ../outputs/t574
    if diff ../outputs/t574 ../originals/t574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p575) timeout -s 9 2 ../source/tcas.exe 640 1 0 654 438 0 1 0 415 2 1 1     > ../outputs/t575
    if diff ../outputs/t575 ../originals/t575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p576) timeout -s 9 2 ../source/tcas.exe 1118 1 1 712 261 735 1 423 450 0 1 1     > ../outputs/t576
    if diff ../outputs/t576 ../originals/t576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p577) timeout -s 9 2 ../source/tcas.exe 1073 1 1 2223 379 752 0 435 438 2 2 0     > ../outputs/t577
    if diff ../outputs/t577 ../originals/t577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p578) timeout -s 9 2 ../source/tcas.exe 763 1 1 6514 0 643 3 816 756 0 2 1     > ../outputs/t578
    if diff ../outputs/t578 ../originals/t578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p579) timeout -s 9 2 ../source/tcas.exe 1064 1 1 674 401 663 9 560 900 0 1 0     > ../outputs/t579
    if diff ../outputs/t579 ../originals/t579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p580) timeout -s 9 2 ../source/tcas.exe 592 1 1 701 532 688 3 396 372 0 2 1     > ../outputs/t580
    if diff ../outputs/t580 ../originals/t580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p581) timeout -s 9 2 ../source/tcas.exe 1037 1 0 610 504 623 3 0 877 0 2 1     > ../outputs/t581
    if diff ../outputs/t581 ../originals/t581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p582) timeout -s 9 2 ../source/tcas.exe 795 1 -1 538 325 601 2 702 634 0 1 1     > ../outputs/t582
    if diff ../outputs/t582 ../originals/t582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p583) timeout -s 9 2 ../source/tcas.exe 709 1 1 686 483 672 1 465 475 1 2 1     > ../outputs/t583
    if diff ../outputs/t583 ../originals/t583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p584) timeout -s 9 2 ../source/tcas.exe 847 1 1 1325 360 668 2 817 803 0 1 1     > ../outputs/t584
    if diff ../outputs/t584 ../originals/t584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p585) timeout -s 9 2 ../source/tcas.exe 782 1 0 729 462 0 1 449 818 0 2 1     > ../outputs/t585
    if diff ../outputs/t585 ../originals/t585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p586) timeout -s 9 2 ../source/tcas.exe 964 1 1 2672 326 714 2 18 609 2 2 1     > ../outputs/t586
    if diff ../outputs/t586 ../originals/t586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p587) timeout -s 9 2 ../source/tcas.exe 796 1 1 0 535 627 1 329 0 0 2 1     > ../outputs/t587
    if diff ../outputs/t587 ../originals/t587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p588) timeout -s 9 2 ../source/tcas.exe 1058 1 0 707 0 703 0 901 906 0 2 0     > ../outputs/t588
    if diff ../outputs/t588 ../originals/t588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p589) timeout -s 9 2 ../source/tcas.exe 732 1 1 654 413 710 2 306 375 -1 2 1     > ../outputs/t589
    if diff ../outputs/t589 ../originals/t589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p590) timeout -s 9 2 ../source/tcas.exe 1122 1 1 705 374 716 1 0 547 0 2 0     > ../outputs/t590
    if diff ../outputs/t590 ../originals/t590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p591) timeout -s 9 2 ../source/tcas.exe 1022 1 0 716 503 -1 1 629 815 0 2 1     > ../outputs/t591
    if diff ../outputs/t591 ../originals/t591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p592) timeout -s 9 2 ../source/tcas.exe 1109 1 1 557 344 639 0 370 -100 0 2 1     > ../outputs/t592
    if diff ../outputs/t592 ../originals/t592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p593) timeout -s 9 2 ../source/tcas.exe 764 -1 0 561 530 592 1 593 619 0 2 1     > ../outputs/t593
    if diff ../outputs/t593 ../originals/t593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p594) timeout -s 9 2 ../source/tcas.exe 756 1 1 546 603 603 0 0 796 2 2 0     > ../outputs/t594
    if diff ../outputs/t594 ../originals/t594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p595) timeout -s 9 2 ../source/tcas.exe 811 1 0 691 350 0 0 619 0 0 2 0     > ../outputs/t595
    if diff ../outputs/t595 ../originals/t595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p596) timeout -s 9 2 ../source/tcas.exe 1149 1 1 606 399 602 1 441 369 0 2 0     > ../outputs/t596
    if diff ../outputs/t596 ../originals/t596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p597) timeout -s 9 2 ../source/tcas.exe 1096 1 0 714 496 682 1 944 908 0 1 0     > ../outputs/t597
    if diff ../outputs/t597 ../originals/t597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p598) timeout -s 9 2 ../source/tcas.exe 1039 0 1 1310 948 653 0 0 922 0 2 0     > ../outputs/t598
    if diff ../outputs/t598 ../originals/t598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p599) timeout -s 9 2 ../source/tcas.exe 806 1 0 744 0 349 2 839 -100 0 2 1     > ../outputs/t599
    if diff ../outputs/t599 ../originals/t599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p600) timeout -s 9 2 ../source/tcas.exe 1032 1 0 707 389 727 1 297 0 2 2 0     > ../outputs/t600
    if diff ../outputs/t600 ../originals/t600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p601) timeout -s 9 2 ../source/tcas.exe 854 1 1 4049 773 654 2 595 625 0 2 1     > ../outputs/t601
    if diff ../outputs/t601 ../originals/t601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p602) timeout -s 9 2 ../source/tcas.exe 1159 0 1 672 298 178 2 468 0 0 2 0     > ../outputs/t602
    if diff ../outputs/t602 ../originals/t602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p603) timeout -s 9 2 ../source/tcas.exe 752 1 1 733 398 746 3 328 0 0 2 9     > ../outputs/t603
    if diff ../outputs/t603 ../originals/t603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p604) timeout -s 9 2 ../source/tcas.exe 1143 0 0 604 365 0 1 451 458 0 2 1     > ../outputs/t604
    if diff ../outputs/t604 ../originals/t604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p605) timeout -s 9 2 ../source/tcas.exe -1 1 1 604 607 622 0 0 0 0 2 0     > ../outputs/t605
    if diff ../outputs/t605 ../originals/t605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p606) timeout -s 9 2 ../source/tcas.exe 943 1 1 668 833 956 2 588 556 0 2 0     > ../outputs/t606
    if diff ../outputs/t606 ../originals/t606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p607) timeout -s 9 2 ../source/tcas.exe 1175 1 0 619 491 684 1 693 60 2 1 1     > ../outputs/t607
    if diff ../outputs/t607 ../originals/t607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p608) timeout -s 9 2 ../source/tcas.exe 784 1 1 566 870 578 2 969 694 0 2 1     > ../outputs/t608
    if diff ../outputs/t608 ../originals/t608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p609) timeout -s 9 2 ../source/tcas.exe 708 1 1 871 369 712 3 427 478 0 2 1     > ../outputs/t609
    if diff ../outputs/t609 ../originals/t609 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p610) timeout -s 9 2 ../source/tcas.exe 162 1 0 587 577 110 0 647 962 1 2 1     > ../outputs/t610
    if diff ../outputs/t610 ../originals/t610 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p611) timeout -s 9 2 ../source/tcas.exe 1074 1 0 0 305 666 3 306 356 0 1 1     > ../outputs/t611
    if diff ../outputs/t611 ../originals/t611 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p612) timeout -s 9 2 ../source/tcas.exe 800 1 0 735 323 724 2 233 584 0 2 0     > ../outputs/t612
    if diff ../outputs/t612 ../originals/t612 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p613) timeout -s 9 2 ../source/tcas.exe 1078 1 0 673 311 692 2 551 490 2 2 0     > ../outputs/t613
    if diff ../outputs/t613 ../originals/t613 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p614) timeout -s 9 2 ../source/tcas.exe 613 1 1 711 538 0 1 363 398 0 2 1     > ../outputs/t614
    if diff ../outputs/t614 ../originals/t614 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p615) timeout -s 9 2 ../source/tcas.exe 860 1 0 -1 485 422 0 330 273 0 2 1     > ../outputs/t615
    if diff ../outputs/t615 ../originals/t615 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p616) timeout -s 9 2 ../source/tcas.exe 615 1 1 767 616 0 1 751 673 0 2 0     > ../outputs/t616
    if diff ../outputs/t616 ../originals/t616 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p617) timeout -s 9 2 ../source/tcas.exe 0 1 0 692 465 646 3 872 825 2 2 1     > ../outputs/t617
    if diff ../outputs/t617 ../originals/t617 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p618) timeout -s 9 2 ../source/tcas.exe 792 0 0 625 409 541 2 381 403 0 2 0     > ../outputs/t618
    if diff ../outputs/t618 ../originals/t618 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p619) timeout -s 9 2 ../source/tcas.exe -1 0 1 593 447 655 1 366 314 0 1 1     > ../outputs/t619
    if diff ../outputs/t619 ../originals/t619 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p620) timeout -s 9 2 ../source/tcas.exe 1113 1 0 7965 430 596 1 820 876 0 2 0     > ../outputs/t620
    if diff ../outputs/t620 ../originals/t620 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p621) timeout -s 9 2 ../source/tcas.exe 999 1 0 0 447 610 1 511 464 1 2 0     > ../outputs/t621
    if diff ../outputs/t621 ../originals/t621 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p622) timeout -s 9 2 ../source/tcas.exe 865 1 1 634 344 699 1 -100 600 0 2 0     > ../outputs/t622
    if diff ../outputs/t622 ../originals/t622 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p623) timeout -s 9 2 ../source/tcas.exe 974 0 1 651 539 671 1 955 997 1 2 0     > ../outputs/t623
    if diff ../outputs/t623 ../originals/t623 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p624) timeout -s 9 2 ../source/tcas.exe 1016 1 0 712 426 0 0 361 745 0 2 1     > ../outputs/t624
    if diff ../outputs/t624 ../originals/t624 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p625) timeout -s 9 2 ../source/tcas.exe 1051 1 0 618 294 236 1 230 872 0 1 0     > ../outputs/t625
    if diff ../outputs/t625 ../originals/t625 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p626) timeout -s 9 2 ../source/tcas.exe 232 1 1 583 513 601 0 0 928 1 2 1     > ../outputs/t626
    if diff ../outputs/t626 ../originals/t626 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p627) timeout -s 9 2 ../source/tcas.exe 661 0 0 544 598 0 1 573 566 0 2 0     > ../outputs/t627
    if diff ../outputs/t627 ../originals/t627 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p628) timeout -s 9 2 ../source/tcas.exe 784 1 0 0 365 732 0 611 624 2 2 1     > ../outputs/t628
    if diff ../outputs/t628 ../originals/t628 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p629) timeout -s 9 2 ../source/tcas.exe 695 0 0 593 451 568 2 981 0 0 2 1     > ../outputs/t629
    if diff ../outputs/t629 ../originals/t629 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p630) timeout -s 9 2 ../source/tcas.exe 1112 1 1 601 400 663 1 298 0 1 2 0     > ../outputs/t630
    if diff ../outputs/t630 ../originals/t630 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p631) timeout -s 9 2 ../source/tcas.exe 876 -1 1 745 375 892 1 930 930 0 2 1     > ../outputs/t631
    if diff ../outputs/t631 ../originals/t631 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p632) timeout -s 9 2 ../source/tcas.exe 1063 1 0 662 0 592 3 416 346 0 2 1     > ../outputs/t632
    if diff ../outputs/t632 ../originals/t632 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p633) timeout -s 9 2 ../source/tcas.exe 271 1 1 697 633 691 3 890 868 0 1 1     > ../outputs/t633
    if diff ../outputs/t633 ../originals/t633 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p634) timeout -s 9 2 ../source/tcas.exe 1208 1 0 544 -1 605 1 797 801 0 2 1     > ../outputs/t634
    if diff ../outputs/t634 ../originals/t634 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p635) timeout -s 9 2 ../source/tcas.exe 1185 1 -1 710 378 674 3 604 554 0 2 0     > ../outputs/t635
    if diff ../outputs/t635 ../originals/t635 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p636) timeout -s 9 2 ../source/tcas.exe 1206 1 0 5140 355 730 2 980 693 2 2 0     > ../outputs/t636
    if diff ../outputs/t636 ../originals/t636 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p637) timeout -s 9 2 ../source/tcas.exe 1155 1 0 603 349 514 3 816 863 1 2 0     > ../outputs/t637
    if diff ../outputs/t637 ../originals/t637 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p638) timeout -s 9 2 ../source/tcas.exe 6 0 0 648 427 687 0 961 947 0 1 1     > ../outputs/t638
    if diff ../outputs/t638 ../originals/t638 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p639) timeout -s 9 2 ../source/tcas.exe 601 1 0 672 0 660 3 577 545 0 2 3     > ../outputs/t639
    if diff ../outputs/t639 ../originals/t639 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p640) timeout -s 9 2 ../source/tcas.exe 648 1 0 680 511 428 3 0 314 0 2 1     > ../outputs/t640
    if diff ../outputs/t640 ../originals/t640 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p641) timeout -s 9 2 ../source/tcas.exe 774 1 1 0 433 239 0 -1 390 0 2 1     > ../outputs/t641
    if diff ../outputs/t641 ../originals/t641 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p642) timeout -s 9 2 ../source/tcas.exe 909 1 0 575 444 -100 1 523 981 0 2 0     > ../outputs/t642
    if diff ../outputs/t642 ../originals/t642 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p643) timeout -s 9 2 ../source/tcas.exe 780 0 1 669 562 387 1 0 951 0 2 1     > ../outputs/t643
    if diff ../outputs/t643 ../originals/t643 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p644) timeout -s 9 2 ../source/tcas.exe 697 1 0 728 614 725 1 173 131 1 2 0     > ../outputs/t644
    if diff ../outputs/t644 ../originals/t644 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p645) timeout -s 9 2 ../source/tcas.exe 0 1 1 752 563 695 1 602 656 0 2 1     > ../outputs/t645
    if diff ../outputs/t645 ../originals/t645 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p646) timeout -s 9 2 ../source/tcas.exe 1004 1 0 0 393 597 1 450 743 0 2 0     > ../outputs/t646
    if diff ../outputs/t646 ../originals/t646 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p647) timeout -s 9 2 ../source/tcas.exe 849 1 1 734 651 0 2 571 565 0 2 1     > ../outputs/t647
    if diff ../outputs/t647 ../originals/t647 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p648) timeout -s 9 2 ../source/tcas.exe 777 1 0 6281 379 700 0 594 0 0 2 1     > ../outputs/t648
    if diff ../outputs/t648 ../originals/t648 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p649) timeout -s 9 2 ../source/tcas.exe 1169 1 0 616 922 690 3 0 784 0 2 0     > ../outputs/t649
    if diff ../outputs/t649 ../originals/t649 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p650) timeout -s 9 2 ../source/tcas.exe 1090 1 0 762 308 713 1 774 759 1 1 0     > ../outputs/t650
    if diff ../outputs/t650 ../originals/t650 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p651) timeout -s 9 2 ../source/tcas.exe 1170 1 1 605 569 629 2 662 665 0 2 9     > ../outputs/t651
    if diff ../outputs/t651 ../originals/t651 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p652) timeout -s 9 2 ../source/tcas.exe 981 1 1 459 317 590 2 533 544 2 2 1     > ../outputs/t652
    if diff ../outputs/t652 ../originals/t652 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p653) timeout -s 9 2 ../source/tcas.exe 1158 0 0 608 441 601 0 671 812 0 2 1     > ../outputs/t653
    if diff ../outputs/t653 ../originals/t653 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p654) timeout -s 9 2 ../source/tcas.exe 0 1 0 1049 563 594 3 401 372 0 2 0     > ../outputs/t654
    if diff ../outputs/t654 ../originals/t654 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p655) timeout -s 9 2 ../source/tcas.exe 1105 1 1 -100 430 529 3 842 74 0 2 1     > ../outputs/t655
    if diff ../outputs/t655 ../originals/t655 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p656) timeout -s 9 2 ../source/tcas.exe 680 1 1 3803 981 581 3 769 812 0 2 0     > ../outputs/t656
    if diff ../outputs/t656 ../originals/t656 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p657) timeout -s 9 2 ../source/tcas.exe 1165 1 0 690 19 871 0 293 346 1 2 0     > ../outputs/t657
    if diff ../outputs/t657 ../originals/t657 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p658) timeout -s 9 2 ../source/tcas.exe 0 1 0 570 620 611 0 992 1023 0 2 0     > ../outputs/t658
    if diff ../outputs/t658 ../originals/t658 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p659) timeout -s 9 2 ../source/tcas.exe 1105 0 0 584 450 293 1 755 638 0 1 1     > ../outputs/t659
    if diff ../outputs/t659 ../originals/t659 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p660) timeout -s 9 2 ../source/tcas.exe 966 -1 1 3658 196 660 1 0 452 0 2 1     > ../outputs/t660
    if diff ../outputs/t660 ../originals/t660 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p661) timeout -s 9 2 ../source/tcas.exe 639 1 0 8459 370 678 1 737 810 0 1 0     > ../outputs/t661
    if diff ../outputs/t661 ../originals/t661 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p662) timeout -s 9 2 ../source/tcas.exe 836 1 0 637 -1 0 0 984 1003 0 2 1     > ../outputs/t662
    if diff ../outputs/t662 ../originals/t662 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p663) timeout -s 9 2 ../source/tcas.exe 903 1 1 684 368 661 0 725 0 0 2 1     > ../outputs/t663
    if diff ../outputs/t663 ../originals/t663 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p664) timeout -s 9 2 ../source/tcas.exe 908 0 0 613 38 564 1 775 835 1 2 0     > ../outputs/t664
    if diff ../outputs/t664 ../originals/t664 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p665) timeout -s 9 2 ../source/tcas.exe 1196 0 -1 688 398 663 0 485 434 0 1 1     > ../outputs/t665
    if diff ../outputs/t665 ../originals/t665 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p666) timeout -s 9 2 ../source/tcas.exe 1055 1 0 9520 512 686 3 0 368 0 2 1     > ../outputs/t666
    if diff ../outputs/t666 ../originals/t666 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p667) timeout -s 9 2 ../source/tcas.exe 618 -1 1 737 0 708 1 907 371 0 2 0     > ../outputs/t667
    if diff ../outputs/t667 ../originals/t667 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p668) timeout -s 9 2 ../source/tcas.exe 825 1 1 783 329 499 3 931 914 1 2 1     > ../outputs/t668
    if diff ../outputs/t668 ../originals/t668 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p669) timeout -s 9 2 ../source/tcas.exe 969 1 0 719 330 690 1 932 -1 0 2 0     > ../outputs/t669
    if diff ../outputs/t669 ../originals/t669 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p670) timeout -s 9 2 ../source/tcas.exe 1072 1 1 0 457 603 0 481 759 1 2 1     > ../outputs/t670
    if diff ../outputs/t670 ../originals/t670 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p671) timeout -s 9 2 ../source/tcas.exe 1101 1 1 713 422 0 3 785 778 1 2 1     > ../outputs/t671
    if diff ../outputs/t671 ../originals/t671 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p672) timeout -s 9 2 ../source/tcas.exe 1119 1 1 586 386 221 2 830 979 0 2 0     > ../outputs/t672
    if diff ../outputs/t672 ../originals/t672 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p673) timeout -s 9 2 ../source/tcas.exe 832 1 -1 82 314 0 2 0 806 0 2 1     > ../outputs/t673
    if diff ../outputs/t673 ../originals/t673 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p674) timeout -s 9 2 ../source/tcas.exe 767 1 1 726 767 714 2 0 798 2 2 0     > ../outputs/t674
    if diff ../outputs/t674 ../originals/t674 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p675) timeout -s 9 2 ../source/tcas.exe 1188 1 1 590 758 610 1 691 669 2 1 1     > ../outputs/t675
    if diff ../outputs/t675 ../originals/t675 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p676) timeout -s 9 2 ../source/tcas.exe 1030 1 1 743 536 737 3 597 754 1 2 1     > ../outputs/t676
    if diff ../outputs/t676 ../originals/t676 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p677) timeout -s 9 2 ../source/tcas.exe -1 1 0 5409 534 551 0 175 764 0 2 1     > ../outputs/t677
    if diff ../outputs/t677 ../originals/t677 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p678) timeout -s 9 2 ../source/tcas.exe 880 1 1 651 496 696 2 716 283 0 1 1     > ../outputs/t678
    if diff ../outputs/t678 ../originals/t678 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p679) timeout -s 9 2 ../source/tcas.exe 656 1 1 612 513 543 1 0 285 0 1 1     > ../outputs/t679
    if diff ../outputs/t679 ../originals/t679 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p680) timeout -s 9 2 ../source/tcas.exe 990 1 1 9671 622 173 2 0 766 0 2 1     > ../outputs/t680
    if diff ../outputs/t680 ../originals/t680 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p681) timeout -s 9 2 ../source/tcas.exe -100 1 1 650 497 655 3 806 764 0 2 1     > ../outputs/t681
    if diff ../outputs/t681 ../originals/t681 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p682) timeout -s 9 2 ../source/tcas.exe 759 1 0 5966 544 494 2 965 955 -1 2 0     > ../outputs/t682
    if diff ../outputs/t682 ../originals/t682 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p683) timeout -s 9 2 ../source/tcas.exe 636 1 0 637 352 716 1 335 -100 0 2 1     > ../outputs/t683
    if diff ../outputs/t683 ../originals/t683 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p684) timeout -s 9 2 ../source/tcas.exe 922 1 0 583 576 558 1 435 474 1 2 0     > ../outputs/t684
    if diff ../outputs/t684 ../originals/t684 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p685) timeout -s 9 2 ../source/tcas.exe 967 1 0 2215 354 582 0 999 0 0 2 1     > ../outputs/t685
    if diff ../outputs/t685 ../originals/t685 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p686) timeout -s 9 2 ../source/tcas.exe 937 1 0 605 0 554 0 633 622 0 2 0     > ../outputs/t686
    if diff ../outputs/t686 ../originals/t686 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p687) timeout -s 9 2 ../source/tcas.exe 594 1 1 770 455 751 0 610 -1 0 2 0     > ../outputs/t687
    if diff ../outputs/t687 ../originals/t687 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p688) timeout -s 9 2 ../source/tcas.exe 1057 1 0 0 379 614 0 812 799 0 2 -1     > ../outputs/t688
    if diff ../outputs/t688 ../originals/t688 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p689) timeout -s 9 2 ../source/tcas.exe 736 0 1 7870 571 700 3 469 438 0 2 1     > ../outputs/t689
    if diff ../outputs/t689 ../originals/t689 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p690) timeout -s 9 2 ../source/tcas.exe 690 1 0 626 252 676 3 366 611 0 1 1     > ../outputs/t690
    if diff ../outputs/t690 ../originals/t690 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p691) timeout -s 9 2 ../source/tcas.exe 458 1 0 4251 551 721 1 617 588 0 1 0     > ../outputs/t691
    if diff ../outputs/t691 ../originals/t691 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p692) timeout -s 9 2 ../source/tcas.exe 795 1 1 1372 334 686 3 559 381 0 2 1     > ../outputs/t692
    if diff ../outputs/t692 ../originals/t692 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p693) timeout -s 9 2 ../source/tcas.exe 842 0 0 631 599 623 3 910 875 1 2 1     > ../outputs/t693
    if diff ../outputs/t693 ../originals/t693 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p694) timeout -s 9 2 ../source/tcas.exe 702 1 0 695 889 0 0 412 469 0 2 0     > ../outputs/t694
    if diff ../outputs/t694 ../originals/t694 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p695) timeout -s 9 2 ../source/tcas.exe 681 1 0 1904 340 904 3 344 360 0 2 0     > ../outputs/t695
    if diff ../outputs/t695 ../originals/t695 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p696) timeout -s 9 2 ../source/tcas.exe 945 1 0 720 292 692 1 890 888 0 1 0     > ../outputs/t696
    if diff ../outputs/t696 ../originals/t696 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p697) timeout -s 9 2 ../source/tcas.exe 896 1 0 592 405 882 1 466 549 0 1 0     > ../outputs/t697
    if diff ../outputs/t697 ../originals/t697 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p698) timeout -s 9 2 ../source/tcas.exe 832 1 0 9715 387 665 1 899 800 0 2 1     > ../outputs/t698
    if diff ../outputs/t698 ../originals/t698 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p699) timeout -s 9 2 ../source/tcas.exe 651 1 0 -1 571 599 2 41 514 0 2 0     > ../outputs/t699
    if diff ../outputs/t699 ../originals/t699 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p700) timeout -s 9 2 ../source/tcas.exe 1098 1 1 664 607 0 -1 580 162 0 2 0     > ../outputs/t700
    if diff ../outputs/t700 ../originals/t700 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p701) timeout -s 9 2 ../source/tcas.exe 0 1 0 713 334 670 2 353 328 1 2 1     > ../outputs/t701
    if diff ../outputs/t701 ../originals/t701 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p702) timeout -s 9 2 ../source/tcas.exe 603 -1 0 654 507 11 3 611 600 0 1 1     > ../outputs/t702
    if diff ../outputs/t702 ../originals/t702 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p703) timeout -s 9 2 ../source/tcas.exe 848 1 0 645 519 579 9 512 970 0 2 0     > ../outputs/t703
    if diff ../outputs/t703 ../originals/t703 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p704) timeout -s 9 2 ../source/tcas.exe 19 0 0 4907 421 657 1 665 0 0 2 0     > ../outputs/t704
    if diff ../outputs/t704 ../originals/t704 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p705) timeout -s 9 2 ../source/tcas.exe 772 1 0 0 311 599 2 978 891 1 2 0     > ../outputs/t705
    if diff ../outputs/t705 ../originals/t705 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p706) timeout -s 9 2 ../source/tcas.exe 613 1 0 0 413 696 3 794 743 0 2 1     > ../outputs/t706
    if diff ../outputs/t706 ../originals/t706 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p707) timeout -s 9 2 ../source/tcas.exe 1092 1 1 2461 931 0 2 647 715 2 2 0     > ../outputs/t707
    if diff ../outputs/t707 ../originals/t707 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p708) timeout -s 9 2 ../source/tcas.exe -1 1 0 655 565 658 0 858 870 0 2 0     > ../outputs/t708
    if diff ../outputs/t708 ../originals/t708 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p709) timeout -s 9 2 ../source/tcas.exe 1106 0 0 521 0 592 2 220 0 0 2 1     > ../outputs/t709
    if diff ../outputs/t709 ../originals/t709 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p710) timeout -s 9 2 ../source/tcas.exe 746 1 0 653 345 667 3 386 153 0 1 0     > ../outputs/t710
    if diff ../outputs/t710 ../originals/t710 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p711) timeout -s 9 2 ../source/tcas.exe 683 1 1 8310 300 0 1 0 0 0 1 1     > ../outputs/t711
    if diff ../outputs/t711 ../originals/t711 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p712) timeout -s 9 2 ../source/tcas.exe -100 0 0 636 630 0 0 467 507 1 2 0     > ../outputs/t712
    if diff ../outputs/t712 ../originals/t712 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p713) timeout -s 9 2 ../source/tcas.exe 469 1 1 579 703 109 3 432 500 0 2 1     > ../outputs/t713
    if diff ../outputs/t713 ../originals/t713 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p714) timeout -s 9 2 ../source/tcas.exe 717 1 -1 641 433 500 2 145 0 2 2 0     > ../outputs/t714
    if diff ../outputs/t714 ../originals/t714 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p715) timeout -s 9 2 ../source/tcas.exe 699 1 0 -1 311 0 1 705 854 2 2 1     > ../outputs/t715
    if diff ../outputs/t715 ../originals/t715 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p716) timeout -s 9 2 ../source/tcas.exe -1 1 1 685 442 -1 2 338 364 0 2 1     > ../outputs/t716
    if diff ../outputs/t716 ../originals/t716 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p717) timeout -s 9 2 ../source/tcas.exe 844 1 0 683 0 663 2 361 725 2 2 0     > ../outputs/t717
    if diff ../outputs/t717 ../originals/t717 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p718) timeout -s 9 2 ../source/tcas.exe 733 1 0 696 228 704 3 693 638 1 2 0     > ../outputs/t718
    if diff ../outputs/t718 ../originals/t718 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p719) timeout -s 9 2 ../source/tcas.exe 733 0 0 730 717 747 1 767 288 2 2 0     > ../outputs/t719
    if diff ../outputs/t719 ../originals/t719 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p720) timeout -s 9 2 ../source/tcas.exe 653 1 0 605 619 554 3 913 601 2 2 0     > ../outputs/t720
    if diff ../outputs/t720 ../originals/t720 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p721) timeout -s 9 2 ../source/tcas.exe 1115 1 1 739 422 739 2 528 534 3 1 1     > ../outputs/t721
    if diff ../outputs/t721 ../originals/t721 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p722) timeout -s 9 2 ../source/tcas.exe 926 1 0 590 50 532 3 957 922 0 2 0     > ../outputs/t722
    if diff ../outputs/t722 ../originals/t722 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p723) timeout -s 9 2 ../source/tcas.exe 675 -1 0 656 506 655 0 564 590 0 2 0     > ../outputs/t723
    if diff ../outputs/t723 ../originals/t723 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p724) timeout -s 9 2 ../source/tcas.exe 1179 1 0 697 805 691 0 594 213 0 2 1     > ../outputs/t724
    if diff ../outputs/t724 ../originals/t724 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p725) timeout -s 9 2 ../source/tcas.exe 1166 1 1 0 352 748 3 297 318 0 1 0     > ../outputs/t725
    if diff ../outputs/t725 ../originals/t725 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p726) timeout -s 9 2 ../source/tcas.exe 232 1 1 564 333 0 1 862 601 0 2 0     > ../outputs/t726
    if diff ../outputs/t726 ../originals/t726 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p727) timeout -s 9 2 ../source/tcas.exe 0 1 0 743 318 747 2 694 726 0 1 1     > ../outputs/t727
    if diff ../outputs/t727 ../originals/t727 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p728) timeout -s 9 2 ../source/tcas.exe 829 1 0 0 464 314 3 784 809 0 1 0     > ../outputs/t728
    if diff ../outputs/t728 ../originals/t728 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p729) timeout -s 9 2 ../source/tcas.exe 1195 1 0 0 460 666 3 509 492 0 2 0     > ../outputs/t729
    if diff ../outputs/t729 ../originals/t729 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p730) timeout -s 9 2 ../source/tcas.exe 790 1 1 719 436 697 1 681 417 2 2 1     > ../outputs/t730
    if diff ../outputs/t730 ../originals/t730 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p731) timeout -s 9 2 ../source/tcas.exe 878 1 0 681 131 650 1 855 816 2 2 1     > ../outputs/t731
    if diff ../outputs/t731 ../originals/t731 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p732) timeout -s 9 2 ../source/tcas.exe 0 1 0 634 577 673 2 527 635 0 2 0     > ../outputs/t732
    if diff ../outputs/t732 ../originals/t732 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p733) timeout -s 9 2 ../source/tcas.exe -1 1 1 513 194 552 0 0 331 0 2 0     > ../outputs/t733
    if diff ../outputs/t733 ../originals/t733 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p734) timeout -s 9 2 ../source/tcas.exe 616 0 1 752 604 702 0 459 857 0 2 1     > ../outputs/t734
    if diff ../outputs/t734 ../originals/t734 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p735) timeout -s 9 2 ../source/tcas.exe 1129 1 0 665 586 225 2 785 973 0 2 0     > ../outputs/t735
    if diff ../outputs/t735 ../originals/t735 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p736) timeout -s 9 2 ../source/tcas.exe 1017 1 0 666 369 646 3 -1 772 0 2 1     > ../outputs/t736
    if diff ../outputs/t736 ../originals/t736 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p737) timeout -s 9 2 ../source/tcas.exe 1124 1 0 605 233 507 1 0 409 0 2 1     > ../outputs/t737
    if diff ../outputs/t737 ../originals/t737 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p738) timeout -s 9 2 ../source/tcas.exe 608 1 1 685 588 718 3 17 883 0 1 1     > ../outputs/t738
    if diff ../outputs/t738 ../originals/t738 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p739) timeout -s 9 2 ../source/tcas.exe 983 1 1 0 636 741 2 460 275 0 1 0     > ../outputs/t739
    if diff ../outputs/t739 ../originals/t739 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p740) timeout -s 9 2 ../source/tcas.exe 334 1 0 728 533 660 2 481 496 0 1 0     > ../outputs/t740
    if diff ../outputs/t740 ../originals/t740 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p741) timeout -s 9 2 ../source/tcas.exe 611 1 0 660 667 0 1 936 924 0 1 0     > ../outputs/t741
    if diff ../outputs/t741 ../originals/t741 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p742) timeout -s 9 2 ../source/tcas.exe 1036 0 0 586 585 304 0 505 578 1 2 0     > ../outputs/t742
    if diff ../outputs/t742 ../originals/t742 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p743) timeout -s 9 2 ../source/tcas.exe 881 1 -1 740 521 722 3 311 958 1 2 0     > ../outputs/t743
    if diff ../outputs/t743 ../originals/t743 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p744) timeout -s 9 2 ../source/tcas.exe 1173 1 0 5952 576 657 0 292 741 2 1 1     > ../outputs/t744
    if diff ../outputs/t744 ../originals/t744 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p745) timeout -s 9 2 ../source/tcas.exe 930 1 0 642 311 0 3 0 699 0 1 1     > ../outputs/t745
    if diff ../outputs/t745 ../originals/t745 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p746) timeout -s 9 2 ../source/tcas.exe 1108 1 0 772 879 723 0 286 340 0 1 0     > ../outputs/t746
    if diff ../outputs/t746 ../originals/t746 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p747) timeout -s 9 2 ../source/tcas.exe 0 1 0 592 607 626 1 586 642 0 2 1     > ../outputs/t747
    if diff ../outputs/t747 ../originals/t747 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p748) timeout -s 9 2 ../source/tcas.exe 0 1 1 771 401 503 2 513 822 0 2 1     > ../outputs/t748
    if diff ../outputs/t748 ../originals/t748 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p749) timeout -s 9 2 ../source/tcas.exe 1019 0 1 6630 400 631 0 416 384 0 2 0     > ../outputs/t749
    if diff ../outputs/t749 ../originals/t749 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p750) timeout -s 9 2 ../source/tcas.exe -1 1 0 -100 606 721 3 927 947 2 2 1     > ../outputs/t750
    if diff ../outputs/t750 ../originals/t750 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p751) timeout -s 9 2 ../source/tcas.exe 915 0 0 721 613 784 2 330 356 2 1 0     > ../outputs/t751
    if diff ../outputs/t751 ../originals/t751 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p752) timeout -s 9 2 ../source/tcas.exe 816 1 0 706 496 737 1 917 908 -1 2 0     > ../outputs/t752
    if diff ../outputs/t752 ../originals/t752 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p753) timeout -s 9 2 ../source/tcas.exe 1150 1 1 594 -100 533 2 494 548 0 2 0     > ../outputs/t753
    if diff ../outputs/t753 ../originals/t753 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p754) timeout -s 9 2 ../source/tcas.exe 0 1 0 767 593 798 2 657 678 1 2 0     > ../outputs/t754
    if diff ../outputs/t754 ../originals/t754 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p755) timeout -s 9 2 ../source/tcas.exe 833 0 1 648 385 621 0 446 0 0 2 1     > ../outputs/t755
    if diff ../outputs/t755 ../originals/t755 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p756) timeout -s 9 2 ../source/tcas.exe 991 0 0 6052 411 45 0 1028 977 2 2 0     > ../outputs/t756
    if diff ../outputs/t756 ../originals/t756 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p757) timeout -s 9 2 ../source/tcas.exe 1058 -1 0 643 495 661 0 1001 978 0 1 1     > ../outputs/t757
    if diff ../outputs/t757 ../originals/t757 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p758) timeout -s 9 2 ../source/tcas.exe 693 0 1 639 352 609 1 470 793 0 2 0     > ../outputs/t758
    if diff ../outputs/t758 ../originals/t758 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p759) timeout -s 9 2 ../source/tcas.exe 925 1 1 625 491 584 0 421 592 1 1 1     > ../outputs/t759
    if diff ../outputs/t759 ../originals/t759 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p760) timeout -s 9 2 ../source/tcas.exe 810 1 0 0 296 50 1 446 -1 0 2 0     > ../outputs/t760
    if diff ../outputs/t760 ../originals/t760 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p761) timeout -s 9 2 ../source/tcas.exe 855 1 0 4592 49 290 0 627 617 0 2 0     > ../outputs/t761
    if diff ../outputs/t761 ../originals/t761 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p762) timeout -s 9 2 ../source/tcas.exe 834 1 0 638 378 0 2 0 842 0 2 1     > ../outputs/t762
    if diff ../outputs/t762 ../originals/t762 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p763) timeout -s 9 2 ../source/tcas.exe 573 1 0 667 0 623 0 651 671 1 1 0     > ../outputs/t763
    if diff ../outputs/t763 ../originals/t763 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p764) timeout -s 9 2 ../source/tcas.exe 1134 0 0 559 587 0 0 1003 0 0 2 0     > ../outputs/t764
    if diff ../outputs/t764 ../originals/t764 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p765) timeout -s 9 2 ../source/tcas.exe 817 1 0 566 402 603 2 348 760 0 2 1     > ../outputs/t765
    if diff ../outputs/t765 ../originals/t765 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p766) timeout -s 9 2 ../source/tcas.exe 610 0 0 0 587 665 3 673 722 0 2 1     > ../outputs/t766
    if diff ../outputs/t766 ../originals/t766 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p767) timeout -s 9 2 ../source/tcas.exe -1 1 0 631 461 0 0 645 604 0 2 1     > ../outputs/t767
    if diff ../outputs/t767 ../originals/t767 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p768) timeout -s 9 2 ../source/tcas.exe 1046 1 -1 565 505 553 1 -100 975 0 2 1     > ../outputs/t768
    if diff ../outputs/t768 ../originals/t768 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p769) timeout -s 9 2 ../source/tcas.exe 832 1 0 562 347 788 0 0 785 2 2 1     > ../outputs/t769
    if diff ../outputs/t769 ../originals/t769 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p770) timeout -s 9 2 ../source/tcas.exe 621 1 1 6021 353 718 1 320 561 0 1 1     > ../outputs/t770
    if diff ../outputs/t770 ../originals/t770 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p771) timeout -s 9 2 ../source/tcas.exe 789 -1 0 707 518 636 3 137 0 0 1 1     > ../outputs/t771
    if diff ../outputs/t771 ../originals/t771 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p772) timeout -s 9 2 ../source/tcas.exe 649 0 0 645 347 702 1 502 76 0 2 1     > ../outputs/t772
    if diff ../outputs/t772 ../originals/t772 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p773) timeout -s 9 2 ../source/tcas.exe 657 1 0 666 0 613 0 840 976 0 2 0     > ../outputs/t773
    if diff ../outputs/t773 ../originals/t773 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p774) timeout -s 9 2 ../source/tcas.exe 688 0 0 0 561 594 0 713 675 0 2 0     > ../outputs/t774
    if diff ../outputs/t774 ../originals/t774 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p775) timeout -s 9 2 ../source/tcas.exe 612 1 0 555 479 560 4 0 651 0 2 1     > ../outputs/t775
    if diff ../outputs/t775 ../originals/t775 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p776) timeout -s 9 2 ../source/tcas.exe 1046 0 0 8338 578 663 3 936 892 0 1 0     > ../outputs/t776
    if diff ../outputs/t776 ../originals/t776 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p777) timeout -s 9 2 ../source/tcas.exe 1153 1 1 745 861 0 1 748 566 1 2 0     > ../outputs/t777
    if diff ../outputs/t777 ../originals/t777 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p778) timeout -s 9 2 ../source/tcas.exe 824 1 0 0 519 426 1 357 694 0 2 0     > ../outputs/t778
    if diff ../outputs/t778 ../originals/t778 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p779) timeout -s 9 2 ../source/tcas.exe 815 1 0 582 0 543 0 906 897 2 2 0     > ../outputs/t779
    if diff ../outputs/t779 ../originals/t779 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p780) timeout -s 9 2 ../source/tcas.exe 1188 1 0 592 426 979 1 911 -1 2 2 1     > ../outputs/t780
    if diff ../outputs/t780 ../originals/t780 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p781) timeout -s 9 2 ../source/tcas.exe 0 0 1 6241 380 757 3 0 890 0 2 0     > ../outputs/t781
    if diff ../outputs/t781 ../originals/t781 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p782) timeout -s 9 2 ../source/tcas.exe 1132 1 0 0 607 565 1 351 593 2 2 1     > ../outputs/t782
    if diff ../outputs/t782 ../originals/t782 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p783) timeout -s 9 2 ../source/tcas.exe 813 1 1 694 381 722 0 357 0 0 2 1     > ../outputs/t783
    if diff ../outputs/t783 ../originals/t783 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p784) timeout -s 9 2 ../source/tcas.exe 1075 1 1 515 0 611 1 830 0 0 2 0     > ../outputs/t784
    if diff ../outputs/t784 ../originals/t784 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p785) timeout -s 9 2 ../source/tcas.exe 1140 1 1 9266 412 763 0 344 384 2 2 0     > ../outputs/t785
    if diff ../outputs/t785 ../originals/t785 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p786) timeout -s 9 2 ../source/tcas.exe 633 0 0 636 533 661 0 573 553 2 1 1     > ../outputs/t786
    if diff ../outputs/t786 ../originals/t786 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p787) timeout -s 9 2 ../source/tcas.exe 1000 0 0 -100 566 687 1 477 241 0 1 0     > ../outputs/t787
    if diff ../outputs/t787 ../originals/t787 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p788) timeout -s 9 2 ../source/tcas.exe 1022 1 0 647 988 694 1 0 0 0 2 0     > ../outputs/t788
    if diff ../outputs/t788 ../originals/t788 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p789) timeout -s 9 2 ../source/tcas.exe 607 1 0 603 447 688 -1 787 829 0 2 0     > ../outputs/t789
    if diff ../outputs/t789 ../originals/t789 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p790) timeout -s 9 2 ../source/tcas.exe -1 1 0 538 409 0 2 474 479 2 2 0     > ../outputs/t790
    if diff ../outputs/t790 ../originals/t790 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p791) timeout -s 9 2 ../source/tcas.exe 627 0 0 697 398 828 -1 915 919 0 2 1     > ../outputs/t791
    if diff ../outputs/t791 ../originals/t791 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p792) timeout -s 9 2 ../source/tcas.exe 892 1 1 1424 630 0 3 550 586 0 2 3     > ../outputs/t792
    if diff ../outputs/t792 ../originals/t792 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p793) timeout -s 9 2 ../source/tcas.exe 764 1 0 9447 619 0 3 747 769 1 2 1     > ../outputs/t793
    if diff ../outputs/t793 ../originals/t793 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p794) timeout -s 9 2 ../source/tcas.exe 664 0 1 693 536 655 1 -100 0 0 2 0     > ../outputs/t794
    if diff ../outputs/t794 ../originals/t794 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p795) timeout -s 9 2 ../source/tcas.exe 1101 0 1 4426 372 625 1 518 566 0 2 0     > ../outputs/t795
    if diff ../outputs/t795 ../originals/t795 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p796) timeout -s 9 2 ../source/tcas.exe 890 1 0 3344 502 537 1 417 578 0 2 0     > ../outputs/t796
    if diff ../outputs/t796 ../originals/t796 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p797) timeout -s 9 2 ../source/tcas.exe 154 1 0 642 514 661 2 999 0 0 1 0     > ../outputs/t797
    if diff ../outputs/t797 ../originals/t797 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p798) timeout -s 9 2 ../source/tcas.exe 774 0 0 0 623 664 0 817 807 0 2 1     > ../outputs/t798
    if diff ../outputs/t798 ../originals/t798 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p799) timeout -s 9 2 ../source/tcas.exe 741 1 0 5872 449 649 2 0 -1 2 2 0     > ../outputs/t799
    if diff ../outputs/t799 ../originals/t799 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p800) timeout -s 9 2 ../source/tcas.exe 739 1 0 7 609 597 3 0 343 0 2 0     > ../outputs/t800
    if diff ../outputs/t800 ../originals/t800 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p801) timeout -s 9 2 ../source/tcas.exe 681 -1 1 9974 308 564 2 391 396 0 2 0     > ../outputs/t801
    if diff ../outputs/t801 ../originals/t801 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p802) timeout -s 9 2 ../source/tcas.exe 789 1 1 635 557 720 4 694 0 0 2 1     > ../outputs/t802
    if diff ../outputs/t802 ../originals/t802 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p803) timeout -s 9 2 ../source/tcas.exe 1009 1 1 606 320 530 2 0 0 0 2 1     > ../outputs/t803
    if diff ../outputs/t803 ../originals/t803 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p804) timeout -s 9 2 ../source/tcas.exe 608 1 0 531 628 547 3 -1 482 1 2 1     > ../outputs/t804
    if diff ../outputs/t804 ../originals/t804 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p805) timeout -s 9 2 ../source/tcas.exe 1200 0 1 626 534 642 0 758 744 1 2 1     > ../outputs/t805
    if diff ../outputs/t805 ../originals/t805 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p806) timeout -s 9 2 ../source/tcas.exe 1181 0 0 714 351 781 0 419 0 0 1 1     > ../outputs/t806
    if diff ../outputs/t806 ../originals/t806 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p807) timeout -s 9 2 ../source/tcas.exe 0 1 0 734 330 755 3 831 892 0 1 0     > ../outputs/t807
    if diff ../outputs/t807 ../originals/t807 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p808) timeout -s 9 2 ../source/tcas.exe 994 0 1 7341 364 742 0 606 659 0 2 1     > ../outputs/t808
    if diff ../outputs/t808 ../originals/t808 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p809) timeout -s 9 2 ../source/tcas.exe 586 0 1 790 79 0 0 689 677 0 2 0     > ../outputs/t809
    if diff ../outputs/t809 ../originals/t809 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p810) timeout -s 9 2 ../source/tcas.exe -1 1 0 1231 543 671 2 545 545 0 2 1     > ../outputs/t810
    if diff ../outputs/t810 ../originals/t810 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p811) timeout -s 9 2 ../source/tcas.exe 890 1 0 0 577 622 0 0 284 0 2 1     > ../outputs/t811
    if diff ../outputs/t811 ../originals/t811 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p812) timeout -s 9 2 ../source/tcas.exe 695 1 0 560 0 578 3 807 988 0 2 1     > ../outputs/t812
    if diff ../outputs/t812 ../originals/t812 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p813) timeout -s 9 2 ../source/tcas.exe 47 1 1 685 497 668 3 812 817 0 2 0     > ../outputs/t813
    if diff ../outputs/t813 ../originals/t813 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p814) timeout -s 9 2 ../source/tcas.exe 1157 0 0 766 480 432 3 0 0 0 2 0     > ../outputs/t814
    if diff ../outputs/t814 ../originals/t814 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p815) timeout -s 9 2 ../source/tcas.exe 659 1 0 0 865 578 3 452 538 1 2 1     > ../outputs/t815
    if diff ../outputs/t815 ../originals/t815 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p816) timeout -s 9 2 ../source/tcas.exe 1046 1 0 531 505 557 2 261 0 0 1 0     > ../outputs/t816
    if diff ../outputs/t816 ../originals/t816 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p817) timeout -s 9 2 ../source/tcas.exe 724 0 1 662 0 0 0 762 728 0 2 1     > ../outputs/t817
    if diff ../outputs/t817 ../originals/t817 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p818) timeout -s 9 2 ../source/tcas.exe 989 1 1 714 693 746 2 960 903 0 2 9     > ../outputs/t818
    if diff ../outputs/t818 ../originals/t818 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p819) timeout -s 9 2 ../source/tcas.exe 377 0 0 5169 412 572 3 801 797 0 2 1     > ../outputs/t819
    if diff ../outputs/t819 ../originals/t819 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p820) timeout -s 9 2 ../source/tcas.exe 619 1 0 0 480 0 0 928 0 0 1 1     > ../outputs/t820
    if diff ../outputs/t820 ../originals/t820 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p821) timeout -s 9 2 ../source/tcas.exe 879 1 1 793 310 -1 2 622 593 0 2 1     > ../outputs/t821
    if diff ../outputs/t821 ../originals/t821 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p822) timeout -s 9 2 ../source/tcas.exe 635 1 0 585 -1 0 1 0 971 0 2 1     > ../outputs/t822
    if diff ../outputs/t822 ../originals/t822 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p823) timeout -s 9 2 ../source/tcas.exe 0 0 0 621 413 714 2 416 360 0 2 1     > ../outputs/t823
    if diff ../outputs/t823 ../originals/t823 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p824) timeout -s 9 2 ../source/tcas.exe -1 1 0 770 600 0 0 401 359 0 2 0     > ../outputs/t824
    if diff ../outputs/t824 ../originals/t824 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p825) timeout -s 9 2 ../source/tcas.exe 674 1 0 679 472 655 3 523 -1 1 1 1     > ../outputs/t825
    if diff ../outputs/t825 ../originals/t825 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p826) timeout -s 9 2 ../source/tcas.exe 1041 1 -1 0 494 660 3 68 546 0 2 0     > ../outputs/t826
    if diff ../outputs/t826 ../originals/t826 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p827) timeout -s 9 2 ../source/tcas.exe 1136 1 0 600 151 0 2 699 867 0 2 1     > ../outputs/t827
    if diff ../outputs/t827 ../originals/t827 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p828) timeout -s 9 2 ../source/tcas.exe -1 1 1 679 532 628 3 0 360 0 2 0     > ../outputs/t828
    if diff ../outputs/t828 ../originals/t828 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p829) timeout -s 9 2 ../source/tcas.exe 890 1 1 0 523 931 1 880 866 2 2 1     > ../outputs/t829
    if diff ../outputs/t829 ../originals/t829 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p830) timeout -s 9 2 ../source/tcas.exe 970 1 1 620 469 126 0 0 0 0 2 0     > ../outputs/t830
    if diff ../outputs/t830 ../originals/t830 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p831) timeout -s 9 2 ../source/tcas.exe 1195 1 1 622 378 621 2 520 0 2 2 0     > ../outputs/t831
    if diff ../outputs/t831 ../originals/t831 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p832) timeout -s 9 2 ../source/tcas.exe 834 0 0 573 887 599 1 0 874 0 2 0     > ../outputs/t832
    if diff ../outputs/t832 ../originals/t832 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p833) timeout -s 9 2 ../source/tcas.exe 629 0 1 615 603 663 0 897 874 -1 1 1     > ../outputs/t833
    if diff ../outputs/t833 ../originals/t833 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p834) timeout -s 9 2 ../source/tcas.exe 1145 1 0 718 520 628 0 639 0 3 2 1     > ../outputs/t834
    if diff ../outputs/t834 ../originals/t834 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p835) timeout -s 9 2 ../source/tcas.exe 623 -1 0 683 461 732 3 634 671 0 2 1     > ../outputs/t835
    if diff ../outputs/t835 ../originals/t835 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p836) timeout -s 9 2 ../source/tcas.exe 774 0 0 654 427 636 1 0 0 1 2 1     > ../outputs/t836
    if diff ../outputs/t836 ../originals/t836 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p837) timeout -s 9 2 ../source/tcas.exe 653 1 1 688 592 709 3 883 849 0 1 -1     > ../outputs/t837
    if diff ../outputs/t837 ../originals/t837 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p838) timeout -s 9 2 ../source/tcas.exe 987 0 1 740 67 735 3 330 326 0 2 1     > ../outputs/t838
    if diff ../outputs/t838 ../originals/t838 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p839) timeout -s 9 2 ../source/tcas.exe 852 1 0 694 586 708 1 -100 621 0 2 1     > ../outputs/t839
    if diff ../outputs/t839 ../originals/t839 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p840) timeout -s 9 2 ../source/tcas.exe 847 1 0 626 888 580 1 0 172 0 2 1     > ../outputs/t840
    if diff ../outputs/t840 ../originals/t840 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p841) timeout -s 9 2 ../source/tcas.exe 1099 1 1 670 349 680 3 729 789 2 2 0     > ../outputs/t841
    if diff ../outputs/t841 ../originals/t841 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p842) timeout -s 9 2 ../source/tcas.exe 841 1 0 0 351 719 3 485 0 0 1 0     > ../outputs/t842
    if diff ../outputs/t842 ../originals/t842 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p843) timeout -s 9 2 ../source/tcas.exe 929 0 0 0 408 754 0 211 941 0 2 1     > ../outputs/t843
    if diff ../outputs/t843 ../originals/t843 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p844) timeout -s 9 2 ../source/tcas.exe 691 0 0 0 548 737 1 410 364 1 1 0     > ../outputs/t844
    if diff ../outputs/t844 ../originals/t844 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p845) timeout -s 9 2 ../source/tcas.exe 0 0 1 604 473 650 3 536 0 0 2 1     > ../outputs/t845
    if diff ../outputs/t845 ../originals/t845 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p846) timeout -s 9 2 ../source/tcas.exe 1002 1 0 706 306 668 2 0 -100 0 2 1     > ../outputs/t846
    if diff ../outputs/t846 ../originals/t846 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p847) timeout -s 9 2 ../source/tcas.exe 819 1 1 9386 518 775 1 707 726 2 2 0     > ../outputs/t847
    if diff ../outputs/t847 ../originals/t847 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p848) timeout -s 9 2 ../source/tcas.exe 1077 1 -1 593 324 636 2 0 448 0 2 1     > ../outputs/t848
    if diff ../outputs/t848 ../originals/t848 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p849) timeout -s 9 2 ../source/tcas.exe 822 1 1 701 453 872 2 851 849 0 2 9     > ../outputs/t849
    if diff ../outputs/t849 ../originals/t849 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p850) timeout -s 9 2 ../source/tcas.exe 925 1 -1 650 432 655 0 859 891 0 2 0     > ../outputs/t850
    if diff ../outputs/t850 ../originals/t850 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p851) timeout -s 9 2 ../source/tcas.exe 1162 1 1 1025 344 631 3 453 466 0 2 4     > ../outputs/t851
    if diff ../outputs/t851 ../originals/t851 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p852) timeout -s 9 2 ../source/tcas.exe 1078 1 0 581 567 655 3 637 906 2 2 0     > ../outputs/t852
    if diff ../outputs/t852 ../originals/t852 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p853) timeout -s 9 2 ../source/tcas.exe 777 1 0 646 616 628 2 904 0 0 1 1     > ../outputs/t853
    if diff ../outputs/t853 ../originals/t853 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p854) timeout -s 9 2 ../source/tcas.exe 782 1 0 0 418 610 1 0 618 0 2 0     > ../outputs/t854
    if diff ../outputs/t854 ../originals/t854 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p855) timeout -s 9 2 ../source/tcas.exe 1084 1 1 995 501 604 2 0 482 -1 2 1     > ../outputs/t855
    if diff ../outputs/t855 ../originals/t855 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p856) timeout -s 9 2 ../source/tcas.exe 1013 1 0 643 373 706 3 0 808 2 2 1     > ../outputs/t856
    if diff ../outputs/t856 ../originals/t856 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p857) timeout -s 9 2 ../source/tcas.exe -1 1 0 706 291 643 1 644 564 0 2 0     > ../outputs/t857
    if diff ../outputs/t857 ../originals/t857 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p858) timeout -s 9 2 ../source/tcas.exe 0 1 0 552 382 612 1 0 754 0 2 1     > ../outputs/t858
    if diff ../outputs/t858 ../originals/t858 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p859) timeout -s 9 2 ../source/tcas.exe 733 1 1 590 341 589 3 534 620 1 2 0     > ../outputs/t859
    if diff ../outputs/t859 ../originals/t859 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p860) timeout -s 9 2 ../source/tcas.exe 706 1 1 4649 316 935 3 605 850 0 2 1     > ../outputs/t860
    if diff ../outputs/t860 ../originals/t860 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p861) timeout -s 9 2 ../source/tcas.exe 0 1 1 2311 594 715 3 906 926 0 2 1     > ../outputs/t861
    if diff ../outputs/t861 ../originals/t861 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p862) timeout -s 9 2 ../source/tcas.exe 995 1 1 756 419 339 0 0 540 0 2 0     > ../outputs/t862
    if diff ../outputs/t862 ../originals/t862 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p863) timeout -s 9 2 ../source/tcas.exe 850 1 0 187 443 542 0 410 407 4 2 0     > ../outputs/t863
    if diff ../outputs/t863 ../originals/t863 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p864) timeout -s 9 2 ../source/tcas.exe 878 1 1 0 321 0 2 550 596 0 2 0     > ../outputs/t864
    if diff ../outputs/t864 ../originals/t864 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p865) timeout -s 9 2 ../source/tcas.exe 1146 0 0 0 550 530 2 899 857 0 1 0     > ../outputs/t865
    if diff ../outputs/t865 ../originals/t865 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p866) timeout -s 9 2 ../source/tcas.exe 862 1 0 0 383 0 2 474 721 0 2 1     > ../outputs/t866
    if diff ../outputs/t866 ../originals/t866 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p867) timeout -s 9 2 ../source/tcas.exe 757 1 1 692 581 640 1 840 841 1 2 0     > ../outputs/t867
    if diff ../outputs/t867 ../originals/t867 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p868) timeout -s 9 2 ../source/tcas.exe 692 0 0 0 439 655 3 852 539 0 2 0     > ../outputs/t868
    if diff ../outputs/t868 ../originals/t868 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p869) timeout -s 9 2 ../source/tcas.exe 1165 1 0 592 -1 605 0 0 596 0 2 1     > ../outputs/t869
    if diff ../outputs/t869 ../originals/t869 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p870) timeout -s 9 2 ../source/tcas.exe 760 1 -1 0 314 0 3 452 423 0 2 1     > ../outputs/t870
    if diff ../outputs/t870 ../originals/t870 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p871) timeout -s 9 2 ../source/tcas.exe 948 0 1 584 415 574 3 665 642 2 2 1     > ../outputs/t871
    if diff ../outputs/t871 ../originals/t871 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p872) timeout -s 9 2 ../source/tcas.exe -100 0 0 1879 547 626 0 854 875 0 2 0     > ../outputs/t872
    if diff ../outputs/t872 ../originals/t872 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p873) timeout -s 9 2 ../source/tcas.exe 615 0 0 2299 456 549 0 748 0 2 2 0     > ../outputs/t873
    if diff ../outputs/t873 ../originals/t873 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p874) timeout -s 9 2 ../source/tcas.exe 1117 0 1 0 569 0 2 716 741 0 2 1     > ../outputs/t874
    if diff ../outputs/t874 ../originals/t874 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p875) timeout -s 9 2 ../source/tcas.exe 818 1 1 563 554 999 1 0 615 1 2 1     > ../outputs/t875
    if diff ../outputs/t875 ../originals/t875 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p876) timeout -s 9 2 ../source/tcas.exe 780 1 0 6500 579 -1 1 730 683 0 2 0     > ../outputs/t876
    if diff ../outputs/t876 ../originals/t876 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p877) timeout -s 9 2 ../source/tcas.exe 463 1 1 0 387 590 1 907 867 0 1 0     > ../outputs/t877
    if diff ../outputs/t877 ../originals/t877 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p878) timeout -s 9 2 ../source/tcas.exe 990 1 1 0 325 0 0 727 665 0 2 1     > ../outputs/t878
    if diff ../outputs/t878 ../originals/t878 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p879) timeout -s 9 2 ../source/tcas.exe 952 1 0 588 0 774 0 593 639 -1 2 0     > ../outputs/t879
    if diff ../outputs/t879 ../originals/t879 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p880) timeout -s 9 2 ../source/tcas.exe 1019 1 0 4248 0 551 2 544 550 1 2 1     > ../outputs/t880
    if diff ../outputs/t880 ../originals/t880 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p881) timeout -s 9 2 ../source/tcas.exe 974 1 0 611 978 521 3 0 962 2 1 0     > ../outputs/t881
    if diff ../outputs/t881 ../originals/t881 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p882) timeout -s 9 2 ../source/tcas.exe -1 1 1 576 500 0 0 641 883 4 2 1     > ../outputs/t882
    if diff ../outputs/t882 ../originals/t882 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p883) timeout -s 9 2 ../source/tcas.exe 868 1 1 729 501 740 3 1017 0 0 2 1     > ../outputs/t883
    if diff ../outputs/t883 ../originals/t883 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p884) timeout -s 9 2 ../source/tcas.exe 1084 1 1 704 538 707 2 0 -1 0 2 0     > ../outputs/t884
    if diff ../outputs/t884 ../originals/t884 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p885) timeout -s 9 2 ../source/tcas.exe 935 1 0 4528 388 0 0 853 956 0 2 0     > ../outputs/t885
    if diff ../outputs/t885 ../originals/t885 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p886) timeout -s 9 2 ../source/tcas.exe 1058 1 1 365 560 652 1 0 682 0 2 0     > ../outputs/t886
    if diff ../outputs/t886 ../originals/t886 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p887) timeout -s 9 2 ../source/tcas.exe 1032 1 1 7944 330 0 1 361 0 0 2 1     > ../outputs/t887
    if diff ../outputs/t887 ../originals/t887 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p888) timeout -s 9 2 ../source/tcas.exe 987 1 0 642 606 0 0 413 0 0 2 1     > ../outputs/t888
    if diff ../outputs/t888 ../originals/t888 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p889) timeout -s 9 2 ../source/tcas.exe 994 1 0 647 755 410 0 564 548 1 2 1     > ../outputs/t889
    if diff ../outputs/t889 ../originals/t889 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p890) timeout -s 9 2 ../source/tcas.exe 911 1 0 527 516 541 0 0 465 2 1 0     > ../outputs/t890
    if diff ../outputs/t890 ../originals/t890 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p891) timeout -s 9 2 ../source/tcas.exe 754 1 0 0 335 604 3 531 453 3 2 1     > ../outputs/t891
    if diff ../outputs/t891 ../originals/t891 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p892) timeout -s 9 2 ../source/tcas.exe 856 0 1 5631 380 590 0 961 695 0 2 0     > ../outputs/t892
    if diff ../outputs/t892 ../originals/t892 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p893) timeout -s 9 2 ../source/tcas.exe 36 0 0 622 340 620 1 0 423 0 1 0     > ../outputs/t893
    if diff ../outputs/t893 ../originals/t893 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p894) timeout -s 9 2 ../source/tcas.exe 716 1 1 618 341 767 1 0 0 0 2 1     > ../outputs/t894
    if diff ../outputs/t894 ../originals/t894 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p895) timeout -s 9 2 ../source/tcas.exe 753 1 1 620 583 650 1 826 779 2 1 0     > ../outputs/t895
    if diff ../outputs/t895 ../originals/t895 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p896) timeout -s 9 2 ../source/tcas.exe 872 1 1 0 669 561 1 955 931 0 2 0     > ../outputs/t896
    if diff ../outputs/t896 ../originals/t896 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p897) timeout -s 9 2 ../source/tcas.exe 1119 0 0 749 332 696 1 533 526 1 2 0     > ../outputs/t897
    if diff ../outputs/t897 ../originals/t897 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p898) timeout -s 9 2 ../source/tcas.exe 1032 1 0 5936 652 0 2 893 920 0 2 0     > ../outputs/t898
    if diff ../outputs/t898 ../originals/t898 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p899) timeout -s 9 2 ../source/tcas.exe 903 1 1 577 396 -100 2 314 515 0 2 0     > ../outputs/t899
    if diff ../outputs/t899 ../originals/t899 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p900) timeout -s 9 2 ../source/tcas.exe 1130 1 1 8164 493 665 2 421 424 0 2 -1     > ../outputs/t900
    if diff ../outputs/t900 ../originals/t900 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p901) timeout -s 9 2 ../source/tcas.exe -1 1 1 9836 458 698 2 530 552 2 1 0     > ../outputs/t901
    if diff ../outputs/t901 ../originals/t901 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p902) timeout -s 9 2 ../source/tcas.exe 1141 0 1 687 434 690 0 0 438 0 1 0     > ../outputs/t902
    if diff ../outputs/t902 ../originals/t902 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p903) timeout -s 9 2 ../source/tcas.exe 692 0 1 650 353 2 3 408 435 1 2 1     > ../outputs/t903
    if diff ../outputs/t903 ../originals/t903 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p904) timeout -s 9 2 ../source/tcas.exe 814 -1 1 652 309 705 2 716 687 0 1 0     > ../outputs/t904
    if diff ../outputs/t904 ../originals/t904 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p905) timeout -s 9 2 ../source/tcas.exe 722 1 0 693 573 674 1 862 822 0 2 3     > ../outputs/t905
    if diff ../outputs/t905 ../originals/t905 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p906) timeout -s 9 2 ../source/tcas.exe 1089 1 0 0 587 0 0 449 -100 1 2 1     > ../outputs/t906
    if diff ../outputs/t906 ../originals/t906 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p907) timeout -s 9 2 ../source/tcas.exe 986 1 1 535 478 521 2 934 874 1 1 1     > ../outputs/t907
    if diff ../outputs/t907 ../originals/t907 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p908) timeout -s 9 2 ../source/tcas.exe 609 1 1 8407 595 583 2 560 485 0 2 0     > ../outputs/t908
    if diff ../outputs/t908 ../originals/t908 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p909) timeout -s 9 2 ../source/tcas.exe 898 1 0 688 0 741 1 703 44 0 2 1     > ../outputs/t909
    if diff ../outputs/t909 ../originals/t909 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p910) timeout -s 9 2 ../source/tcas.exe 1154 1 1 552 433 593 4 727 829 0 2 9     > ../outputs/t910
    if diff ../outputs/t910 ../originals/t910 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p911) timeout -s 9 2 ../source/tcas.exe 856 1 1 574 -100 515 3 941 674 0 2 1     > ../outputs/t911
    if diff ../outputs/t911 ../originals/t911 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p912) timeout -s 9 2 ../source/tcas.exe 1034 1 0 642 397 581 1 445 -1 0 1 0     > ../outputs/t912
    if diff ../outputs/t912 ../originals/t912 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p913) timeout -s 9 2 ../source/tcas.exe 840 1 1 0 515 573 0 0 54 0 1 0     > ../outputs/t913
    if diff ../outputs/t913 ../originals/t913 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p914) timeout -s 9 2 ../source/tcas.exe 757 1 0 0 527 205 3 698 750 2 2 0     > ../outputs/t914
    if diff ../outputs/t914 ../originals/t914 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p915) timeout -s 9 2 ../source/tcas.exe 397 1 1 685 603 656 2 501 991 0 2 1     > ../outputs/t915
    if diff ../outputs/t915 ../originals/t915 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p916) timeout -s 9 2 ../source/tcas.exe 793 1 1 8753 425 622 1 744 0 0 2 0     > ../outputs/t916
    if diff ../outputs/t916 ../originals/t916 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p917) timeout -s 9 2 ../source/tcas.exe 1084 1 0 58 197 731 2 547 984 0 2 0     > ../outputs/t917
    if diff ../outputs/t917 ../originals/t917 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p918) timeout -s 9 2 ../source/tcas.exe 1156 1 1 9408 599 0 0 904 902 0 2 0     > ../outputs/t918
    if diff ../outputs/t918 ../originals/t918 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p919) timeout -s 9 2 ../source/tcas.exe 721 1 0 690 438 613 2 0 991 0 2 1     > ../outputs/t919
    if diff ../outputs/t919 ../originals/t919 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p920) timeout -s 9 2 ../source/tcas.exe 0 1 0 709 851 776 3 214 588 0 2 0     > ../outputs/t920
    if diff ../outputs/t920 ../originals/t920 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p921) timeout -s 9 2 ../source/tcas.exe -100 1 1 753 474 747 1 920 420 0 2 0     > ../outputs/t921
    if diff ../outputs/t921 ../originals/t921 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p922) timeout -s 9 2 ../source/tcas.exe 133 1 1 611 507 0 2 801 860 0 2 0     > ../outputs/t922
    if diff ../outputs/t922 ../originals/t922 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p923) timeout -s 9 2 ../source/tcas.exe 988 1 1 -1 312 655 2 749 734 0 1 1     > ../outputs/t923
    if diff ../outputs/t923 ../originals/t923 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p924) timeout -s 9 2 ../source/tcas.exe 1171 0 1 718 630 688 3 252 769 0 1 1     > ../outputs/t924
    if diff ../outputs/t924 ../originals/t924 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p925) timeout -s 9 2 ../source/tcas.exe 1065 1 0 -1 597 582 3 840 881 2 2 0     > ../outputs/t925
    if diff ../outputs/t925 ../originals/t925 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p926) timeout -s 9 2 ../source/tcas.exe 619 1 -1 746 349 961 0 0 868 0 2 0     > ../outputs/t926
    if diff ../outputs/t926 ../originals/t926 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p927) timeout -s 9 2 ../source/tcas.exe 911 1 0 -1 549 -100 3 396 383 0 2 0     > ../outputs/t927
    if diff ../outputs/t927 ../originals/t927 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p928) timeout -s 9 2 ../source/tcas.exe 1001 1 1 737 -100 741 1 828 0 0 2 0     > ../outputs/t928
    if diff ../outputs/t928 ../originals/t928 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p929) timeout -s 9 2 ../source/tcas.exe 590 1 0 610 325 417 1 578 287 0 2 0     > ../outputs/t929
    if diff ../outputs/t929 ../originals/t929 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p930) timeout -s 9 2 ../source/tcas.exe 1062 1 1 1941 575 682 3 872 880 1 2 0     > ../outputs/t930
    if diff ../outputs/t930 ../originals/t930 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p931) timeout -s 9 2 ../source/tcas.exe 604 1 0 652 354 0 2 371 323 2 2 1     > ../outputs/t931
    if diff ../outputs/t931 ../originals/t931 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p932) timeout -s 9 2 ../source/tcas.exe 1130 0 0 581 426 657 0 848 0 0 2 0     > ../outputs/t932
    if diff ../outputs/t932 ../originals/t932 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p933) timeout -s 9 2 ../source/tcas.exe 924 0 0 770 424 756 2 0 0 0 2 1     > ../outputs/t933
    if diff ../outputs/t933 ../originals/t933 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p934) timeout -s 9 2 ../source/tcas.exe 1129 1 1 2950 208 669 1 724 512 0 2 0     > ../outputs/t934
    if diff ../outputs/t934 ../originals/t934 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p935) timeout -s 9 2 ../source/tcas.exe 599 1 1 654 522 0 0 659 399 0 2 0     > ../outputs/t935
    if diff ../outputs/t935 ../originals/t935 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p936) timeout -s 9 2 ../source/tcas.exe 954 1 0 672 625 744 2 732 810 2 2 1     > ../outputs/t936
    if diff ../outputs/t936 ../originals/t936 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p937) timeout -s 9 2 ../source/tcas.exe 972 1 1 460 299 688 1 440 0 0 1 1     > ../outputs/t937
    if diff ../outputs/t937 ../originals/t937 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p938) timeout -s 9 2 ../source/tcas.exe 0 1 1 522 555 530 1 933 914 2 2 0     > ../outputs/t938
    if diff ../outputs/t938 ../originals/t938 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p939) timeout -s 9 2 ../source/tcas.exe 801 1 0 782 524 0 3 381 435 0 1 0     > ../outputs/t939
    if diff ../outputs/t939 ../originals/t939 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p940) timeout -s 9 2 ../source/tcas.exe 0 0 0 598 440 637 2 437 455 0 2 0     > ../outputs/t940
    if diff ../outputs/t940 ../originals/t940 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p941) timeout -s 9 2 ../source/tcas.exe 817 0 1 0 364 15 0 886 851 0 2 1     > ../outputs/t941
    if diff ../outputs/t941 ../originals/t941 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p942) timeout -s 9 2 ../source/tcas.exe 1157 1 1 0 563 797 2 459 58 0 2 0     > ../outputs/t942
    if diff ../outputs/t942 ../originals/t942 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p943) timeout -s 9 2 ../source/tcas.exe 1151 1 0 578 611 0 0 331 378 0 1 1     > ../outputs/t943
    if diff ../outputs/t943 ../originals/t943 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p944) timeout -s 9 2 ../source/tcas.exe 1149 1 1 0 527 607 3 818 860 2 1 0     > ../outputs/t944
    if diff ../outputs/t944 ../originals/t944 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p945) timeout -s 9 2 ../source/tcas.exe 1079 1 0 613 397 0 3 524 477 1 2 0     > ../outputs/t945
    if diff ../outputs/t945 ../originals/t945 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p946) timeout -s 9 2 ../source/tcas.exe 949 1 0 648 515 619 2 0 825 0 2 0     > ../outputs/t946
    if diff ../outputs/t946 ../originals/t946 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p947) timeout -s 9 2 ../source/tcas.exe 1078 1 0 589 605 584 1 -1 323 0 2 1     > ../outputs/t947
    if diff ../outputs/t947 ../originals/t947 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p948) timeout -s 9 2 ../source/tcas.exe 903 0 1 660 612 703 1 867 883 0 2 1     > ../outputs/t948
    if diff ../outputs/t948 ../originals/t948 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p949) timeout -s 9 2 ../source/tcas.exe 1159 1 0 730 910 738 0 740 747 1 2 1     > ../outputs/t949
    if diff ../outputs/t949 ../originals/t949 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p950) timeout -s 9 2 ../source/tcas.exe 1156 1 0 693 104 674 2 499 883 2 2 1     > ../outputs/t950
    if diff ../outputs/t950 ../originals/t950 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p951) timeout -s 9 2 ../source/tcas.exe 886 0 0 5515 447 700 3 478 597 0 2 0     > ../outputs/t951
    if diff ../outputs/t951 ../originals/t951 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p952) timeout -s 9 2 ../source/tcas.exe 1107 1 1 665 853 701 0 653 892 1 2 1     > ../outputs/t952
    if diff ../outputs/t952 ../originals/t952 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p953) timeout -s 9 2 ../source/tcas.exe 655 1 0 749 487 139 2 477 850 0 2 0     > ../outputs/t953
    if diff ../outputs/t953 ../originals/t953 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p954) timeout -s 9 2 ../source/tcas.exe 1184 -1 0 0 391 534 3 491 476 0 2 1     > ../outputs/t954
    if diff ../outputs/t954 ../originals/t954 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p955) timeout -s 9 2 ../source/tcas.exe 879 0 0 0 -100 728 0 517 507 0 2 1     > ../outputs/t955
    if diff ../outputs/t955 ../originals/t955 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p956) timeout -s 9 2 ../source/tcas.exe 826 1 0 655 326 577 0 0 425 1 2 0     > ../outputs/t956
    if diff ../outputs/t956 ../originals/t956 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p957) timeout -s 9 2 ../source/tcas.exe 323 1 0 4964 498 697 3 780 810 0 2 1     > ../outputs/t957
    if diff ../outputs/t957 ../originals/t957 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p958) timeout -s 9 2 ../source/tcas.exe 1084 1 1 703 387 726 3 384 0 1 2 1     > ../outputs/t958
    if diff ../outputs/t958 ../originals/t958 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p959) timeout -s 9 2 ../source/tcas.exe 988 1 0 622 496 613 1 379 404 0 2 0     > ../outputs/t959
    if diff ../outputs/t959 ../originals/t959 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p960) timeout -s 9 2 ../source/tcas.exe 1039 -1 1 630 618 0 3 0 801 1 2 1     > ../outputs/t960
    if diff ../outputs/t960 ../originals/t960 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p961) timeout -s 9 2 ../source/tcas.exe 1185 1 1 595 0 534 1 560 0 0 2 1     > ../outputs/t961
    if diff ../outputs/t961 ../originals/t961 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p962) timeout -s 9 2 ../source/tcas.exe 700 1 0 575 415 -1 0 795 796 2 2 0     > ../outputs/t962
    if diff ../outputs/t962 ../originals/t962 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p963) timeout -s 9 2 ../source/tcas.exe 665 1 1 585 445 533 0 209 848 0 2 1     > ../outputs/t963
    if diff ../outputs/t963 ../originals/t963 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p964) timeout -s 9 2 ../source/tcas.exe 820 1 1 561 0 599 2 993 817 0 2 0     > ../outputs/t964
    if diff ../outputs/t964 ../originals/t964 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p965) timeout -s 9 2 ../source/tcas.exe 1189 1 1 753 620 761 2 0 185 0 1 0     > ../outputs/t965
    if diff ../outputs/t965 ../originals/t965 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p966) timeout -s 9 2 ../source/tcas.exe 910 1 1 722 601 707 3 0 0 0 2 0     > ../outputs/t966
    if diff ../outputs/t966 ../originals/t966 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p967) timeout -s 9 2 ../source/tcas.exe 986 1 1 618 321 595 1 0 418 0 1 4     > ../outputs/t967
    if diff ../outputs/t967 ../originals/t967 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p968) timeout -s 9 2 ../source/tcas.exe 1079 1 1 631 547 663 2 401 314 4 1 0     > ../outputs/t968
    if diff ../outputs/t968 ../originals/t968 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p969) timeout -s 9 2 ../source/tcas.exe 204 1 0 707 601 741 1 695 652 2 2 1     > ../outputs/t969
    if diff ../outputs/t969 ../originals/t969 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p970) timeout -s 9 2 ../source/tcas.exe 797 0 0 8545 149 589 3 278 280 1 1 1     > ../outputs/t970
    if diff ../outputs/t970 ../originals/t970 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p971) timeout -s 9 2 ../source/tcas.exe -100 1 0 1362 527 922 2 437 358 0 2 1     > ../outputs/t971
    if diff ../outputs/t971 ../originals/t971 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p972) timeout -s 9 2 ../source/tcas.exe 965 1 1 7468 524 693 1 830 0 0 2 0     > ../outputs/t972
    if diff ../outputs/t972 ../originals/t972 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p973) timeout -s 9 2 ../source/tcas.exe 0 1 0 7119 153 556 2 836 841 1 1 1     > ../outputs/t973
    if diff ../outputs/t973 ../originals/t973 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p974) timeout -s 9 2 ../source/tcas.exe 1006 0 -1 8234 374 598 1 811 514 0 2 0     > ../outputs/t974
    if diff ../outputs/t974 ../originals/t974 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p975) timeout -s 9 2 ../source/tcas.exe 830 1 0 -1 473 631 3 22 0 0 2 1     > ../outputs/t975
    if diff ../outputs/t975 ../originals/t975 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p976) timeout -s 9 2 ../source/tcas.exe 904 1 0 530 438 0 2 951 0 1 2 0     > ../outputs/t976
    if diff ../outputs/t976 ../originals/t976 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p977) timeout -s 9 2 ../source/tcas.exe 638 0 1 545 325 589 1 900 798 0 2 0     > ../outputs/t977
    if diff ../outputs/t977 ../originals/t977 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p978) timeout -s 9 2 ../source/tcas.exe 0 1 -1 0 388 737 3 0 470 0 2 1     > ../outputs/t978
    if diff ../outputs/t978 ../originals/t978 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p979) timeout -s 9 2 ../source/tcas.exe 1053 1 0 6178 547 127 0 518 489 0 2 0     > ../outputs/t979
    if diff ../outputs/t979 ../originals/t979 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p980) timeout -s 9 2 ../source/tcas.exe 610 1 1 611 0 616 1 541 578 9 2 1     > ../outputs/t980
    if diff ../outputs/t980 ../originals/t980 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p981) timeout -s 9 2 ../source/tcas.exe 899 1 1 -100 601 571 3 618 595 4 1 0     > ../outputs/t981
    if diff ../outputs/t981 ../originals/t981 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p982) timeout -s 9 2 ../source/tcas.exe 1085 1 1 1017 510 614 0 595 614 2 2 4     > ../outputs/t982
    if diff ../outputs/t982 ../originals/t982 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p983) timeout -s 9 2 ../source/tcas.exe 650 1 1 0 197 701 0 682 711 0 2 -1     > ../outputs/t983
    if diff ../outputs/t983 ../originals/t983 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p984) timeout -s 9 2 ../source/tcas.exe 1015 0 1 600 526 629 1 569 0 0 2 1     > ../outputs/t984
    if diff ../outputs/t984 ../originals/t984 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p985) timeout -s 9 2 ../source/tcas.exe -100 0 1 3803 419 630 3 -1 437 0 2 1     > ../outputs/t985
    if diff ../outputs/t985 ../originals/t985 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p986) timeout -s 9 2 ../source/tcas.exe 598 0 0 639 0 327 1 411 374 0 2 0     > ../outputs/t986
    if diff ../outputs/t986 ../originals/t986 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p987) timeout -s 9 2 ../source/tcas.exe 1118 0 1 725 0 756 2 860 846 0 2 1     > ../outputs/t987
    if diff ../outputs/t987 ../originals/t987 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p988) timeout -s 9 2 ../source/tcas.exe 652 1 0 -100 478 779 0 356 371 -1 2 0     > ../outputs/t988
    if diff ../outputs/t988 ../originals/t988 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p989) timeout -s 9 2 ../source/tcas.exe 698 1 0 3071 59 307 0 849 904 0 2 0     > ../outputs/t989
    if diff ../outputs/t989 ../originals/t989 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p990) timeout -s 9 2 ../source/tcas.exe 734 1 1 615 -100 591 2 889 -1 0 2 0     > ../outputs/t990
    if diff ../outputs/t990 ../originals/t990 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p991) timeout -s 9 2 ../source/tcas.exe 628 1 0 706 1 976 0 417 652 2 2 1     > ../outputs/t991
    if diff ../outputs/t991 ../originals/t991 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p992) timeout -s 9 2 ../source/tcas.exe 913 1 1 661 -100 255 3 0 668 0 2 0     > ../outputs/t992
    if diff ../outputs/t992 ../originals/t992 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p993) timeout -s 9 2 ../source/tcas.exe 618 0 1 754 390 215 0 250 830 0 2 1     > ../outputs/t993
    if diff ../outputs/t993 ../originals/t993 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p994) timeout -s 9 2 ../source/tcas.exe 617 0 1 640 441 662 1 677 528 4 2 1     > ../outputs/t994
    if diff ../outputs/t994 ../originals/t994 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p995) timeout -s 9 2 ../source/tcas.exe 766 1 0 719 300 700 3 406 378 1 1 1     > ../outputs/t995
    if diff ../outputs/t995 ../originals/t995 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p996) timeout -s 9 2 ../source/tcas.exe 119 1 0 715 292 212 0 322 341 0 2 1     > ../outputs/t996
    if diff ../outputs/t996 ../originals/t996 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p997) timeout -s 9 2 ../source/tcas.exe 939 1 1 532 534 -100 2 335 971 1 2 1     > ../outputs/t997
    if diff ../outputs/t997 ../originals/t997 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p998) timeout -s 9 2 ../source/tcas.exe 190 1 1 724 567 715 1 1011 1021 1 2 1     > ../outputs/t998
    if diff ../outputs/t998 ../originals/t998 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p999) timeout -s 9 2 ../source/tcas.exe -100 1 1 680 602 702 0 831 860 2 2 1     > ../outputs/t999
    if diff ../outputs/t999 ../originals/t999 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1000) timeout -s 9 2 ../source/tcas.exe 685 1 0 586 0 601 1 646 701 0 1 0     > ../outputs/t1000
    if diff ../outputs/t1000 ../originals/t1000 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1001) timeout -s 9 2 ../source/tcas.exe  679 1 1  541  338 5123 0  641  641 0 0 1     > ../outputs/t1001
    if diff ../outputs/t1001 ../originals/t1001 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1002) timeout -s 9 2 ../source/tcas.exe  644 1 1 1886  596 2348 0  741  400 1 0 0     > ../outputs/t1002
    if diff ../outputs/t1002 ../originals/t1002 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1003) timeout -s 9 2 ../source/tcas.exe  722 1 1 1415  245  316 0  401  739 0 0 0     > ../outputs/t1003
    if diff ../outputs/t1003 ../originals/t1003 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1004) timeout -s 9 2 ../source/tcas.exe  722 1 1 1415  275  316 0  401  799 0 0 0     > ../outputs/t1004
    if diff ../outputs/t1004 ../originals/t1004 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1005) timeout -s 9 2 ../source/tcas.exe  782 1 1  513  224 5295 0  641  639 0 1 1     > ../outputs/t1005
    if diff ../outputs/t1005 ../originals/t1005 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1006) timeout -s 9 2 ../source/tcas.exe  782 1 1  413  224 4295 0  641  639 0 1 1     > ../outputs/t1006
    if diff ../outputs/t1006 ../originals/t1006 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1007) timeout -s 9 2 ../source/tcas.exe  786 1 1  383  548 5870 0  639  399 1 0 1     > ../outputs/t1007
    if diff ../outputs/t1007 ../originals/t1007 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1008) timeout -s 9 2 ../source/tcas.exe  786 1 1  383  448 4870 0  639  399 1 0 1     > ../outputs/t1008
    if diff ../outputs/t1008 ../originals/t1008 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1009) timeout -s 9 2 ../source/tcas.exe  638 1 0 2578  156 3757 0  400  399 1 0 1     > ../outputs/t1009
    if diff ../outputs/t1009 ../originals/t1009 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1010) timeout -s 9 2 ../source/tcas.exe  638 1 0 2278  156 3757 0  650  399 1 0 1     > ../outputs/t1010
    if diff ../outputs/t1010 ../originals/t1010 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1011) timeout -s 9 2 ../source/tcas.exe  727 1 1 1935  339  968 0  399  740 0 1 1     > ../outputs/t1011
    if diff ../outputs/t1011 ../originals/t1011 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1012) timeout -s 9 2 ../source/tcas.exe  927 1 1 4902  351 2093 0  739  740 1 0 0     > ../outputs/t1012
    if diff ../outputs/t1012 ../originals/t1012 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1013) timeout -s 9 2 ../source/tcas.exe  927 1 1 4702  251 1093 0  739  740 1 0 0     > ../outputs/t1013
    if diff ../outputs/t1013 ../originals/t1013 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1014) timeout -s 9 2 ../source/tcas.exe  867 1 1 1774  101 2204 0  499  499 1 0 1     > ../outputs/t1014
    if diff ../outputs/t1014 ../originals/t1014 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1015) timeout -s 9 2 ../source/tcas.exe  867 1 1 1674  101 2104 0  499  499 1 0 1     > ../outputs/t1015
    if diff ../outputs/t1015 ../originals/t1015 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1016) timeout -s 9 2 ../source/tcas.exe  653 1 0 3203  448 1267 0  541  641 0 0 0     > ../outputs/t1016
    if diff ../outputs/t1016 ../originals/t1016 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1017) timeout -s 9 2 ../source/tcas.exe  653 1 0 3203  448 1267 0  541  641 1 0 0     > ../outputs/t1017
    if diff ../outputs/t1017 ../originals/t1017 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1018) timeout -s 9 2 ../source/tcas.exe  653 1 0  632  167  203 0  401  401 1 0 0     > ../outputs/t1018
    if diff ../outputs/t1018 ../originals/t1018 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1019) timeout -s 9 2 ../source/tcas.exe  958 1 1 2297  574 4253 0  399  400 0 0 1     > ../outputs/t1019
    if diff ../outputs/t1019 ../originals/t1019 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1020) timeout -s 9 2 ../source/tcas.exe  958 1 1 2297  574 4253 0  399  300 0 0 1     > ../outputs/t1020
    if diff ../outputs/t1020 ../originals/t1020 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1021) timeout -s 9 2 ../source/tcas.exe  958 1 1 2297  574 4253 0  399  300 1 0 1     > ../outputs/t1021
    if diff ../outputs/t1021 ../originals/t1021 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1022) timeout -s 9 2 ../source/tcas.exe  635 1 0 1142  411 4704 1  740  500 0 0 1     > ../outputs/t1022
    if diff ../outputs/t1022 ../originals/t1022 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1023) timeout -s 9 2 ../source/tcas.exe  635 1 0 1142  511 2704 1  740  500 0 0 1     > ../outputs/t1023
    if diff ../outputs/t1023 ../originals/t1023 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1024) timeout -s 9 2 ../source/tcas.exe  635 1 0 1142  511 2704 1  740  500 1 0 1     > ../outputs/t1024
    if diff ../outputs/t1024 ../originals/t1024 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1025) timeout -s 9 2 ../source/tcas.exe  635 1 0 1142  511 1704 1  740  500 1 0 1     > ../outputs/t1025
    if diff ../outputs/t1025 ../originals/t1025 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1026) timeout -s 9 2 ../source/tcas.exe  635 1 0 1142  411 1704 1  740  500 1 0 1     > ../outputs/t1026
    if diff ../outputs/t1026 ../originals/t1026 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1027) timeout -s 9 2 ../source/tcas.exe  675 1 0 1142  411 1704 1  740  500 1 0 1     > ../outputs/t1027
    if diff ../outputs/t1027 ../originals/t1027 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1028) timeout -s 9 2 ../source/tcas.exe  675 1 0 1142  411 1704 1  640  500 1 0 1     > ../outputs/t1028
    if diff ../outputs/t1028 ../originals/t1028 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1029) timeout -s 9 2 ../source/tcas.exe  675 1 1 1142  411 1704 1  640  500 1 0 1     > ../outputs/t1029
    if diff ../outputs/t1029 ../originals/t1029 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1030) timeout -s 9 2 ../source/tcas.exe  775 1 1 1142  411 1704 1  640  500 1 0 1     > ../outputs/t1030
    if diff ../outputs/t1030 ../originals/t1030 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1031) timeout -s 9 2 ../source/tcas.exe  775 1 1 1142  411 1704 1  540  500 1 0 1     > ../outputs/t1031
    if diff ../outputs/t1031 ../originals/t1031 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1032) timeout -s 9 2 ../source/tcas.exe  775 1 1 1142  411 1504 1  540  500 1 0 1     > ../outputs/t1032
    if diff ../outputs/t1032 ../originals/t1032 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1033) timeout -s 9 2 ../source/tcas.exe  775 1 1 1042  411 1504 1  540  500 1 0 1     > ../outputs/t1033
    if diff ../outputs/t1033 ../originals/t1033 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1034) timeout -s 9 2 ../source/tcas.exe  775 1 1 942  411 1504 1  540  500 1 0 1     > ../outputs/t1034
    if diff ../outputs/t1034 ../originals/t1034 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1035) timeout -s 9 2 ../source/tcas.exe  775 1 1 942  311 1504 1  540  500 1 0 1     > ../outputs/t1035
    if diff ../outputs/t1035 ../originals/t1035 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1036) timeout -s 9 2 ../source/tcas.exe  775 1 1 942  211 1504 1  540  500 1 0 1     > ../outputs/t1036
    if diff ../outputs/t1036 ../originals/t1036 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1037) timeout -s 9 2 ../source/tcas.exe  775 1 1 942  211 1204 1  540  500 1 0 1     > ../outputs/t1037
    if diff ../outputs/t1037 ../originals/t1037 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1038) timeout -s 9 2 ../source/tcas.exe  644 1 1 1986  596 2448 0  741  400 1 0 1     > ../outputs/t1038
    if diff ../outputs/t1038 ../originals/t1038 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1039) timeout -s 9 2 ../source/tcas.exe  644 1 0 1986  596 2448 0  741  400 1 0 1     > ../outputs/t1039
    if diff ../outputs/t1039 ../originals/t1039 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1040) timeout -s 9 2 ../source/tcas.exe  644 1 0 1786  596 2448 0  741  400 1 0 1     > ../outputs/t1040
    if diff ../outputs/t1040 ../originals/t1040 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1041) timeout -s 9 2 ../source/tcas.exe  644 1 0 1786  596 2248 0  741  400 1 0 1     > ../outputs/t1041
    if diff ../outputs/t1041 ../originals/t1041 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1042) timeout -s 9 2 ../source/tcas.exe  644 1 0 1786  596 2248 0  721  400 1 0 1     > ../outputs/t1042
    if diff ../outputs/t1042 ../originals/t1042 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1043) timeout -s 9 2 ../source/tcas.exe  624 1 0 1786  596 2248 0  721  400 1 0 1     > ../outputs/t1043
    if diff ../outputs/t1043 ../originals/t1043 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1044) timeout -s 9 2 ../source/tcas.exe  624 1 0 1786  496 2248 0  721  400 1 0 1     > ../outputs/t1044
    if diff ../outputs/t1044 ../originals/t1044 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1045) timeout -s 9 2 ../source/tcas.exe  624 1 0 1286  496 2248 0  721  400 1 0 1     > ../outputs/t1045
    if diff ../outputs/t1045 ../originals/t1045 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1046) timeout -s 9 2 ../source/tcas.exe  624 1 0 1086  496 2248 0  721  400 1 0 1     > ../outputs/t1046
    if diff ../outputs/t1046 ../originals/t1046 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1047) timeout -s 9 2 ../source/tcas.exe  604 1 0 1086  496 2248 0  721  400 1 0 1     > ../outputs/t1047
    if diff ../outputs/t1047 ../originals/t1047 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1048) timeout -s 9 2 ../source/tcas.exe  604 1 0 1086  496 1248 0  721  400 1 0 1     > ../outputs/t1048
    if diff ../outputs/t1048 ../originals/t1048 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1049) timeout -s 9 2 ../source/tcas.exe  604 1 0 1086  396 1248 0  721  400 1 0 1     > ../outputs/t1049
    if diff ../outputs/t1049 ../originals/t1049 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1050) timeout -s 9 2 ../source/tcas.exe  958 1 0 2597  574 4253 0  399  400 0 0 1     > ../outputs/t1050
    if diff ../outputs/t1050 ../originals/t1050 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1051) timeout -s 9 2 ../source/tcas.exe  958 1 0 2597  574 4253 0  379  400 0 0 1     > ../outputs/t1051
    if diff ../outputs/t1051 ../originals/t1051 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1052) timeout -s 9 2 ../source/tcas.exe  958 1 0 2597  574 4253 0  379  400 1 0 1     > ../outputs/t1052
    if diff ../outputs/t1052 ../originals/t1052 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1053) timeout -s 9 2 ../source/tcas.exe  958 1 0 2597  574 3253 0  379  400 1 0 1     > ../outputs/t1053
    if diff ../outputs/t1053 ../originals/t1053 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1054) timeout -s 9 2 ../source/tcas.exe  958 1 0 2597  474 3253 0  379  400 1 0 1     > ../outputs/t1054
    if diff ../outputs/t1054 ../originals/t1054 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1055) timeout -s 9 2 ../source/tcas.exe  958 1 0 2597  474 3253 0  379  400 0 0 1     > ../outputs/t1055
    if diff ../outputs/t1055 ../originals/t1055 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1056) timeout -s 9 2 ../source/tcas.exe  958 1 1 2597  574 4253 0  399  400 0 0 1     > ../outputs/t1056
    if diff ../outputs/t1056 ../originals/t1056 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1057) timeout -s 9 2 ../source/tcas.exe  939 1 1 532 434 -100 2 335 971 1 2 1     > ../outputs/t1057
    if diff ../outputs/t1057 ../originals/t1057 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1058) timeout -s 9 2 ../source/tcas.exe  939 1 1 532 434 0 2 335 971 1 2 1     > ../outputs/t1058
    if diff ../outputs/t1058 ../originals/t1058 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1059) timeout -s 9 2 ../source/tcas.exe  939 1 0 532 434 0 2 335 971 1 2 1     > ../outputs/t1059
    if diff ../outputs/t1059 ../originals/t1059 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1060) timeout -s 9 2 ../source/tcas.exe  839 1 0 532 434 0 2 335 971 1 2 1     > ../outputs/t1060
    if diff ../outputs/t1060 ../originals/t1060 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1061) timeout -s 9 2 ../source/tcas.exe  839 1 0 532 234 0 2 335 971 1 2 1     > ../outputs/t1061
    if diff ../outputs/t1061 ../originals/t1061 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1062) timeout -s 9 2 ../source/tcas.exe  839 1 0 532 234 0 2 325 971 1 2 1     > ../outputs/t1062
    if diff ../outputs/t1062 ../originals/t1062 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1063) timeout -s 9 2 ../source/tcas.exe  820 1 1 561 0 599 2 993 817 1 2 0     > ../outputs/t1063
    if diff ../outputs/t1063 ../originals/t1063 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1064) timeout -s 9 2 ../source/tcas.exe  820 1 0 561 0 599 2 993 817 1 2 0     > ../outputs/t1064
    if diff ../outputs/t1064 ../originals/t1064 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1065) timeout -s 9 2 ../source/tcas.exe  820 1 0 561 0 599 2 893 817 1 2 0     > ../outputs/t1065
    if diff ../outputs/t1065 ../originals/t1065 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1066) timeout -s 9 2 ../source/tcas.exe  720 1 0 561 0 599 2 893 817 1 2 0     > ../outputs/t1066
    if diff ../outputs/t1066 ../originals/t1066 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1067) timeout -s 9 2 ../source/tcas.exe  720 1 0 461 0 599 2 893 817 1 2 0     > ../outputs/t1067
    if diff ../outputs/t1067 ../originals/t1067 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1068) timeout -s 9 2 ../source/tcas.exe  655 1 0 749 487 139 2 477 850 1 2 0     > ../outputs/t1068
    if diff ../outputs/t1068 ../originals/t1068 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1069) timeout -s 9 2 ../source/tcas.exe  655 1 0 749 487 139 2 477 850 1 2 1     > ../outputs/t1069
    if diff ../outputs/t1069 ../originals/t1069 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1070) timeout -s 9 2 ../source/tcas.exe  655 1 1 749 487 139 2 477 850 1 2 1     > ../outputs/t1070
    if diff ../outputs/t1070 ../originals/t1070 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1071) timeout -s 9 2 ../source/tcas.exe  655 1 0 749 387 139 2 477 850 1 2 1     > ../outputs/t1071
    if diff ../outputs/t1071 ../originals/t1071 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1072) timeout -s 9 2 ../source/tcas.exe  755 1 0 749 387 139 2 477 850 1 2 1     > ../outputs/t1072
    if diff ../outputs/t1072 ../originals/t1072 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1073) timeout -s 9 2 ../source/tcas.exe  755 1 0 649 387 139 2 477 850 1 2 1     > ../outputs/t1073
    if diff ../outputs/t1073 ../originals/t1073 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1074) timeout -s 9 2 ../source/tcas.exe  698 1 0 3071 59 307 0 849 904 1 2 0     > ../outputs/t1074
    if diff ../outputs/t1074 ../originals/t1074 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1075) timeout -s 9 2 ../source/tcas.exe  698 1 0 2071 59 307 0 849 904 1 2 0     > ../outputs/t1075
    if diff ../outputs/t1075 ../originals/t1075 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1076) timeout -s 9 2 ../source/tcas.exe  698 1 0 2071 49 307 0 849 904 1 2 0     > ../outputs/t1076
    if diff ../outputs/t1076 ../originals/t1076 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1077) timeout -s 9 2 ../source/tcas.exe  798 1 0 2071 49 307 0 849 904 1 2 0     > ../outputs/t1077
    if diff ../outputs/t1077 ../originals/t1077 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1078) timeout -s 9 2 ../source/tcas.exe  798 1 1 2071 49 307 0 849 904 1 2 0     > ../outputs/t1078
    if diff ../outputs/t1078 ../originals/t1078 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1079) timeout -s 9 2 ../source/tcas.exe  700 1 0 575 415 1 0 795 796 2 2 0     > ../outputs/t1079
    if diff ../outputs/t1079 ../originals/t1079 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1080) timeout -s 9 2 ../source/tcas.exe  700 1 1 575 415 1 0 795 796 2 2 0     > ../outputs/t1080
    if diff ../outputs/t1080 ../originals/t1080 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1081) timeout -s 9 2 ../source/tcas.exe  700 1 1 575 415 1 0 795 796 1 2 0     > ../outputs/t1081
    if diff ../outputs/t1081 ../originals/t1081 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1082) timeout -s 9 2 ../source/tcas.exe  700 1 1 275 415 1 0 795 796 1 2 0     > ../outputs/t1082
    if diff ../outputs/t1082 ../originals/t1082 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1083) timeout -s 9 2 ../source/tcas.exe  700 1 1 275 415 1 0 695 796 1 2 0     > ../outputs/t1083
    if diff ../outputs/t1083 ../originals/t1083 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1084) timeout -s 9 2 ../source/tcas.exe  800 1 1 275 415 1 0 695 796 1 2 0     > ../outputs/t1084
    if diff ../outputs/t1084 ../originals/t1084 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1085) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1941 575 682 3 872 880 1 2 0     > ../outputs/t1085
    if diff ../outputs/t1085 ../originals/t1085 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1086) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1941 545 582 3 872 880 1 2 0     > ../outputs/t1086
    if diff ../outputs/t1086 ../originals/t1086 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1087) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1941 545 582 2 872 880 1 2 0     > ../outputs/t1087
    if diff ../outputs/t1087 ../originals/t1087 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1088) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1941 545 582 2 772 880 1 2 0     > ../outputs/t1088
    if diff ../outputs/t1088 ../originals/t1088 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1089) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1941 545 582 2 772 780 1 2 0     > ../outputs/t1089
    if diff ../outputs/t1089 ../originals/t1089 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1090) timeout -s 9 2 ../source/tcas.exe  1062 1 1 1941 545 582 2 772 780 1 2 0     > ../outputs/t1090
    if diff ../outputs/t1090 ../originals/t1090 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1091) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1941 445 582 2 772 780 1 2 0     > ../outputs/t1091
    if diff ../outputs/t1091 ../originals/t1091 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1092) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1241 445 582 2 772 780 1 2 0     > ../outputs/t1092
    if diff ../outputs/t1092 ../originals/t1092 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1093) timeout -s 9 2 ../source/tcas.exe  1062 1 0 1241 445 582 2 712 780 1 2 0     > ../outputs/t1093
    if diff ../outputs/t1093 ../originals/t1093 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1094) timeout -s 9 2 ../source/tcas.exe  935 1 0 3528 388 0 0 853 956 0 2 0     > ../outputs/t1094
    if diff ../outputs/t1094 ../originals/t1094 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1095) timeout -s 9 2 ../source/tcas.exe  935 1 0 3528 288 0 0 853 956 0 2 0     > ../outputs/t1095
    if diff ../outputs/t1095 ../originals/t1095 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1096) timeout -s 9 2 ../source/tcas.exe  935 1 1 3528 288 0 0 853 956 0 2 0     > ../outputs/t1096
    if diff ../outputs/t1096 ../originals/t1096 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1097) timeout -s 9 2 ../source/tcas.exe  935 1 1 3528 288 0 0 853 956 1 2 0     > ../outputs/t1097
    if diff ../outputs/t1097 ../originals/t1097 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1098) timeout -s 9 2 ../source/tcas.exe  935 1 1 2528 288 0 0 853 956 1 2 0     > ../outputs/t1098
    if diff ../outputs/t1098 ../originals/t1098 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1099) timeout -s 9 2 ../source/tcas.exe  757 1 0 692 581 640 1 840 841 1 2 0     > ../outputs/t1099
    if diff ../outputs/t1099 ../originals/t1099 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1100) timeout -s 9 2 ../source/tcas.exe  757 1 0 692 581 640 1 840 841 0 2 0     > ../outputs/t1100
    if diff ../outputs/t1100 ../originals/t1100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1101) timeout -s 9 2 ../source/tcas.exe  757 1 1 692 481 640 1 840 841 0 2 0     > ../outputs/t1101
    if diff ../outputs/t1101 ../originals/t1101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1102) timeout -s 9 2 ../source/tcas.exe  757 1 1 692 481 640 2 840 841 1 2 0     > ../outputs/t1102
    if diff ../outputs/t1102 ../originals/t1102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1103) timeout -s 9 2 ../source/tcas.exe  757 1 1 692 481 640 2 840 891 1 2 0     > ../outputs/t1103
    if diff ../outputs/t1103 ../originals/t1103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1104) timeout -s 9 2 ../source/tcas.exe  913 1 0 661 -100 255 3 0 668 0 2 0     > ../outputs/t1104
    if diff ../outputs/t1104 ../originals/t1104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1105) timeout -s 9 2 ../source/tcas.exe  913 1 0 661 0 255 3 0 668 0 2 0     > ../outputs/t1105
    if diff ../outputs/t1105 ../originals/t1105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1106) timeout -s 9 2 ../source/tcas.exe  913 1 0 661 0 255 3 0 368 0 2 0     > ../outputs/t1106
    if diff ../outputs/t1106 ../originals/t1106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1107) timeout -s 9 2 ../source/tcas.exe  913 1 0 661 0 255 3 1 368 0 2 0     > ../outputs/t1107
    if diff ../outputs/t1107 ../originals/t1107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1108) timeout -s 9 2 ../source/tcas.exe  913 1 0 661 0 255 3 100 368 0 2 0     > ../outputs/t1108
    if diff ../outputs/t1108 ../originals/t1108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1109) timeout -s 9 2 ../source/tcas.exe  713 1 0 661 0 255 3 100 368 0 2 0     > ../outputs/t1109
    if diff ../outputs/t1109 ../originals/t1109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1110) timeout -s 9 2 ../source/tcas.exe  713 1 0 661 0 255 3 100 368 1 2 0     > ../outputs/t1110
    if diff ../outputs/t1110 ../originals/t1110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1111) timeout -s 9 2 ../source/tcas.exe  713 1 0 661 0 255 3 100 228 1 2 0     > ../outputs/t1111
    if diff ../outputs/t1111 ../originals/t1111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1112) timeout -s 9 2 ../source/tcas.exe  613 1 0 661 0 255 3 100 228 1 2 0     > ../outputs/t1112
    if diff ../outputs/t1112 ../originals/t1112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1113) timeout -s 9 2 ../source/tcas.exe  613 1 0 661 0 155 3 100 228 1 2 0     > ../outputs/t1113
    if diff ../outputs/t1113 ../originals/t1113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1114) timeout -s 9 2 ../source/tcas.exe  613 1 0 561 0 155 3 100 228 1 2 0     > ../outputs/t1114
    if diff ../outputs/t1114 ../originals/t1114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1115) timeout -s 9 2 ../source/tcas.exe  613 1 0 461 0 155 3 100 228 1 2 0     > ../outputs/t1115
    if diff ../outputs/t1115 ../originals/t1115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1116) timeout -s 9 2 ../source/tcas.exe  613 1 0 461 0 55 3 100 228 1 2 0     > ../outputs/t1116
    if diff ../outputs/t1116 ../originals/t1116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1117) timeout -s 9 2 ../source/tcas.exe  758 1 1 2597  574 4253 0  399  400 0 0 1     > ../outputs/t1117
    if diff ../outputs/t1117 ../originals/t1117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1118) timeout -s 9 2 ../source/tcas.exe  1058 1 1 2597  574 4253 0  399  400 0 0 1     > ../outputs/t1118
    if diff ../outputs/t1118 ../originals/t1118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1119) timeout -s 9 2 ../source/tcas.exe  1058 1 1 2597  574 3253 0  399  400 0 0 1     > ../outputs/t1119
    if diff ../outputs/t1119 ../originals/t1119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1120) timeout -s 9 2 ../source/tcas.exe  1058 1 1 2597  274 3253 0  399  400 0 0 1     > ../outputs/t1120
    if diff ../outputs/t1120 ../originals/t1120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1121) timeout -s 9 2 ../source/tcas.exe  1058 1 0 2597  274 3253 0  399  400 0 0 1     > ../outputs/t1121
    if diff ../outputs/t1121 ../originals/t1121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1122) timeout -s 9 2 ../source/tcas.exe  1058 1 0 2597  174 3253 0  399  400 0 0 1     > ../outputs/t1122
    if diff ../outputs/t1122 ../originals/t1122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1123) timeout -s 9 2 ../source/tcas.exe  1058 1 0 1597  174 3253 0  399  400 0 0 1     > ../outputs/t1123
    if diff ../outputs/t1123 ../originals/t1123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1124) timeout -s 9 2 ../source/tcas.exe  1058 1 0 1597  174 4253 0  399  400 0 0 1     > ../outputs/t1124
    if diff ../outputs/t1124 ../originals/t1124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1125) timeout -s 9 2 ../source/tcas.exe  1058 1 0 1597  174 7253 0  399  400 0 0 1     > ../outputs/t1125
    if diff ../outputs/t1125 ../originals/t1125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1126) timeout -s 9 2 ../source/tcas.exe  775 1 1 942  211 5204 1  540  500 1 0 1     > ../outputs/t1126
    if diff ../outputs/t1126 ../originals/t1126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1127) timeout -s 9 2 ../source/tcas.exe  775 1 1 642  211 5204 1  540  500 1 0 1     > ../outputs/t1127
    if diff ../outputs/t1127 ../originals/t1127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1128) timeout -s 9 2 ../source/tcas.exe  775 1 0 642  211 5204 1  540  500 1 0 1     > ../outputs/t1128
    if diff ../outputs/t1128 ../originals/t1128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1129) timeout -s 9 2 ../source/tcas.exe  605 1 0 1142  511 4704 1  740  500 0 0 1     > ../outputs/t1129
    if diff ../outputs/t1129 ../originals/t1129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1130) timeout -s 9 2 ../source/tcas.exe  611 1 1 1142  511 4704 1  740  500 0 0 1     > ../outputs/t1130
    if diff ../outputs/t1130 ../originals/t1130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1131) timeout -s 9 2 ../source/tcas.exe  611 1 1 1142  511 4704 1  740  500 1 0 1     > ../outputs/t1131
    if diff ../outputs/t1131 ../originals/t1131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1132) timeout -s 9 2 ../source/tcas.exe  604 1 0 1086  496 8248 0  721  400 1 0 1     > ../outputs/t1132
    if diff ../outputs/t1132 ../originals/t1132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1133) timeout -s 9 2 ../source/tcas.exe  604 1 0 1086  196 8248 0  721  400 1 0 1     > ../outputs/t1133
    if diff ../outputs/t1133 ../originals/t1133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1134) timeout -s 9 2 ../source/tcas.exe  604 1 0 1111  196 8248 0  721  400 1 0 1     > ../outputs/t1134
    if diff ../outputs/t1134 ../originals/t1134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1135) timeout -s 9 2 ../source/tcas.exe  604 1 0 1111  196 8248 0  721  400 0 0 0     > ../outputs/t1135
    if diff ../outputs/t1135 ../originals/t1135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1136) timeout -s 9 2 ../source/tcas.exe  604 1 0 911  196 8248 0  721  400 0 0 0     > ../outputs/t1136
    if diff ../outputs/t1136 ../originals/t1136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1137) timeout -s 9 2 ../source/tcas.exe  604 1 0 911  96 8248 0  721  400 0 0 0     > ../outputs/t1137
    if diff ../outputs/t1137 ../originals/t1137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1138) timeout -s 9 2 ../source/tcas.exe  604 1 1 911  96 8248 0  721  400 1 0 1     > ../outputs/t1138
    if diff ../outputs/t1138 ../originals/t1138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1139) timeout -s 9 2 ../source/tcas.exe 1058 1 0 1597  174 3253 0  399  400 1 0 1     > ../outputs/t1139
    if diff ../outputs/t1139 ../originals/t1139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1140) timeout -s 9 2 ../source/tcas.exe 1058 1 0 597  174 3253 0  399  400 1 0 1     > ../outputs/t1140
    if diff ../outputs/t1140 ../originals/t1140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1141) timeout -s 9 2 ../source/tcas.exe 958 1 0 597  174 3253 0  399  400 1 0 1     > ../outputs/t1141
    if diff ../outputs/t1141 ../originals/t1141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1142) timeout -s 9 2 ../source/tcas.exe 958 1 0 597  64 3253 0  399  400 1 0 1     > ../outputs/t1142
    if diff ../outputs/t1142 ../originals/t1142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1143) timeout -s 9 2 ../source/tcas.exe 958 1 0 497  64 3253 0  399  400 1 0 1     > ../outputs/t1143
    if diff ../outputs/t1143 ../originals/t1143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1144) timeout -s 9 2 ../source/tcas.exe 958 1 0 497  64 3253 0  399  200 1 0 1     > ../outputs/t1144
    if diff ../outputs/t1144 ../originals/t1144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1145) timeout -s 9 2 ../source/tcas.exe 958 1 0 797  64 3253 0  399  200 1 0 1     > ../outputs/t1145
    if diff ../outputs/t1145 ../originals/t1145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1146) timeout -s 9 2 ../source/tcas.exe 958 1 0 797  64 3253 0  399  100 1 0 1     > ../outputs/t1146
    if diff ../outputs/t1146 ../originals/t1146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1147) timeout -s 9 2 ../source/tcas.exe 958 1 0 997  64 3253 0  399  120 1 0 1     > ../outputs/t1147
    if diff ../outputs/t1147 ../originals/t1147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1148) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 2253 0  399  120 1 0 1     > ../outputs/t1148
    if diff ../outputs/t1148 ../originals/t1148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1149) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 2153 0  299  126 1 0 1     > ../outputs/t1149
    if diff ../outputs/t1149 ../originals/t1149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1150) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 1153 0  299  126 1 0 1     > ../outputs/t1150
    if diff ../outputs/t1150 ../originals/t1150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1151) timeout -s 9 2 ../source/tcas.exe 718 1 0 917  64 1153 0  299  126 1 0 1     > ../outputs/t1151
    if diff ../outputs/t1151 ../originals/t1151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1152) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  64 1153 0  299  126 1 0 1     > ../outputs/t1152
    if diff ../outputs/t1152 ../originals/t1152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1153) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  34 1153 0  299  126 1 0 1      > ../outputs/t1153
    if diff ../outputs/t1153 ../originals/t1153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1154) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  34 1153 0  229  126 1 0 1     > ../outputs/t1154
    if diff ../outputs/t1154 ../originals/t1154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1155) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  334 1153 0  229  126 1 0 1     > ../outputs/t1155
    if diff ../outputs/t1155 ../originals/t1155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1156) timeout -s 9 2 ../source/tcas.exe 1058 1 0 997  174 7253 0  399  400 0 0 1     > ../outputs/t1156
    if diff ../outputs/t1156 ../originals/t1156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1157) timeout -s 9 2 ../source/tcas.exe 1058 1 0 997  174 7253 0  329  400 0 0 1     > ../outputs/t1157
    if diff ../outputs/t1157 ../originals/t1157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1158) timeout -s 9 2 ../source/tcas.exe 1258 1 0 897  174 7253 1  629  500 0 0 1     > ../outputs/t1158
    if diff ../outputs/t1158 ../originals/t1158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1159) timeout -s 9 2 ../source/tcas.exe 1558 1 0 897  174 7253 2  729  640  0 0 1     > ../outputs/t1159
    if diff ../outputs/t1159 ../originals/t1159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1160) timeout -s 9 2 ../source/tcas.exe 1558 1 0 697  174 7253 2  729  640  0 0 1     > ../outputs/t1160
    if diff ../outputs/t1160 ../originals/t1160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1161) timeout -s 9 2 ../source/tcas.exe 1558 1 0 697  174 7253 2  729  640  1 0 1     > ../outputs/t1161
    if diff ../outputs/t1161 ../originals/t1161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1162) timeout -s 9 2 ../source/tcas.exe 1558 1 1 697  174 7253 2  729  640  1 0 1     > ../outputs/t1162
    if diff ../outputs/t1162 ../originals/t1162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1163) timeout -s 9 2 ../source/tcas.exe 1558 1 1 697  174 7253 2  929  640  1 0 1     > ../outputs/t1163
    if diff ../outputs/t1163 ../originals/t1163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1164) timeout -s 9 2 ../source/tcas.exe 1558 1 1 697  174 7253 3  929  740  1 0 1     > ../outputs/t1164
    if diff ../outputs/t1164 ../originals/t1164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1165) timeout -s 9 2 ../source/tcas.exe 1558 1 1 697  174 7253 3  741  740  1 0 1     > ../outputs/t1165
    if diff ../outputs/t1165 ../originals/t1165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1166) timeout -s 9 2 ../source/tcas.exe 701 1 1 697  174 7253 3  741  740  1 0 1     > ../outputs/t1166
    if diff ../outputs/t1166 ../originals/t1166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1167) timeout -s 9 2 ../source/tcas.exe 701 1 1 697  174 753 3  741  740  1 0 1     > ../outputs/t1167
    if diff ../outputs/t1167 ../originals/t1167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1168) timeout -s 9 2 ../source/tcas.exe 701 1 1 697  174 753 3  749  740  0 0 1     > ../outputs/t1168
    if diff ../outputs/t1168 ../originals/t1168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1169) timeout -s 9 2 ../source/tcas.exe 734 1 0 343 30 545 0 565 321 1 0 1     > ../outputs/t1169
    if diff ../outputs/t1169 ../originals/t1169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1170) timeout -s 9 2 ../source/tcas.exe 934 1 0 343 30 545 0 565 21 0 0 1     > ../outputs/t1170
    if diff ../outputs/t1170 ../originals/t1170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1171) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 0 565 21 0 0 1     > ../outputs/t1171
    if diff ../outputs/t1171 ../originals/t1171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1172) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 1 565 21 0 0 1     > ../outputs/t1172
    if diff ../outputs/t1172 ../originals/t1172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1173) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 2 565 21 0 0 1     > ../outputs/t1173
    if diff ../outputs/t1173 ../originals/t1173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1174) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 3 565 21 0 0 1     > ../outputs/t1174
    if diff ../outputs/t1174 ../originals/t1174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1175) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 3 565 421 0 0 1     > ../outputs/t1175
    if diff ../outputs/t1175 ../originals/t1175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1176) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 3 765 621 0 0 1     > ../outputs/t1176
    if diff ../outputs/t1176 ../originals/t1176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1177) timeout -s 9 2 ../source/tcas.exe 934 0 0 533 30 545 3 765 621 0 0 1     > ../outputs/t1177
    if diff ../outputs/t1177 ../originals/t1177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1178) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 730 545 3 765 621 0 0 1     > ../outputs/t1178
    if diff ../outputs/t1178 ../originals/t1178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1179) timeout -s 9 2 ../source/tcas.exe 34 1 0 533 30 545 3 765 621 0 0 1     > ../outputs/t1179
    if diff ../outputs/t1179 ../originals/t1179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1180) timeout -s 9 2 ../source/tcas.exe 734 1 1 533 30 545 3 765 621 1 1 1     > ../outputs/t1180
    if diff ../outputs/t1180 ../originals/t1180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1181) timeout -s 9 2 ../source/tcas.exe 734 1 0 533 30 545 3 765 621 1 1 1     > ../outputs/t1181
    if diff ../outputs/t1181 ../originals/t1181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1182) timeout -s 9 2 ../source/tcas.exe 734 1 0 343 30 545 0 265 321 1 0 0     > ../outputs/t1182
    if diff ../outputs/t1182 ../originals/t1182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1183) timeout -s 9 2 ../source/tcas.exe 934 1 0 343 30 545 0 5 121 0 0 1     > ../outputs/t1183
    if diff ../outputs/t1183 ../originals/t1183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1184) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 0 65 421 0 0 1     > ../outputs/t1184
    if diff ../outputs/t1184 ../originals/t1184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1185) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 1 65 165 0 0 1     > ../outputs/t1185
    if diff ../outputs/t1185 ../originals/t1185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1186) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 2 565 721 0 0 1     > ../outputs/t1186
    if diff ../outputs/t1186 ../originals/t1186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1187) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 3 565 621 0 0 1     > ../outputs/t1187
    if diff ../outputs/t1187 ../originals/t1187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1188) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 3 365 421 0 0 0     > ../outputs/t1188
    if diff ../outputs/t1188 ../originals/t1188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1189) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 3 365 365 0 0 0     > ../outputs/t1189
    if diff ../outputs/t1189 ../originals/t1189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1190) timeout -s 9 2 ../source/tcas.exe 1058 1 0 997  174 7253 0  399  200 0 0 1     > ../outputs/t1190
    if diff ../outputs/t1190 ../originals/t1190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1191) timeout -s 9 2 ../source/tcas.exe 1058 1 0 997  174 7253 0  329  100 0 0 1     > ../outputs/t1191
    if diff ../outputs/t1191 ../originals/t1191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1192) timeout -s 9 2 ../source/tcas.exe 1258 1 0 897  174 7253 1  629  650 0 0 0     > ../outputs/t1192
    if diff ../outputs/t1192 ../originals/t1192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1193) timeout -s 9 2 ../source/tcas.exe 1558 1 0 897  174 7253 2  729  840  0 0 1     > ../outputs/t1193
    if diff ../outputs/t1193 ../originals/t1193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1194) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 1 65 165 0 0 1     > ../outputs/t1194
    if diff ../outputs/t1194 ../originals/t1194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1195) timeout -s 9 2 ../source/tcas.exe 934 1 0 533 30 545 1 65 165 1 0 1     > ../outputs/t1195
    if diff ../outputs/t1195 ../originals/t1195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1196) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 30 545 1 65 165 1 0 1     > ../outputs/t1196
    if diff ../outputs/t1196 ../originals/t1196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1197) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 30 545 2 65 165 1 0 1     > ../outputs/t1197
    if diff ../outputs/t1197 ../originals/t1197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1198) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 30 545 3 65 165 1 0 1     > ../outputs/t1198
    if diff ../outputs/t1198 ../originals/t1198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1199) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 300 545 3 65 465 1 0 1     > ../outputs/t1199
    if diff ../outputs/t1199 ../originals/t1199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1200) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 400 645 3 265 465 1 0 1     > ../outputs/t1200
    if diff ../outputs/t1200 ../originals/t1200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1201) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 3 265 465 1 0 1     > ../outputs/t1201
    if diff ../outputs/t1201 ../originals/t1201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1202) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 3 265 465 0 0 1     > ../outputs/t1202
    if diff ../outputs/t1202 ../originals/t1202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1203) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 0 265 465 0 0 1     > ../outputs/t1203
    if diff ../outputs/t1203 ../originals/t1203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1204) timeout -s 9 2 ../source/tcas.exe 1034 1 0 433 400 645 0 265 465 0 0 1     > ../outputs/t1204
    if diff ../outputs/t1204 ../originals/t1204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1205) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 30 545 2 65 165 1 0 1     > ../outputs/t1205
    if diff ../outputs/t1205 ../originals/t1205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1206) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 300 545 2 65 465 1 0 1     > ../outputs/t1206
    if diff ../outputs/t1206 ../originals/t1206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1207) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 400 645 2 265 465 1 0 1     > ../outputs/t1207
    if diff ../outputs/t1207 ../originals/t1207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1208) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 2 265 465 1 0 1     > ../outputs/t1208
    if diff ../outputs/t1208 ../originals/t1208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1209) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 2 265 465 0 0 1     > ../outputs/t1209
    if diff ../outputs/t1209 ../originals/t1209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1210) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 2 265 465 0 0 1     > ../outputs/t1210
    if diff ../outputs/t1210 ../originals/t1210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1211) timeout -s 9 2 ../source/tcas.exe 958 1 0 497  64 3253 2  399  400 1 0 1     > ../outputs/t1211
    if diff ../outputs/t1211 ../originals/t1211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1212) timeout -s 9 2 ../source/tcas.exe 958 1 0 497  64 3253 2  399  200 1 0 1     > ../outputs/t1212
    if diff ../outputs/t1212 ../originals/t1212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1213) timeout -s 9 2 ../source/tcas.exe 958 1 0 797  64 3253 2  399  200 1 0 1     > ../outputs/t1213
    if diff ../outputs/t1213 ../originals/t1213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1214) timeout -s 9 2 ../source/tcas.exe 958 1 0 797  64 3253 2  399  100 1 0 1     > ../outputs/t1214
    if diff ../outputs/t1214 ../originals/t1214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1215) timeout -s 9 2 ../source/tcas.exe 958 1 0 997  64 3253 2  399  120 1 0 1     > ../outputs/t1215
    if diff ../outputs/t1215 ../originals/t1215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1216) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 2253 2  399  120 1 0 1     > ../outputs/t1216
    if diff ../outputs/t1216 ../originals/t1216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1217) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 2153 2  299  126 1 0 1     > ../outputs/t1217
    if diff ../outputs/t1217 ../originals/t1217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1218) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 1153 2  299  126 1 0 1     > ../outputs/t1218
    if diff ../outputs/t1218 ../originals/t1218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1219) timeout -s 9 2 ../source/tcas.exe 718 1 0 917  64 1153 2  299  126 1 0 1     > ../outputs/t1219
    if diff ../outputs/t1219 ../originals/t1219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1220) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  64 1153 2  299  126 1 0 1     > ../outputs/t1220
    if diff ../outputs/t1220 ../originals/t1220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1221) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  34 1153 2  299  126 1 0 1      > ../outputs/t1221
    if diff ../outputs/t1221 ../originals/t1221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1222) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  34 1153 2  229  126 1 0 1     > ../outputs/t1222
    if diff ../outputs/t1222 ../originals/t1222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1223) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  334 1153 2  229  126 1 0 1     > ../outputs/t1223
    if diff ../outputs/t1223 ../originals/t1223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1224) timeout -s 9 2 ../source/tcas.exe 1034 1 0 433 200 245 0 565 765 0 0 1     > ../outputs/t1224
    if diff ../outputs/t1224 ../originals/t1224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1225) timeout -s 9 2 ../source/tcas.exe 1034 1 0 433 200 245 0 565 665 0 0 1     > ../outputs/t1225
    if diff ../outputs/t1225 ../originals/t1225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1226) timeout -s 9 2 ../source/tcas.exe 1034 1 0 433 200 245 0 565 665 1 0 1     > ../outputs/t1226
    if diff ../outputs/t1226 ../originals/t1226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1227) timeout -s 9 2 ../source/tcas.exe 1034 1 0 433 200 245 1 565 665 0 0 1     > ../outputs/t1227
    if diff ../outputs/t1227 ../originals/t1227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1228) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 200 245 1 565 795 0 0 1     > ../outputs/t1228
    if diff ../outputs/t1228 ../originals/t1228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1229) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 200 245 1 565 795 1 0 1     > ../outputs/t1229
    if diff ../outputs/t1229 ../originals/t1229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1230) timeout -s 9 2 ../source/tcas.exe 634 1 1 433 200 245 1 565 795 1 0 1     > ../outputs/t1230
    if diff ../outputs/t1230 ../originals/t1230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1231) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 1 565 795 0 0 1     > ../outputs/t1231
    if diff ../outputs/t1231 ../originals/t1231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1232) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 2 665 795 0 0 1     > ../outputs/t1232
    if diff ../outputs/t1232 ../originals/t1232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1233) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 2 665 795 1 0 1     > ../outputs/t1233
    if diff ../outputs/t1233 ../originals/t1233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1234) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 200 535 1 565 795 0 1 1     > ../outputs/t1234
    if diff ../outputs/t1234 ../originals/t1234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1235) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 200 535 0 565 795 0 1 1     > ../outputs/t1235
    if diff ../outputs/t1235 ../originals/t1235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1236) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 200 535 2 665 795 0 1 1     > ../outputs/t1236
    if diff ../outputs/t1236 ../originals/t1236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1237) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 200 535 3 765 795 1 1 1     > ../outputs/t1237
    if diff ../outputs/t1237 ../originals/t1237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1238) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 200 535 3 765 995 0 1 1     > ../outputs/t1238
    if diff ../outputs/t1238 ../originals/t1238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1239) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 30 545 3 65 165 1 0 1     > ../outputs/t1239
    if diff ../outputs/t1239 ../originals/t1239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1240) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 300 545 3 65 465 1 0 1     > ../outputs/t1240
    if diff ../outputs/t1240 ../originals/t1240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1241) timeout -s 9 2 ../source/tcas.exe 634 1 0 533 400 645 3 265 465 1 0 1     > ../outputs/t1241
    if diff ../outputs/t1241 ../originals/t1241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1242) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 3 265 465 1 0 1     > ../outputs/t1242
    if diff ../outputs/t1242 ../originals/t1242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1243) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 3 265 465 0 0 1     > ../outputs/t1243
    if diff ../outputs/t1243 ../originals/t1243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1244) timeout -s 9 2 ../source/tcas.exe 1034 1 0 533 400 645 3 265 465 0 0 1     > ../outputs/t1244
    if diff ../outputs/t1244 ../originals/t1244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1245) timeout -s 9 2 ../source/tcas.exe 958 1 0 497  64 3253 3  399  400 1 0 1     > ../outputs/t1245
    if diff ../outputs/t1245 ../originals/t1245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1246) timeout -s 9 2 ../source/tcas.exe 958 1 0 497  64 3253 3  399  200 1 0 1     > ../outputs/t1246
    if diff ../outputs/t1246 ../originals/t1246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1247) timeout -s 9 2 ../source/tcas.exe 958 1 0 797  64 3253 3  399  200 1 0 1     > ../outputs/t1247
    if diff ../outputs/t1247 ../originals/t1247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1248) timeout -s 9 2 ../source/tcas.exe 958 1 0 797  64 3253 3  399  100 1 0 1     > ../outputs/t1248
    if diff ../outputs/t1248 ../originals/t1248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1249) timeout -s 9 2 ../source/tcas.exe 958 1 0 997  64 3253 3  399  120 1 0 1     > ../outputs/t1249
    if diff ../outputs/t1249 ../originals/t1249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1250) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 2253 3  399  120 1 0 1     > ../outputs/t1250
    if diff ../outputs/t1250 ../originals/t1250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1251) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 2153 3  299  126 1 0 1     > ../outputs/t1251
    if diff ../outputs/t1251 ../originals/t1251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1252) timeout -s 9 2 ../source/tcas.exe 918 1 0 917  64 1153 3  299  126 1 0 1     > ../outputs/t1252
    if diff ../outputs/t1252 ../originals/t1252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1253) timeout -s 9 2 ../source/tcas.exe 718 1 0 917  64 1153 3  299  126 1 0 1     > ../outputs/t1253
    if diff ../outputs/t1253 ../originals/t1253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1254) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  64 1153 3  299  126 1 0 1     > ../outputs/t1254
    if diff ../outputs/t1254 ../originals/t1254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1255) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  34 1153 3  299  126 1 0 1      > ../outputs/t1255
    if diff ../outputs/t1255 ../originals/t1255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1256) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  34 1153 3  229  126 1 0 1     > ../outputs/t1256
    if diff ../outputs/t1256 ../originals/t1256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1257) timeout -s 9 2 ../source/tcas.exe 718 1 0 717  334 1153 3  229  126 1 0 1     > ../outputs/t1257
    if diff ../outputs/t1257 ../originals/t1257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1258) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 0 565 795 1 0 1     > ../outputs/t1258
    if diff ../outputs/t1258 ../originals/t1258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1259) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 0 265 795 1 0 1     > ../outputs/t1259
    if diff ../outputs/t1259 ../originals/t1259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1260) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 0 265 795 1 0 1     > ../outputs/t1260
    if diff ../outputs/t1260 ../originals/t1260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1261) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 0 665 795 0 0 1     > ../outputs/t1261
    if diff ../outputs/t1261 ../originals/t1261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1262) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 300 535 0 665 795 0 1 1     > ../outputs/t1262
    if diff ../outputs/t1262 ../originals/t1262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1263) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 0 665 795 0 1 1     > ../outputs/t1263
    if diff ../outputs/t1263 ../originals/t1263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1264) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 0 665 795 0 1 0     > ../outputs/t1264
    if diff ../outputs/t1264 ../originals/t1264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1265) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 100 535 0 665 795 1 0 0     > ../outputs/t1265
    if diff ../outputs/t1265 ../originals/t1265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1266) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 535 0 665 795 1 0 0     > ../outputs/t1266
    if diff ../outputs/t1266 ../originals/t1266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1267) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 335 0 665 795 1 0 0     > ../outputs/t1267
    if diff ../outputs/t1267 ../originals/t1267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1268) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 500 335 3 845 740 1 0 0     > ../outputs/t1268
    if diff ../outputs/t1268 ../originals/t1268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1269) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 500 335 3 845 740 1 0 1     > ../outputs/t1269
    if diff ../outputs/t1269 ../originals/t1269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1270) timeout -s 9 2 ../source/tcas.exe 634 1 1 233 500 335 3 845 740 0 1 1     > ../outputs/t1270
    if diff ../outputs/t1270 ../originals/t1270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1271) timeout -s 9 2 ../source/tcas.exe 934 1 1 233 500 335 2 845 640 0 1 1     > ../outputs/t1271
    if diff ../outputs/t1271 ../originals/t1271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1272) timeout -s 9 2 ../source/tcas.exe 934 1 1 233 500 335 1 845 500 0 1 1     > ../outputs/t1272
    if diff ../outputs/t1272 ../originals/t1272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1273) timeout -s 9 2 ../source/tcas.exe 934 1 1 233 500 335 0 845 400 0 1 1     > ../outputs/t1273
    if diff ../outputs/t1273 ../originals/t1273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1274) timeout -s 9 2 ../source/tcas.exe 934 1 1 233 100 335 0 845 400 0 1 1     > ../outputs/t1274
    if diff ../outputs/t1274 ../originals/t1274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1275) timeout -s 9 2 ../source/tcas.exe 634 1 1 233 100 335 0 845 400 0 1 1     > ../outputs/t1275
    if diff ../outputs/t1275 ../originals/t1275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1276) timeout -s 9 2 ../source/tcas.exe 634 1 1 233 100 335 0 445 400 0 1 1     > ../outputs/t1276
    if diff ../outputs/t1276 ../originals/t1276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1277) timeout -s 9 2 ../source/tcas.exe 634 1 1 233 400 335 0 445 400 0 1 1     > ../outputs/t1277
    if diff ../outputs/t1277 ../originals/t1277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1278) timeout -s 9 2 ../source/tcas.exe 634 1 1 233 400 235 0 445 400 0 1 1     > ../outputs/t1278
    if diff ../outputs/t1278 ../originals/t1278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1279) timeout -s 9 2 ../source/tcas.exe 634 1 1 233 400 234 0 445 400 0 1 1     > ../outputs/t1279
    if diff ../outputs/t1279 ../originals/t1279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1280) timeout -s 9 2 ../source/tcas.exe 934 1 0 233 500 335 0 845 400 1 0 1     > ../outputs/t1280
    if diff ../outputs/t1280 ../originals/t1280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1281) timeout -s 9 2 ../source/tcas.exe 934 1 0 233 100 335 0 845 400 0 0 1     > ../outputs/t1281
    if diff ../outputs/t1281 ../originals/t1281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1282) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 100 335 0 845 400 0 0 1     > ../outputs/t1282
    if diff ../outputs/t1282 ../originals/t1282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1283) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 100 335 0 445 400 1 0 1     > ../outputs/t1283
    if diff ../outputs/t1283 ../originals/t1283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1284) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 400 335 0 445 400 0 0 1     > ../outputs/t1284
    if diff ../outputs/t1284 ../originals/t1284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1285) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 400 235 0 445 400 0 0 1     > ../outputs/t1285
    if diff ../outputs/t1285 ../originals/t1285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1286) timeout -s 9 2 ../source/tcas.exe 634 1 0 233 400 234 0 445 400 1 0 1     > ../outputs/t1286
    if diff ../outputs/t1286 ../originals/t1286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1287) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 400 634 0 345 500 1 0 1     > ../outputs/t1287
    if diff ../outputs/t1287 ../originals/t1287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1288) timeout -s 9 2 ../source/tcas.exe 634 1 1 433 400 634 0 345 500 0 1 1     > ../outputs/t1288
    if diff ../outputs/t1288 ../originals/t1288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1289) timeout -s 9 2 ../source/tcas.exe 634 1 1 433 200 634 0 345 500 0 1 1     > ../outputs/t1289
    if diff ../outputs/t1289 ../originals/t1289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1290) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 200 634 0 345 500 0 0 1     > ../outputs/t1290
    if diff ../outputs/t1290 ../originals/t1290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1291) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 200 634 0 345 500 1 0 1     > ../outputs/t1291
    if diff ../outputs/t1291 ../originals/t1291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1292) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 300 634 0 345 450 1 0 1     > ../outputs/t1292
    if diff ../outputs/t1292 ../originals/t1292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1293) timeout -s 9 2 ../source/tcas.exe 1934 1 0 433 300 634 0 345 450 1 0 1     > ../outputs/t1293
    if diff ../outputs/t1293 ../originals/t1293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1294) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 2 565 795 1 0 1     > ../outputs/t1294
    if diff ../outputs/t1294 ../originals/t1294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1295) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 2 265 795 1 0 1     > ../outputs/t1295
    if diff ../outputs/t1295 ../originals/t1295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1296) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 2 265 795 1 0 1     > ../outputs/t1296
    if diff ../outputs/t1296 ../originals/t1296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1297) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 2 665 795 0 0 1     > ../outputs/t1297
    if diff ../outputs/t1297 ../originals/t1297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1298) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 300 535 2 665 795 0 1 1     > ../outputs/t1298
    if diff ../outputs/t1298 ../originals/t1298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1299) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 2 665 795 0 1 1     > ../outputs/t1299
    if diff ../outputs/t1299 ../originals/t1299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1300) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 2 665 795 0 1 0     > ../outputs/t1300
    if diff ../outputs/t1300 ../originals/t1300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1301) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 100 535 2 665 795 1 0 0     > ../outputs/t1301
    if diff ../outputs/t1301 ../originals/t1301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1302) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 535 2 665 795 1 0 0     > ../outputs/t1302
    if diff ../outputs/t1302 ../originals/t1302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1303) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 335 2 665 795 1 0 0     > ../outputs/t1303
    if diff ../outputs/t1303 ../originals/t1303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1304) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 234 0 445 550 1 0 1     > ../outputs/t1304
    if diff ../outputs/t1304 ../originals/t1304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1305) timeout -s 9 2 ../source/tcas.exe 934 1 1 433 400 234 0 445 550 0 1 1     > ../outputs/t1305
    if diff ../outputs/t1305 ../originals/t1305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1306) timeout -s 9 2 ../source/tcas.exe 934 1 1 433 400 234 0 445 550 0 1 0     > ../outputs/t1306
    if diff ../outputs/t1306 ../originals/t1306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1307) timeout -s 9 2 ../source/tcas.exe 634 1 1 433 500 234 0 445 550 0 1 1     > ../outputs/t1307
    if diff ../outputs/t1307 ../originals/t1307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1308) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 500 234 0 445 550 1 0 1     > ../outputs/t1308
    if diff ../outputs/t1308 ../originals/t1308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1309) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 500 334 0 445 550 1 0 1     > ../outputs/t1309
    if diff ../outputs/t1309 ../originals/t1309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1310) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 3 565 795 1 0 1     > ../outputs/t1310
    if diff ../outputs/t1310 ../originals/t1310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1311) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 3 265 795 1 0 1     > ../outputs/t1311
    if diff ../outputs/t1311 ../originals/t1311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1312) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 3 265 795 1 0 1     > ../outputs/t1312
    if diff ../outputs/t1312 ../originals/t1312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1313) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 3 665 795 0 0 1     > ../outputs/t1313
    if diff ../outputs/t1313 ../originals/t1313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1314) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 300 535 3 665 795 0 1 1     > ../outputs/t1314
    if diff ../outputs/t1314 ../originals/t1314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1315) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 3 665 795 0 1 1     > ../outputs/t1315
    if diff ../outputs/t1315 ../originals/t1315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1316) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 3 665 795 0 1 0     > ../outputs/t1316
    if diff ../outputs/t1316 ../originals/t1316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1317) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 100 535 3 665 795 1 0 0     > ../outputs/t1317
    if diff ../outputs/t1317 ../originals/t1317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1318) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 535 3 665 795 1 0 0     > ../outputs/t1318
    if diff ../outputs/t1318 ../originals/t1318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1319) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 335 3 665 795 1 0 0     > ../outputs/t1319
    if diff ../outputs/t1319 ../originals/t1319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1320) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 500 334 0 445 350 1 0 1     > ../outputs/t1320
    if diff ../outputs/t1320 ../originals/t1320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1321) timeout -s 9 2 ../source/tcas.exe 634 1 1 433 500 334 0 445 350 0 1 1     > ../outputs/t1321
    if diff ../outputs/t1321 ../originals/t1321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1322) timeout -s 9 2 ../source/tcas.exe 634 1 1 433 500 334 0 445 350 0 1 0     > ../outputs/t1322
    if diff ../outputs/t1322 ../originals/t1322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1323) timeout -s 9 2 ../source/tcas.exe 634 1 0 433 300 433 0 445 350 1 0 1     > ../outputs/t1323
    if diff ../outputs/t1323 ../originals/t1323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1324) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 433 0 445 350 1 0 0     > ../outputs/t1324
    if diff ../outputs/t1324 ../originals/t1324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1325) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 433 1 445 350 1 0 0     > ../outputs/t1325
    if diff ../outputs/t1325 ../originals/t1325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1326) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 433 2 445 350 1 0 0     > ../outputs/t1326
    if diff ../outputs/t1326 ../originals/t1326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1327) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 433 3 445 350 1 0 0     > ../outputs/t1327
    if diff ../outputs/t1327 ../originals/t1327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1328) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 433 3 445 350 1 0 1     > ../outputs/t1328
    if diff ../outputs/t1328 ../originals/t1328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1329) timeout -s 9 2 ../source/tcas.exe 934 1 1 433 400 433 3 445 350 0 1 1     > ../outputs/t1329
    if diff ../outputs/t1329 ../originals/t1329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1330) timeout -s 9 2 ../source/tcas.exe 934 1 1 433 500 433 3 445 350 0 1 1     > ../outputs/t1330
    if diff ../outputs/t1330 ../originals/t1330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1331) timeout -s 9 2 ../source/tcas.exe 734 1 1 433 100 433 3 445 350 0 1 1     > ../outputs/t1331
    if diff ../outputs/t1331 ../originals/t1331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1332) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 1 565 795 1 0 1     > ../outputs/t1332
    if diff ../outputs/t1332 ../originals/t1332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1333) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 200 535 1 265 795 1 0 1     > ../outputs/t1333
    if diff ../outputs/t1333 ../originals/t1333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1334) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 1 265 795 1 0 1     > ../outputs/t1334
    if diff ../outputs/t1334 ../originals/t1334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1335) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 300 535 1 665 795 0 0 1     > ../outputs/t1335
    if diff ../outputs/t1335 ../originals/t1335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1336) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 300 535 1 665 795 0 1 1     > ../outputs/t1336
    if diff ../outputs/t1336 ../originals/t1336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1337) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 1 665 795 0 1 1     > ../outputs/t1337
    if diff ../outputs/t1337 ../originals/t1337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1338) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 100 535 1 665 795 0 1 0     > ../outputs/t1338
    if diff ../outputs/t1338 ../originals/t1338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1339) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 100 535 1 665 795 1 0 0     > ../outputs/t1339
    if diff ../outputs/t1339 ../originals/t1339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1340) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 535 1 665 795 1 0 0     > ../outputs/t1340
    if diff ../outputs/t1340 ../originals/t1340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1341) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 335 1 665 795 1 0 0     > ../outputs/t1341
    if diff ../outputs/t1341 ../originals/t1341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1342) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 400 234 0 445 550 1 0 0     > ../outputs/t1342
    if diff ../outputs/t1342 ../originals/t1342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1343) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 200 234 0 445 550 1 0 0     > ../outputs/t1343
    if diff ../outputs/t1343 ../originals/t1343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1344) timeout -s 9 2 ../source/tcas.exe 934 1 0 433 200 234 0 445 550 0 0 0      > ../outputs/t1344
    if diff ../outputs/t1344 ../originals/t1344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1345) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 100 602 0 500 400 1 0 0     > ../outputs/t1345
    if diff ../outputs/t1345 ../originals/t1345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1346) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 200 602 0 599 400 1 0 1     > ../outputs/t1346
    if diff ../outputs/t1346 ../originals/t1346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1347) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 200 602 0 599 400 0 0 1     > ../outputs/t1347
    if diff ../outputs/t1347 ../originals/t1347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1348) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 602 0 599 400 0 0 0     > ../outputs/t1348
    if diff ../outputs/t1348 ../originals/t1348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1349) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 602 0 599 400 0 1 0     > ../outputs/t1349
    if diff ../outputs/t1349 ../originals/t1349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1350) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 0 401 400 0 1 0     > ../outputs/t1350
    if diff ../outputs/t1350 ../originals/t1350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1351) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 0 401 400 0 1 1     > ../outputs/t1351
    if diff ../outputs/t1351 ../originals/t1351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1352) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 1 401 500 0 1 1     > ../outputs/t1352
    if diff ../outputs/t1352 ../originals/t1352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1353) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 1 401 500 0 1 0     > ../outputs/t1353
    if diff ../outputs/t1353 ../originals/t1353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1354) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 2 701 640 0 1 0     > ../outputs/t1354
    if diff ../outputs/t1354 ../originals/t1354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1355) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 2 701 640 0 1 1     > ../outputs/t1355
    if diff ../outputs/t1355 ../originals/t1355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1356) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 3 801 740 0 1 1     > ../outputs/t1356
    if diff ../outputs/t1356 ../originals/t1356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1357) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 3 801 740 0 1 0     > ../outputs/t1357
    if diff ../outputs/t1357 ../originals/t1357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1358) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 503 1 401 500 0 0 1     > ../outputs/t1358
    if diff ../outputs/t1358 ../originals/t1358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1359) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 503 1 401 500 0 0 0     > ../outputs/t1359
    if diff ../outputs/t1359 ../originals/t1359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1360) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 2 701 640 0 0 0     > ../outputs/t1360
    if diff ../outputs/t1360 ../originals/t1360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1361) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 2 701 640 0 0 1     > ../outputs/t1361
    if diff ../outputs/t1361 ../originals/t1361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1362) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 3 801 740 0 0 1     > ../outputs/t1362
    if diff ../outputs/t1362 ../originals/t1362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1363) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 3 801 740 0 0 0     > ../outputs/t1363
    if diff ../outputs/t1363 ../originals/t1363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1364) timeout -s 9 2 ../source/tcas.exe 599 0 0 400 100 300 0 800 400 0 0 0     > ../outputs/t1364
    if diff ../outputs/t1364 ../originals/t1364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1365) timeout -s 9 2 ../source/tcas.exe 601 0 0 400 100 300 0 800 400 0 0 0     > ../outputs/t1365
    if diff ../outputs/t1365 ../originals/t1365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1366) timeout -s 9 2 ../source/tcas.exe 599 1 0 400 601 300 0 800 400 0 0 0     > ../outputs/t1366
    if diff ../outputs/t1366 ../originals/t1366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1367) timeout -s 9 2 ../source/tcas.exe 602 1 0 400 601 300 0 800 400 0 0 0     > ../outputs/t1367
    if diff ../outputs/t1367 ../originals/t1367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1368) timeout -s 9 2 ../source/tcas.exe 602 1 0 400 601 300 0 800 400 0 1 0     > ../outputs/t1368
    if diff ../outputs/t1368 ../originals/t1368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1369) timeout -s 9 2 ../source/tcas.exe 602 1 0 400 601 300 0 800 400 1 1 0     > ../outputs/t1369
    if diff ../outputs/t1369 ../originals/t1369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1370) timeout -s 9 2 ../source/tcas.exe 602 1 0 400 601 300 0 800 400 1 1 1     > ../outputs/t1370
    if diff ../outputs/t1370 ../originals/t1370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1371) timeout -s 9 2 ../source/tcas.exe 602 1 1 400 601 300 0 800 400 1 1 1     > ../outputs/t1371
    if diff ../outputs/t1371 ../originals/t1371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1372) timeout -s 9 2 ../source/tcas.exe 602 1 1 400 601 300 3 800 400 1 1 1     > ../outputs/t1372
    if diff ../outputs/t1372 ../originals/t1372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1373) timeout -s 9 2 ../source/tcas.exe 602 1 1 400 601 300 3 800 400 1 0 1     > ../outputs/t1373
    if diff ../outputs/t1373 ../originals/t1373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1374) timeout -s 9 2 ../source/tcas.exe 602 1 1 400 601 300 3 800 400 0 0 1     > ../outputs/t1374
    if diff ../outputs/t1374 ../originals/t1374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1375) timeout -s 9 2 ../source/tcas.exe 602 0 1 400 601 300 3 800 400 0 0 1     > ../outputs/t1375
    if diff ../outputs/t1375 ../originals/t1375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1376) timeout -s 9 2 ../source/tcas.exe 602 0 1 400 601 300 3 800 400 1 0 1     > ../outputs/t1376
    if diff ../outputs/t1376 ../originals/t1376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1377) timeout -s 9 2 ../source/tcas.exe 602 0 1 400 601 300 3 800 400 1 1 1     > ../outputs/t1377
    if diff ../outputs/t1377 ../originals/t1377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1378) timeout -s 9 2 ../source/tcas.exe 602 0 1 400 601 300 3 800 400 1 1 0     > ../outputs/t1378
    if diff ../outputs/t1378 ../originals/t1378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1379) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 100 602 0 300 400 1 0 0     > ../outputs/t1379
    if diff ../outputs/t1379 ../originals/t1379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1380) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 200 602 0 299 400 1 0 1     > ../outputs/t1380
    if diff ../outputs/t1380 ../originals/t1380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1381) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 200 602 0 299 400 0 0 1     > ../outputs/t1381
    if diff ../outputs/t1381 ../originals/t1381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1382) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 602 0 299 400 0 0 0     > ../outputs/t1382
    if diff ../outputs/t1382 ../originals/t1382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1383) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 602 0 299 400 0 1 0     > ../outputs/t1383
    if diff ../outputs/t1383 ../originals/t1383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1384) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 0 301 400 0 1 0     > ../outputs/t1384
    if diff ../outputs/t1384 ../originals/t1384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1385) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 0 301 400 0 1 1     > ../outputs/t1385
    if diff ../outputs/t1385 ../originals/t1385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1386) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 1 201 500 0 1 1     > ../outputs/t1386
    if diff ../outputs/t1386 ../originals/t1386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1387) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 503 1 201 500 0 1 0     > ../outputs/t1387
    if diff ../outputs/t1387 ../originals/t1387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1388) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 2 501 640 0 1 0     > ../outputs/t1388
    if diff ../outputs/t1388 ../originals/t1388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1389) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 2 301 640 0 1 1     > ../outputs/t1389
    if diff ../outputs/t1389 ../originals/t1389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1390) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 3 401 740 0 1 1     > ../outputs/t1390
    if diff ../outputs/t1390 ../originals/t1390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1391) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 650 3 201 740 0 1 0     > ../outputs/t1391
    if diff ../outputs/t1391 ../originals/t1391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1392) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 503 1 101 500 0 0 1     > ../outputs/t1392
    if diff ../outputs/t1392 ../originals/t1392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1393) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 503 1 401 500 0 0 0     > ../outputs/t1393
    if diff ../outputs/t1393 ../originals/t1393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1394) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 2 301 640 0 0 0     > ../outputs/t1394
    if diff ../outputs/t1394 ../originals/t1394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1395) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 2 201 640 0 0 1     > ../outputs/t1395
    if diff ../outputs/t1395 ../originals/t1395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1396) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 3 401 740 0 0 1     > ../outputs/t1396
    if diff ../outputs/t1396 ../originals/t1396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1397) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 650 3 601 740 0 0 0     > ../outputs/t1397
    if diff ../outputs/t1397 ../originals/t1397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1398) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 100 402 0 500 400 1 0 0     > ../outputs/t1398
    if diff ../outputs/t1398 ../originals/t1398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1399) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 200 402 0 599 400 1 0 1     > ../outputs/t1399
    if diff ../outputs/t1399 ../originals/t1399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1400) timeout -s 9 2 ../source/tcas.exe 601 1 0 502 200 502 0 599 400 0 0 1     > ../outputs/t1400
    if diff ../outputs/t1400 ../originals/t1400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1401) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 402 0 599 400 0 0 0     > ../outputs/t1401
    if diff ../outputs/t1401 ../originals/t1401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1402) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 302 0 599 400 0 1 0     > ../outputs/t1402
    if diff ../outputs/t1402 ../originals/t1402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1403) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 403 0 401 400 0 1 0     > ../outputs/t1403
    if diff ../outputs/t1403 ../originals/t1403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1404) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 403 0 401 400 0 1 1     > ../outputs/t1404
    if diff ../outputs/t1404 ../originals/t1404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1405) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 303 1 401 500 0 1 1     > ../outputs/t1405
    if diff ../outputs/t1405 ../originals/t1405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1406) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 203 1 401 500 0 1 0     > ../outputs/t1406
    if diff ../outputs/t1406 ../originals/t1406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1407) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 2 701 640 0 1 0     > ../outputs/t1407
    if diff ../outputs/t1407 ../originals/t1407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1408) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 2 701 640 0 1 1     > ../outputs/t1408
    if diff ../outputs/t1408 ../originals/t1408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1409) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 3 801 740 0 1 1     > ../outputs/t1409
    if diff ../outputs/t1409 ../originals/t1409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1410) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 350 3 801 740 0 1 0     > ../outputs/t1410
    if diff ../outputs/t1410 ../originals/t1410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1411) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 403 1 401 500 0 0 1     > ../outputs/t1411
    if diff ../outputs/t1411 ../originals/t1411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1412) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 303 1 401 500 0 0 0     > ../outputs/t1412
    if diff ../outputs/t1412 ../originals/t1412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1413) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 450 2 701 640 0 0 0     > ../outputs/t1413
    if diff ../outputs/t1413 ../originals/t1413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1414) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 350 2 701 640 0 0 1     > ../outputs/t1414
    if diff ../outputs/t1414 ../originals/t1414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1415) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 450 3 801 740 0 0 1     > ../outputs/t1415
    if diff ../outputs/t1415 ../originals/t1415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1416) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 350 3 801 740 0 0 0     > ../outputs/t1416
    if diff ../outputs/t1416 ../originals/t1416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1417) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 0 500 400 1 0 1     > ../outputs/t1417
    if diff ../outputs/t1417 ../originals/t1417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1418) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 0 400 400 0 0 1     > ../outputs/t1418
    if diff ../outputs/t1418 ../originals/t1418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1419) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 1 500 500 0 0 1     > ../outputs/t1419
    if diff ../outputs/t1419 ../originals/t1419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1420) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 1 500 500 0 1 1     > ../outputs/t1420
    if diff ../outputs/t1420 ../originals/t1420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1421) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 1 600 500 0 1 1      > ../outputs/t1421
    if diff ../outputs/t1421 ../originals/t1421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1422) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 1 600 500 0 1 0     > ../outputs/t1422
    if diff ../outputs/t1422 ../originals/t1422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1423) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 2 700 640  1 0 1     > ../outputs/t1423
    if diff ../outputs/t1423 ../originals/t1423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1424) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 2 800 640 0 0 1     > ../outputs/t1424
    if diff ../outputs/t1424 ../originals/t1424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1425) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 3 900 740 0 0 1     > ../outputs/t1425
    if diff ../outputs/t1425 ../originals/t1425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1426) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 3 900 740 0 1 1     > ../outputs/t1426
    if diff ../outputs/t1426 ../originals/t1426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1427) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 3 900 740 0 1 1      > ../outputs/t1427
    if diff ../outputs/t1427 ../originals/t1427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1428) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 3 900 740 0 1 0     > ../outputs/t1428
    if diff ../outputs/t1428 ../originals/t1428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1429) timeout -s 9 2 ../source/tcas.exe 675 0 0 300 0 424 5 600 500 1 1 1     > ../outputs/t1429
    if diff ../outputs/t1429 ../originals/t1429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1430) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 1 600 500 0 1 0     > ../outputs/t1430
    if diff ../outputs/t1430 ../originals/t1430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1431) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 5 600 500 0 1 0     > ../outputs/t1431
    if diff ../outputs/t1431 ../originals/t1431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1432) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 5 600 500 1 1 0     > ../outputs/t1432
    if diff ../outputs/t1432 ../originals/t1432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1433) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 5 600 500 1 1 1     > ../outputs/t1433
    if diff ../outputs/t1433 ../originals/t1433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1434) timeout -s 9 2 ../source/tcas.exe 675 0 0 300 0 424 5 600 500 1 1 1     > ../outputs/t1434
    if diff ../outputs/t1434 ../originals/t1434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1435) timeout -s 9 2 ../source/tcas.exe 65 0 0 300 0 424 5 600 500 1 1 1     > ../outputs/t1435
    if diff ../outputs/t1435 ../originals/t1435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1436) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 0 424 5 600 500 1 1 1      > ../outputs/t1436
    if diff ../outputs/t1436 ../originals/t1436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1437) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 0 424 5 600 500 0 0 0     > ../outputs/t1437
    if diff ../outputs/t1437 ../originals/t1437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1438) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 700 424 5 600 500 0 0 0     > ../outputs/t1438
    if diff ../outputs/t1438 ../originals/t1438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1439) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 700 424 5 600 500 1 1 1     > ../outputs/t1439
    if diff ../outputs/t1439 ../originals/t1439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1440) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 5 400 500 1 0 1     > ../outputs/t1440
    if diff ../outputs/t1440 ../originals/t1440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1441) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 5 400 500 0 0 1     > ../outputs/t1441
    if diff ../outputs/t1441 ../originals/t1441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1442) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 5 400 500 0 0 0     > ../outputs/t1442
    if diff ../outputs/t1442 ../originals/t1442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1443) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 2 400 500 0 0 0     > ../outputs/t1443
    if diff ../outputs/t1443 ../originals/t1443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1444) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 3 400 500 0 0 0     > ../outputs/t1444
    if diff ../outputs/t1444 ../originals/t1444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1445) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 4 400 500 0 1 0     > ../outputs/t1445
    if diff ../outputs/t1445 ../originals/t1445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1446) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 4 400 500 0 1 1     > ../outputs/t1446
    if diff ../outputs/t1446 ../originals/t1446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1447) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 4 400 500 1 1 1     > ../outputs/t1447
    if diff ../outputs/t1447 ../originals/t1447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1448) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 500 424 3 400 500 1 1 1     > ../outputs/t1448
    if diff ../outputs/t1448 ../originals/t1448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1449) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 600 424 3 400 500 1 1 1     > ../outputs/t1449
    if diff ../outputs/t1449 ../originals/t1449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1450) timeout -s 9 2 ../source/tcas.exe 718 1 0 717 34 1153 0 229 126 1 0 0     > ../outputs/t1450
    if diff ../outputs/t1450 ../originals/t1450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1451) timeout -s 9 2 ../source/tcas.exe 718 1 0 717 34 1153 0 229 126 0 0 0     > ../outputs/t1451
    if diff ../outputs/t1451 ../originals/t1451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1452) timeout -s 9 2 ../source/tcas.exe 718 1 1 717 34 1153 0 229 126 0 1 0     > ../outputs/t1452
    if diff ../outputs/t1452 ../originals/t1452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1453) timeout -s 9 2 ../source/tcas.exe 718 1 1 717 34 1153 1 229 126 0 1 0     > ../outputs/t1453
    if diff ../outputs/t1453 ../originals/t1453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1454) timeout -s 9 2 ../source/tcas.exe 718 1 1 717 34 1153 2 229 126 0 1 0     > ../outputs/t1454
    if diff ../outputs/t1454 ../originals/t1454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1455) timeout -s 9 2 ../source/tcas.exe 718 1 1 717 34 1153 3 229 126 0 1 0     > ../outputs/t1455
    if diff ../outputs/t1455 ../originals/t1455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1456) timeout -s 9 2 ../source/tcas.exe 718 1 1 717 34 1153 1 229 226 0 1 0     > ../outputs/t1456
    if diff ../outputs/t1456 ../originals/t1456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1457) timeout -s 9 2 ../source/tcas.exe 718 1 0 717 34 1153 1 429 326 0 0 0     > ../outputs/t1457
    if diff ../outputs/t1457 ../originals/t1457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1458) timeout -s 9 2 ../source/tcas.exe 718 1 0 717 34 1153 2 429 326 0 0 0     > ../outputs/t1458
    if diff ../outputs/t1458 ../originals/t1458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1459) timeout -s 9 2 ../source/tcas.exe 601 1 0 717 534 1153 2 429 326 0 0 0     > ../outputs/t1459
    if diff ../outputs/t1459 ../originals/t1459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1460) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 5 400 500 1 0 1     > ../outputs/t1460
    if diff ../outputs/t1460 ../originals/t1460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1461) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 5 400 500 0 0 1     > ../outputs/t1461
    if diff ../outputs/t1461 ../originals/t1461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1462) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 5 400 500 0 0 0     > ../outputs/t1462
    if diff ../outputs/t1462 ../originals/t1462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1463) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 2 400 500 0 0 0     > ../outputs/t1463
    if diff ../outputs/t1463 ../originals/t1463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1464) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 400 500 0 0 0     > ../outputs/t1464
    if diff ../outputs/t1464 ../originals/t1464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1465) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 1 600 500 0 1 0     > ../outputs/t1465
    if diff ../outputs/t1465 ../originals/t1465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1466) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 3 600 500 0 1 0     > ../outputs/t1466
    if diff ../outputs/t1466 ../originals/t1466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1467) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 599 424 2 600 500 1 1 0     > ../outputs/t1467
    if diff ../outputs/t1467 ../originals/t1467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1468) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 0 600 500 1 1 1     > ../outputs/t1468
    if diff ../outputs/t1468 ../originals/t1468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1469) timeout -s 9 2 ../source/tcas.exe 675 0 0 300 0 424 1 600 500 1 1 1     > ../outputs/t1469
    if diff ../outputs/t1469 ../originals/t1469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1470) timeout -s 9 2 ../source/tcas.exe 65 0 0 300 0 424 2 600 500 1 1 1     > ../outputs/t1470
    if diff ../outputs/t1470 ../originals/t1470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1471) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 0 424 3 600 500 1 1 1      > ../outputs/t1471
    if diff ../outputs/t1471 ../originals/t1471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1472) timeout -s 9 2 ../source/tcas.exe 5 0 1 300 0 424 2 600 500 0 0 0     > ../outputs/t1472
    if diff ../outputs/t1472 ../originals/t1472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1473) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 700 424 1 600 500 0 0 0     > ../outputs/t1473
    if diff ../outputs/t1473 ../originals/t1473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1474) timeout -s 9 2 ../source/tcas.exe 65 0 1 300 700 424 2 600 500 1 1 1     > ../outputs/t1474
    if diff ../outputs/t1474 ../originals/t1474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1475) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 300 424 0 400 500 1 0 1     > ../outputs/t1475
    if diff ../outputs/t1475 ../originals/t1475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1476) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 100 424 2 400 500 0 0 1     > ../outputs/t1476
    if diff ../outputs/t1476 ../originals/t1476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1477) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 0 424 1 400 500 0 0 0     > ../outputs/t1477
    if diff ../outputs/t1477 ../originals/t1477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1478) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 40 424 2 400 500 0 0 0     > ../outputs/t1478
    if diff ../outputs/t1478 ../originals/t1478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1479) timeout -s 9 2 ../source/tcas.exe 765 1 0 300 400 424 3 400 500 1 0 0     > ../outputs/t1479
    if diff ../outputs/t1479 ../originals/t1479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1480) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 600 800 1 0 1     > ../outputs/t1480
    if diff ../outputs/t1480 ../originals/t1480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1481) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 600 800 1 0 0     > ../outputs/t1481
    if diff ../outputs/t1481 ../originals/t1481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1482) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 600 800 0 0 0     > ../outputs/t1482
    if diff ../outputs/t1482 ../originals/t1482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1483) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 600 800 0 0 1     > ../outputs/t1483
    if diff ../outputs/t1483 ../originals/t1483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1484) timeout -s 9 2 ../source/tcas.exe 665 1 0 500 500 624 3 600 800 0 0 1     > ../outputs/t1484
    if diff ../outputs/t1484 ../originals/t1484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1485) timeout -s 9 2 ../source/tcas.exe 665 1 0 600 500 524 3 600 800 0 0 1     > ../outputs/t1485
    if diff ../outputs/t1485 ../originals/t1485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1486) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 5 600 500 1 0 1     > ../outputs/t1486
    if diff ../outputs/t1486 ../originals/t1486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1487) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 5 600 500 0 0 1     > ../outputs/t1487
    if diff ../outputs/t1487 ../originals/t1487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1488) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 5 600 500 0 0 0     > ../outputs/t1488
    if diff ../outputs/t1488 ../originals/t1488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1489) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 2 600 500 0 0 0     > ../outputs/t1489
    if diff ../outputs/t1489 ../originals/t1489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1490) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 600 500 0 0 0     > ../outputs/t1490
    if diff ../outputs/t1490 ../originals/t1490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1491) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 200 500 1 100 200 1 0 0     > ../outputs/t1491
    if diff ../outputs/t1491 ../originals/t1491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1492) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 200 600 1 100 500 1 0 0     > ../outputs/t1492
    if diff ../outputs/t1492 ../originals/t1492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1493) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 300 600 3 100 500 1 0 0     > ../outputs/t1493
    if diff ../outputs/t1493 ../originals/t1493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1494) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 300 600 3 100 500 1 0 1     > ../outputs/t1494
    if diff ../outputs/t1494 ../originals/t1494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1495) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 300 600 3 100 500 0 0 1     > ../outputs/t1495
    if diff ../outputs/t1495 ../originals/t1495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1496) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 300 600 3 100 500 0 0 0      > ../outputs/t1496
    if diff ../outputs/t1496 ../originals/t1496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1497) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 400 600 2 100 500 0 0 0     > ../outputs/t1497
    if diff ../outputs/t1497 ../originals/t1497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1498) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 400 600 2 100 500 0 1 0     > ../outputs/t1498
    if diff ../outputs/t1498 ../originals/t1498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1499) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 400 600 2 100 500 0 1 1     > ../outputs/t1499
    if diff ../outputs/t1499 ../originals/t1499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1500) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 200 600 0 100 500 0 1 1     > ../outputs/t1500
    if diff ../outputs/t1500 ../originals/t1500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1501) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 200 600 0 100 500 0 1 1      > ../outputs/t1501
    if diff ../outputs/t1501 ../originals/t1501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1502) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 300 600 2 100 500 0 1 1      > ../outputs/t1502
    if diff ../outputs/t1502 ../originals/t1502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1503) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 300 600 2 100 300 0 1 1      > ../outputs/t1503
    if diff ../outputs/t1503 ../originals/t1503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1504) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 300 600 2 100 300 1 1 1     > ../outputs/t1504
    if diff ../outputs/t1504 ../originals/t1504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1505) timeout -s 9 2 ../source/tcas.exe 800 1 1 400 300 600 3 100 300 1 1 1     > ../outputs/t1505
    if diff ../outputs/t1505 ../originals/t1505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1506) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 300 600 3 100 800 0 0 1     > ../outputs/t1506
    if diff ../outputs/t1506 ../originals/t1506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1507) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 200 600 0 100 300 0 1 1     > ../outputs/t1507
    if diff ../outputs/t1507 ../originals/t1507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1508) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 200 600 1 100 500 1 0 0     > ../outputs/t1508
    if diff ../outputs/t1508 ../originals/t1508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1509) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 400 600 2 100 500 0 0 0     > ../outputs/t1509
    if diff ../outputs/t1509 ../originals/t1509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1510) timeout -s 9 2 ../source/tcas.exe 700 1 0 400 400 600 2 100 600 0 0 0     > ../outputs/t1510
    if diff ../outputs/t1510 ../originals/t1510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1511) timeout -s 9 2 ../source/tcas.exe 700 1 1 400 300 600 2 100 500 0 1 1     > ../outputs/t1511
    if diff ../outputs/t1511 ../originals/t1511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1512) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 400 200 2 300 400 1 1 1      > ../outputs/t1512
    if diff ../outputs/t1512 ../originals/t1512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1513) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 400 200 3 300 400 1 1 1     > ../outputs/t1513
    if diff ../outputs/t1513 ../originals/t1513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1514) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 400 200 3 300 400 1 1 0     > ../outputs/t1514
    if diff ../outputs/t1514 ../originals/t1514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1515) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 400 200 3 300 400 0 1 0     > ../outputs/t1515
    if diff ../outputs/t1515 ../originals/t1515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1516) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 0 200 0 300 400 0 1 0     > ../outputs/t1516
    if diff ../outputs/t1516 ../originals/t1516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1517) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 0 200 1 300 400 0 1 0     > ../outputs/t1517
    if diff ../outputs/t1517 ../originals/t1517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1518) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 0 200 1 300 400 1 1 1     > ../outputs/t1518
    if diff ../outputs/t1518 ../originals/t1518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1519) timeout -s 9 2 ../source/tcas.exe 610 1 0 400 0 200 1 300 800 1 1 1     > ../outputs/t1519
    if diff ../outputs/t1519 ../originals/t1519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1520) timeout -s 9 2 ../source/tcas.exe 665 1 0 500 500 624 2 600 800 0 0 1     > ../outputs/t1520
    if diff ../outputs/t1520 ../originals/t1520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1521) timeout -s 9 2 ../source/tcas.exe 665 1 0 500 500 624 2 600 800 1 0 1     > ../outputs/t1521
    if diff ../outputs/t1521 ../originals/t1521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1522) timeout -s 9 2 ../source/tcas.exe 665 1 0 500 500 624 3 600 800 1 0 1     > ../outputs/t1522
    if diff ../outputs/t1522 ../originals/t1522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1523) timeout -s 9 2 ../source/tcas.exe 665 1 0 500 500 624 3 600 600 1 0 0     > ../outputs/t1523
    if diff ../outputs/t1523 ../originals/t1523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1524) timeout -s 9 2 ../source/tcas.exe 665 1 0 500 500 624 2 600 600 1 0 0     > ../outputs/t1524
    if diff ../outputs/t1524 ../originals/t1524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1525) timeout -s 9 2 ../source/tcas.exe 665 1 1 500 500 624 2 600 600 0 1 0     > ../outputs/t1525
    if diff ../outputs/t1525 ../originals/t1525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1526) timeout -s 9 2 ../source/tcas.exe 665 1 1 500 500 624 3 600 600 0 1 0     > ../outputs/t1526
    if diff ../outputs/t1526 ../originals/t1526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1527) timeout -s 9 2 ../source/tcas.exe 665 1 1 500 200 624 3 600 600 0 1 0     > ../outputs/t1527
    if diff ../outputs/t1527 ../originals/t1527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1528) timeout -s 9 2 ../source/tcas.exe 665 1 1 300 200 624 3 600 600 0 1 0     > ../outputs/t1528
    if diff ../outputs/t1528 ../originals/t1528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1529) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 2 600 500 0 0 0     > ../outputs/t1529
    if diff ../outputs/t1529 ../originals/t1529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1530) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 2 600 500 1 0 1     > ../outputs/t1530
    if diff ../outputs/t1530 ../originals/t1530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1531) timeout -s 9 2 ../source/tcas.exe 765 1 0 500 400 424 3 600 500 1 0 1     > ../outputs/t1531
    if diff ../outputs/t1531 ../originals/t1531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1532) timeout -s 9 2 ../source/tcas.exe 765 1 1 500 400 424 3 600 500 0 1 1     > ../outputs/t1532
    if diff ../outputs/t1532 ../originals/t1532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1533) timeout -s 9 2 ../source/tcas.exe 765 1 1 500 400 424 0 600 500 0 1 1     > ../outputs/t1533
    if diff ../outputs/t1533 ../originals/t1533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1534) timeout -s 9 2 ../source/tcas.exe 765 1 1 600 400 524 0 600 500 0 1 1     > ../outputs/t1534
    if diff ../outputs/t1534 ../originals/t1534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1535) timeout -s 9 2 ../source/tcas.exe 765 1 1 600 400 524 2 600 500 0 1 1     > ../outputs/t1535
    if diff ../outputs/t1535 ../originals/t1535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1536) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 450 3 801 740 1 0 1     > ../outputs/t1536
    if diff ../outputs/t1536 ../originals/t1536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1537) timeout -s 9 2 ../source/tcas.exe 901 1 0 502 200 450 2 801 740 1 0 1     > ../outputs/t1537
    if diff ../outputs/t1537 ../originals/t1537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1538) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 1 801 740 1 0 1     > ../outputs/t1538
    if diff ../outputs/t1538 ../originals/t1538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1539) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 1 801 740 0 1 0     > ../outputs/t1539
    if diff ../outputs/t1539 ../originals/t1539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1540) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 1 801 740 0 1 1     > ../outputs/t1540
    if diff ../outputs/t1540 ../originals/t1540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1541) timeout -s 9 2 ../source/tcas.exe 901 1 1 502 200 450 0 801 740 0 1 1     > ../outputs/t1541
    if diff ../outputs/t1541 ../originals/t1541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1542) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 1 600 500 0 1 1     > ../outputs/t1542
    if diff ../outputs/t1542 ../originals/t1542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1543) timeout -s 9 2 ../source/tcas.exe 675 1 0 300 0 424 2 600 500 0 1 1     > ../outputs/t1543
    if diff ../outputs/t1543 ../originals/t1543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1544) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 2 600 500 0 1 1     > ../outputs/t1544
    if diff ../outputs/t1544 ../originals/t1544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1545) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 3 600 500 0 1 1     > ../outputs/t1545
    if diff ../outputs/t1545 ../originals/t1545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1546) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 0 600 500 0 1 1     > ../outputs/t1546
    if diff ../outputs/t1546 ../originals/t1546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1547) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 0 600 300 0 1 1     > ../outputs/t1547
    if diff ../outputs/t1547 ../originals/t1547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1548) timeout -s 9 2 ../source/tcas.exe 675 1 1 300 0 424 0 600 300 0 1 0     > ../outputs/t1548
    if diff ../outputs/t1548 ../originals/t1548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1549) timeout -s 9 2 ../source/tcas.exe 611 1 1 1142 511 4704 1 740 500 0 1 1     > ../outputs/t1549
    if diff ../outputs/t1549 ../originals/t1549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1550) timeout -s 9 2 ../source/tcas.exe 611 1 1 1142 511 4704 1 740 500 0 1 0     > ../outputs/t1550
    if diff ../outputs/t1550 ../originals/t1550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1551) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 1 740 500 1 1 0     > ../outputs/t1551
    if diff ../outputs/t1551 ../originals/t1551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1552) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 2 740 500 1 1 0     > ../outputs/t1552
    if diff ../outputs/t1552 ../originals/t1552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1553) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 3 740 500 1 1 0     > ../outputs/t1553
    if diff ../outputs/t1553 ../originals/t1553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1554) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 0 740 500 1 1 0     > ../outputs/t1554
    if diff ../outputs/t1554 ../originals/t1554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1555) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 0 740 500 0 1 0     > ../outputs/t1555
    if diff ../outputs/t1555 ../originals/t1555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1556) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 0 740 500 0 1 1     > ../outputs/t1556
    if diff ../outputs/t1556 ../originals/t1556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1557) timeout -s 9 2 ../source/tcas.exe 611 1 0 1142 511 4704 2 740 500 0 1 1     > ../outputs/t1557
    if diff ../outputs/t1557 ../originals/t1557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1558) timeout -s 9 2 ../source/tcas.exe 718 1 0 717 34 1153 2 429 326 0 0 1     > ../outputs/t1558
    if diff ../outputs/t1558 ../originals/t1558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1559) timeout -s 9 2 ../source/tcas.exe 718 1 0 717 34 1153 3 429 326 0 0 1     > ../outputs/t1559
    if diff ../outputs/t1559 ../originals/t1559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1560) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 335 1 665 795 1 0 1     > ../outputs/t1560
    if diff ../outputs/t1560 ../originals/t1560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1561) timeout -s 9 2 ../source/tcas.exe 634 1 0 633 500 335 2 665 795 1 0 1     > ../outputs/t1561
    if diff ../outputs/t1561 ../originals/t1561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1562) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 500 335 2 665 795 1 0 1     > ../outputs/t1562
    if diff ../outputs/t1562 ../originals/t1562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1563) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 500 335 2 665 795 0 1 1     > ../outputs/t1563
    if diff ../outputs/t1563 ../originals/t1563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1564) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 500 335 3 665 795 0 1 1     > ../outputs/t1564
    if diff ../outputs/t1564 ../originals/t1564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1565) timeout -s 9 2 ../source/tcas.exe 634 1 1 633 500 335 0 665 795 0 1 1     > ../outputs/t1565
    if diff ../outputs/t1565 ../originals/t1565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1566) timeout -s 9 2 ../source/tcas.exe 634 1 1 733 500 335 0 665 795 0 1 1     > ../outputs/t1566
    if diff ../outputs/t1566 ../originals/t1566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1567) timeout -s 9 2 ../source/tcas.exe 500 0 1 300 0 424 2 600 500 0 0 0     > ../outputs/t1567
    if diff ../outputs/t1567 ../originals/t1567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1568) timeout -s 9 2 ../source/tcas.exe 500 0 1 300 0 424 2 600 500 1 1 1     > ../outputs/t1568
    if diff ../outputs/t1568 ../originals/t1568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1569) timeout -s 9 2 ../source/tcas.exe 500 0 0 300 0 424 2 600 500 1 1 1     > ../outputs/t1569
    if diff ../outputs/t1569 ../originals/t1569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1570) timeout -s 9 2 ../source/tcas.exe 400 0 1 300 80 424 2 600 500 0 0 0     > ../outputs/t1570
    if diff ../outputs/t1570 ../originals/t1570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1571) timeout -s 9 2 ../source/tcas.exe 700 0 1 300 80 424 2 600 500 0 0 0     > ../outputs/t1571
    if diff ../outputs/t1571 ../originals/t1571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1572) timeout -s 9 2 ../source/tcas.exe 700 0 1 300 0 424 2 600 500 0 0 0     > ../outputs/t1572
    if diff ../outputs/t1572 ../originals/t1572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1573) timeout -s 9 2 ../source/tcas.exe 700 0 1 300 0 424 2 600 500 1 1 1     > ../outputs/t1573
    if diff ../outputs/t1573 ../originals/t1573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1574) timeout -s 9 2 ../source/tcas.exe 700 0 0 300 0 424 2 600 500 1 1 1     > ../outputs/t1574
    if diff ../outputs/t1574 ../originals/t1574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1575) timeout -s 9 2 ../source/tcas.exe 1078 1 0 581 567 655 3 637 906 1 1 0     > ../outputs/t1575
    if diff ../outputs/t1575 ../originals/t1575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1576) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 3 637 906 0 1 0     > ../outputs/t1576
    if diff ../outputs/t1576 ../originals/t1576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1577) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 3 637 906 0 1 1     > ../outputs/t1577
    if diff ../outputs/t1577 ../originals/t1577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1578) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 0 637 906 0 1 1     > ../outputs/t1578
    if diff ../outputs/t1578 ../originals/t1578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1579) timeout -s 9 2 ../source/tcas.exe 1     > ../outputs/t1579
    if diff ../outputs/t1579 ../originals/t1579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1580) timeout -s 9 2 ../source/tcas.exe 1 1 581 567 655 0 637 906 0 1 1     > ../outputs/t1580
    if diff ../outputs/t1580 ../originals/t1580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1581) timeout -s 9 2 ../source/tcas.exe 1 581 567 655 0 637 906 0 1 1     > ../outputs/t1581
    if diff ../outputs/t1581 ../originals/t1581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1582) timeout -s 9 2 ../source/tcas.exe 581 567 655 0 637 906 0 1 1     > ../outputs/t1582
    if diff ../outputs/t1582 ../originals/t1582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1583) timeout -s 9 2 ../source/tcas.exe 567 655 0 637 906 0 1 1     > ../outputs/t1583
    if diff ../outputs/t1583 ../originals/t1583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1584) timeout -s 9 2 ../source/tcas.exe 655 0 637 906 0 1 1     > ../outputs/t1584
    if diff ../outputs/t1584 ../originals/t1584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1585) timeout -s 9 2 ../source/tcas.exe 0 637 906 0 1 1     > ../outputs/t1585
    if diff ../outputs/t1585 ../originals/t1585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1586) timeout -s 9 2 ../source/tcas.exe 637 906 0 1 1     > ../outputs/t1586
    if diff ../outputs/t1586 ../originals/t1586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1587) timeout -s 9 2 ../source/tcas.exe 906 0 1 1     > ../outputs/t1587
    if diff ../outputs/t1587 ../originals/t1587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1588) timeout -s 9 2 ../source/tcas.exe 0 1 1     > ../outputs/t1588
    if diff ../outputs/t1588 ../originals/t1588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1589) timeout -s 9 2 ../source/tcas.exe 1 1     > ../outputs/t1589
    if diff ../outputs/t1589 ../originals/t1589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1590) timeout -s 9 2 ../source/tcas.exe 1078 1 1 567 655 0 637 906 0 1 1     > ../outputs/t1590
    if diff ../outputs/t1590 ../originals/t1590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1591) timeout -s 9 2 ../source/tcas.exe 1078 1 1 655 0 637 906 0 1 1     > ../outputs/t1591
    if diff ../outputs/t1591 ../originals/t1591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1592) timeout -s 9 2 ../source/tcas.exe 1078 1 1 0 637 906 0 1 1     > ../outputs/t1592
    if diff ../outputs/t1592 ../originals/t1592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1593) timeout -s 9 2 ../source/tcas.exe 1078 1 1 637 906 0 1 1     > ../outputs/t1593
    if diff ../outputs/t1593 ../originals/t1593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1594) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 655 0 637 906 0 1 1     > ../outputs/t1594
    if diff ../outputs/t1594 ../originals/t1594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1595) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 0 637 906 0 1 1     > ../outputs/t1595
    if diff ../outputs/t1595 ../originals/t1595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1596) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 637 906 0 1 1     > ../outputs/t1596
    if diff ../outputs/t1596 ../originals/t1596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1597) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 906 0 1 1     > ../outputs/t1597
    if diff ../outputs/t1597 ../originals/t1597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1598) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 906 1 1     > ../outputs/t1598
    if diff ../outputs/t1598 ../originals/t1598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1599) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 0 906 0 1 1     > ../outputs/t1599
    if diff ../outputs/t1599 ../originals/t1599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1600) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 0 0 1 1     > ../outputs/t1600
    if diff ../outputs/t1600 ../originals/t1600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1601) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 0 1 1     > ../outputs/t1601
    if diff ../outputs/t1601 ../originals/t1601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1602) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 655 0 1     > ../outputs/t1602
    if diff ../outputs/t1602 ../originals/t1602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1603) timeout -s 9 2 ../source/tcas.exe 1078 1 1 581 567 0 637 0 1 1     > ../outputs/t1603
    if diff ../outputs/t1603 ../originals/t1603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1604) timeout -s 9 2 ../source/tcas.exe 1078 1 1 567 655 0 906 0 1 1     > ../outputs/t1604
    if diff ../outputs/t1604 ../originals/t1604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1605) timeout -s 9 2 ../source/tcas.exe 1078 1 581 655 0 906 0 1 1     > ../outputs/t1605
    if diff ../outputs/t1605 ../originals/t1605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1606) timeout -s 9 2 ../source/tcas.exe 1078 1 1 655 0 906 0 1 1     > ../outputs/t1606
    if diff ../outputs/t1606 ../originals/t1606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1607) timeout -s 9 2 ../source/tcas.exe 1078 1 655 0 906 0 1 1     > ../outputs/t1607
    if diff ../outputs/t1607 ../originals/t1607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1608) timeout -s 9 2 ../source/tcas.exe 1078 1 1 637 906 1 1     > ../outputs/t1608
    if diff ../outputs/t1608 ../originals/t1608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  *) exit 2 ;;
esac
